/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/drv_asy.h"             */
/*  Constants and definition for ASY driver.                                 */
/*                                                                           */
/*  Author : JYA                        Last modification : 09/02/2019       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures
         5  RAM data to be inclueded in board_xyz.c


*/


#ifndef DRV_ASY_H                      /* If this file is not already        */
#define DRV_ASY_H                      /* included, include it.              */


/*
    1    Defines
    ____________
*/

/* Definitions des champs de bit pour la description des devices ............*/

/* Definition des baudrate predefinis */

#define BR_0                 0         /* Baudrate nul = Arret de l'ASY      */
#define BR_50                1         /* 50 Bauds                           */
#define BR_75                2         /* 75 Bauds                           */
#define BR_110               3         /* 110 Bauds                          */
#define BR_134               4         /* 134 Bauds                          */
#define BR_150               5         /* 150 Bauds                          */
#define BR_200               6         /* 200 Bauds                          */
#define BR_300               7         /* 300 Bauds                          */
#define BR_600               8         /* 600 Bauds                          */
#define BR_1200              9         /* 1200 Bauds                         */
#define BR_1800             10         /* 1800 Bauds                         */
#define BR_2400             11         /* 2400 Bauds                         */
#define BR_4800             12         /* 4800 Bauds                         */
#define BR_9600             13         /* 9600 Bauds                         */
#define BR_19200            14         /* 19200 Bauds                        */
#define BR_38400            15         /* 38400 Bauds                        */
#define BR_57600            16         /* 57600 Bauds                        */
#define BR_115200           17         /* 115200 Bauds                       */
#define BR_ALL  ((1<<(BR_115200+1))-1) /* Tous les modes supportes           */

/* Definiton des stop bits */

#define ST_05                1         /* 0.5 stop bits                      */
#define ST_1                 2         /* 1 stop bits                        */
#define ST_15                4         /* 1.5 stop bits                      */
#define ST_2                 8         /* 2 stop bits                        */
#define ST_ALL             0xF         /* Tous les modes supportes           */

/* Definition de la parite */

#define PAR_NONE             1         /* Pas de parite                      */
#define PAR_ODD              2         /* Parite ODD                         */
#define PAR_EVEN             4         /* Parite EVEN                        */
#define PAR_ALL            0x7         /* Tous les modes supportes           */

/* Definitions supplementaires */

#define OTH_CTS           0x01         /* Hardware flow control support      */
#define OTH_FIFO          0x04         /* FIFO available                     */
#define OTH_CTSDMA        0x10         /* RTS/CTS handling done by DMA       */
#define OTH_DMA           0x40         /* DMA available                      */

#define ASY_NBREG           10
#define NBBLK                4
#define SZBLK              128


/*
    2    Structures and typedefs
    ____________________________
*/

/* Structure de description d'une liaison asynchrone  .......................*/

typedef struct                         /* Description device Asy             */
  BEGIN                                /* ---------------------------------- */
    void         (*info)         ()  ; /* Nom du device ASY                  */
    void         (*setline)      ()  ; /* Ecrire parametres de ligne UART    */
    void         (*setflow)      ()  ; /* Communiquer parametres flow control*/
    void         (*setsig)       ()  ; /* Changer etats RTS DTR TXBREAK      */
    void         (*getsig)       ()  ; /* Lire etats CTS DSR RI DCD RXBREAK  */
    void         (*ittx)         ()  ; /* Autoriser/Interdire IT TX          */
    IWORD        (*putbyte)      ()  ; /* Ecrire un cara dans FIFO TX        */
    IWORD        (*getbyte)      ()  ; /* Lire un cara depuis FIFO RX        */
    void         (*setto)        ()  ; /* Armer temporisateur CHAR/FRAME     */
                                       /*                                    */
    IWORD        (*snddma)       ()  ; /* Demarrer emission avec DMA ASY     */
    IWORD        (*rcvdma)       ()  ; /* Demarrer reception avec DMA ASY    */
    IWORD        (*rcvdmastop)   ()  ; /* Arreter reception avec DMA ASY     */

  END            Asy_desc            ; /* ---------------------------------- */


typedef struct                         /* ASY Device Definition              */
  BEGIN                                /* ---------------------------------- */
    UINT         lctx                ; /* Low level device/context index     */
    UINT         supp_speed          ; /* Supported line rates               */
    UCHAR        supp_stop           ; /* Supported sto bit numbers          */
    UCHAR        supp_size[5]        ; /* Supported parity modes             */
    UCHAR        supp_other          ; /* Miscellaneous supported features   */
  END            Asy_drvdef          ; /* ---------------------------------- */


typedef struct                         /* ASY Device context                 */
  BEGIN                                /* ---------------------------------- */
    Hd_ctx       hctx                ; /* Context header                     */
    Req_ctx      rctx                ; /* The "Job" queues                   */
    Key_lnk      key                 ; /* A single key by device             */
    Circ_buf     cbuf                ; /* Buffer circulaire pour pipe        */
    Next_lnk     nlnk                ; /* References entite a droite         */
    UCHAR        lreg1[16]           ; /* Used by asy_set_line               */
    UCHAR        lreg2[16]           ; /* Used by asy_set_sig                */
    UCHAR        lreg3[40]           ; /* Used by asy_set_eom                */
    UCHAR        lreg4[16]           ; /* Used by asy_set_flow               */
    UCHAR        lreg5[76]           ; /* Used by asy_get all                */
                                       /*                                    */
    void         (*setline)      ()  ; /* Set the UART line parameters       */
    void         (*setflow)      ()  ; /* Set the flow control parameters    */
    void         (*setsig)       ()  ; /* Set the RTS DTR TXBREAK sig. state */
    void         (*getsig)       ()  ; /* Get the CTS DSR RI DCD RXBREAK sig */
    void         (*ittx)         ()  ; /* Enable/Disable the TX interrupt    */
    IWORD        (*putbyte)      ()  ; /* Write a byte in the TX FIFO        */
    IWORD        (*getbyte)      ()  ; /* Read a byte from the RX FIFO       */
    void         (*setto)        ()  ; /* Set the CHAR/FRAME timer           */
    IWORD        (*snddma)       ()  ; /* Start a UART DMA transmission      */
    IWORD        (*rcvdma)       ()  ; /* Start a UART DMA reception         */
    IWORD        (*rcvdmastop)   ()  ; /* Stop a UART DMA reception          */
                                       /*                                    */
    Asy_drvdef   *def                ; /* Definitions of the device          */
    UINT         lctx                ; /* Low-level device index             */
                                       /*                                    */
    IWORD        (*cb_send)      ()  ; /* End of asy_send() callback  UNUSED */
    IWORD        (*cb_rcv)       ()  ; /* End of reception callback   UNUSED */
    IWORD        (*cb_io)        ()  ; /* End of asy_io() callback    UNUSED */
    IWORD        (*cb_ind)       ()  ; /* IND_REPORT callback         UNUSED */
    INT          inihigh             ; /* Reference of what is stacked above */
                                       /*                                    */
    UINT         reg[ASY_NBREG]      ; /* Value of the registers             */
                                       /*                                    */
    USHORT       char1               ; /* End of message character 1         */
    USHORT       char2               ; /* End of message character 2         */
    USHORT       char3               ; /* End of message character 3         */
    USHORT       maxframe            ; /* Maximum frame size                 */
    USHORT       minframe            ; /* Minimum frame size                 */
    USHORT       tmode               ; /* 0:NONE  1:CHARACTER  2:FRAME       */
    USHORT       tempo               ; /* Timeout (milliseconds)             */
    USHORT       flowctl             ; /* 0:NONE  1:RTS/CTS  2:XON/XOFF      */
    USHORT       bufsize             ; /* BUFSIZE                            */
    USHORT       dma                 ; /* 0:byte by byte mode  1: DMA mode   */
                                       /*                                    */
    UCHAR        buf[64]             ; /* If no other buffer is available    */
    USHORT       ibuf                ; /* Index of the next byte to receive  */
                                       /*                                    */
    UCHAR        *snd                ; /* Address of the transmission buffer */
    USHORT       sndsize             ; /* Number of bytes to send            */
    USHORT       isnd                ; /* Index of the next byte to send     */
    USHORT       sndcnt              ; /* Count of received IT_TX events     */
    USHORT       sndcur              ; /* Count of current ongoing sends     */
                                       /*                                    */
    UCHAR        *rcv                ; /* Addess of the reception buffer     */
    USHORT       rcvsize             ; /* Size of the reception buffer       */
    USHORT       ircv                ; /* Index of the next byte received    */
    USHORT       rcvcnt              ; /* Count of received IT_RX events     */
    USHORT       rcvcur              ; /* Count of current ongoing receives  */
                                       /*                                    */
    UCHAR        stoptx              ; /* 1 if the outgoing flow is blocked  */
    UCHAR        stoprx              ; /* 1 if the incoming flow is blocked  */
    UCHAR        asyto               ; /* 1 if the UART timer is running     */
    UCHAR        rts                 ; /* 1 if out RTS is TRUE               */
    UCHAR        close               ; /* 1 if a REQ_CLOSE has been received */
 
  END            Asy_ctx             ; /* ---------------------------------- */


/*
    3    Public variables
    _____________________
*/

extern UCHAR      asy_sysdrv         ; /* ASY driver number                  */
extern const UINT tasybauds[]        ; /* Baudrate corresponding to the      */
                                       /* baud rate index                    */

/*
    4    Prototypes of public procedures
    ____________________________________
*/

/* Procedures appelees par les controleurs d'interruption ...................*/

  void  itasyrx             (IWORD                                           );
  void  itasytx             (IWORD                                           );
  void  itasyto             (IWORD                                           );
  void  itasysig            (IWORD                                           );
  void  itasydmarx          (IWORD,INT,INT                                   );
  void  itasydmatx          (IWORD                                           );


/* Procedures d'interface du driver systeme .................................*/

extern UCHAR asy_numdrv              ; /* Numero du driver ASY               */
extern UCHAR asy_sysdrv              ; /* Numero du driver ASY               */

  IWORD asy_get_rctx        (INT, Req_ctx**                                  );
  IWORD asy_set_line        (Req_ctx*, INT, INT, INT, INT, INT               );
  IWORD asy_set_signals     (Req_ctx*, INT, INT, INT, INT                    );
  IWORD asy_set_eom         (Req_ctx*, USHORT *, INT, INT, INT, INT, INT     );
  IWORD asy_set_flowctl     (Req_ctx*, INT, INT, INT                         );
  IWORD asy_get_all         (Req_ctx*, INT                                   );
  IWORD asy_send            (Req_ctx*, UCHAR *, INT, INT, INT                );
  IWORD asy_receive         (Req_ctx*, INT, INT, UCHAR*, INT, INT            );
  IWORD asy_io              (Req_ctx*, Job *, INT                            );
  IWORD asy_write           (INT,UCHAR*,INT                                  );
  IWORD asy_read            (INT,UCHAR*,INT,INT*                             );


/* Procedures d'interface pour affichage console ............................*/

  IWORD asy_write           (INT, UCHAR *, INT                               );
  IWORD asy_read            (INT, UCHAR *, INT, INT *                        );

/* Procedures de traces eb memoire pour les bas niveaux (MEMLOG).............*/

  void  asy_log_init        (void                                            );
  void  asy_log             (INT,INT,INT                                     );
  void  asy_log_prt         (void                                            );


#endif                                 /* End of DRV_ASY_H.                  */
/*
    5  RAM data to be inclueded in board_xyz.c
    ___________________________________________
*/

#ifdef BOARD_XYZ_DATA_C

const USHORT  asy_nbiod = NUM_ASY    ; /* Nombre de devices pour le VMK.     */
const USHORT  asy_nbvl = NUM_ASY+1   ; /* Nombre de voies logiques           */

Asy_ctx       asy_ctx   [NUM_ASY]    ; /* Controller's context table         */
USHORT        asy_etat  [NUM_ASY+1]  ; /* Etat de voie logique               */

Itf_ctx asy_itfctx[1+NUM_ASY]        ;


#endif                                 /* End of BOARD_XYZ_C                 */


