/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/emu32.h"               */
/*  Constants and definitions for emu32 emulator.                            */
/*                                                                           */
/*  Author : JYA                        Last modification : 02/11/2016       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef EMU32_H                        /* If this file is not already        */
#define EMU32_H                        /* included, include it.              */


/*
    1    Defines
    ____________
*/


/* Menage a faire. Nom d'instruction court ..................................*/

#define ALLOCL        ALLOCLINK        /*                                    */
#define POSTL         POSTLINK         /*                                    */
#define FREEL         FREELINK         /*                                    */
#define LBUF          LINKBUF          /*                                    */
#define RELBUF        RELINKBUF        /*                                    */
#define UNLBUF        UNLINKBUF        /*                                    */
#define SBUF          SEARCHBUF        /*                                    */


/* Codes des erreurs irrecuperables de l'emulateur ..........................*/

#define E_EOF              -101        /*                                    */
#define E_DIV_ZERO         -102        /* DIVR/I MODR/I ALIGNR/I ROUNDR/I .. */
#define E_REG_ADDR         -103        /* Numero direct de registre >= 127   */
#define E_BAD_IREG         -104        /* Numero indirect de registre pas bon*/
#define E_BUFF_OVR         -105        /* STOC CONCAT MID COPY               */
#define E_STOC             -106        /* STOC                               */
#define E_CONCAT           -107        /* CONCAT, "s2" egal a "sd"           */
#define E_MID              -108        /* MID, "deb" sort de la chaine       */
#define E_STACK            -109        /* PUSH POP                           */
#define E_ALLOC            -110        /* ALLOCI/ALLOCR taille > 32Ko        */
#define E_CLEARTO          -111        /* CLEARTO                            */
#define E_EVT_FULL         -112        /* SENDVMIO STOEVT                    */
#define E_PPNB             -113        /* PEEK POKE                          */
#define E_ORDER            -114        /* RDSHORT RDINT WRSHORTR/I WRINTR/I  */

#define E_BAD_PGM          -115        /* init_emu32 ADRPGMR/I               */
#define E_BAD_REF          -116        /* link_emu32                         */
#define E_BAD_DATA         -117        /* COD ADRDATAR/I                     */
#define E_BAD_SUB          -118        /* init_emu32 GOSUB JPSUB ADRSUBR/I ..*/
#define E_BAD_LAB          -119        /* GOTO GOTOXX                        */
#define E_BAD_TASK         -120        /* TASKR/I SWITCHR/I                  */

#define E_REINIT_P         -121        /* init_pgm32, prog deja initialise   */
#define E_INIT_BUF         -122        /* init_pgm32, echec allocation buffer*/
#define E_INIT_SUB         -123        /* init_pgm32, SUB/ENDSUB non corresp */
#define E_NB_PGM           -124        /* init_pgm32, table programmes pleine*/


/* Codes supplementaires pour cpi32.c .......................................*/

#define E_BAD_INST         -125        /* Code instruction inconnu           */
#define E_BAD_NUM          -126        /* Mauvais numero de variable/adresse */
#define E_BAD_TYPE         -127        /* Type de donnee n'est pas bon       */
#define E_BAD_COUNT        -128        /* Nombre/Compte d'octets pas bon     */
#define E_BAD_ADR          -129        /* Adresse egale a 0                  */
#define E_BAD_LIND         -130        /* Mauvais indice de liste            */
#define E_NO_LBEG          -131        /* Pas de marqueur de debut de liste  */
#define E_NO_SEL           -132        /* Pas de selecteur avant la liste    */
#define E_EMPTY_LIST       -133        /* Liste vide                         */
#define E_EMPTY_BUFF       -134        /* Plus de donnees a lire depuis buff */


/* Codes des instructions de l'emulateur ....................................*/


/*****************************************************************************
 * Ces valeurs sont des indices dans le tableau (*refinst[])() de emu32.c,   *
 * ainsi que dans le tableau "refsize[]". Il ne faut donc pas modifier ces   *
 * valeurs sans reorganiser "definst" et "defsize".                          *
 *****************************************************************************/


#define C_ENDCODE             0        /*                                    */
#define C_ENDSUB              1        /*                                    */
#define C_SUB                 2        /*                                    */
#define C_LABEL               3        /*                                    */
#define C_DATA                4        /*                                    */
#define C_STOP                5        /*                                    */

#define C_GOTO                6        /*                                    */
#define C_GOTOR               7        /*                                    */
#define C_GOTOEQ              8        /*                                    */
#define C_GOTONE              9        /*                                    */
#define C_GOTOLT             10        /*                                    */
#define C_GOTOLE             11        /*                                    */
#define C_GOTOGT             12        /*                                    */
#define C_GOTOGE             13        /*                                    */
#define C_GOSUB              14        /*                                    */
#define C_JPSUB              15        /*                                    */
#define C_RETURN             16        /*                                    */

#define C_IGOTO              17        /*                                    */
#define C_IGOTOR             18        /*                                    */
#define C_IGOTOEQ            19        /*                                    */
#define C_IGOTONE            20        /*                                    */
#define C_IGOTOLT            21        /*                                    */
#define C_IGOTOLE            22        /*                                    */
#define C_IGOTOGT            23        /*                                    */
#define C_IGOTOGE            24        /*                                    */
#define C_IGOSUB             25        /*                                    */
#define C_IJPSUB             26        /*                                    */

#define C_TASKR              27        /*                                    */
#define C_TASKI              28        /*                                    */
#define C_SWITCHR            29        /*                                    */
#define C_SWITCHI            30        /*                                    */

#define C_MOVER              31        /*                                    */
#define C_NOTR               32        /*                                    */
#define C_ADDR               33        /*                                    */
#define C_SUBR               34        /*                                    */
#define C_MULR               35        /*                                    */
#define C_DIVR               36        /*                                    */
#define C_MODR               37        /*                                    */
#define C_ALIGNR             38        /*                                    */
#define C_ROUNDR             39        /*                                    */
#define C_MINR               40        /*                                    */
#define C_MAXR               41        /*                                    */
#define C_CMPRU              42        /*                                    */
#define C_MULRU              43        /*                                    */
#define C_DIVRU              44        /*                                    */
#define C_MODRU              45        /*                                    */
#define C_MINRU              46        /*                                    */
#define C_MAXRU              47        /*                                    */
#define C_ANDR               48        /*                                    */
#define C_ORR                49        /*                                    */
#define C_XORR               50        /*                                    */
#define C_SRR                51        /*                                    */
#define C_SLR                52        /*                                    */

#define C_MOVEI              53        /*                                    */
#define C_ADDI               54        /*                                    */
#define C_SUBI               55        /*                                    */
#define C_MULI               56        /*                                    */
#define C_DIVI               57        /*                                    */
#define C_MODI               58        /*                                    */
#define C_ALIGNI             59        /*                                    */
#define C_ROUNDI             60        /*                                    */
#define C_MINI               61        /*                                    */
#define C_MAXI               62        /*                                    */
#define C_CMPIU              63        /*                                    */
#define C_MULIU              64        /*                                    */
#define C_DIVIU              65        /*                                    */
#define C_MODIU              66        /*                                    */
#define C_MINIU              67        /*                                    */
#define C_MAXIU              68        /*                                    */
#define C_ANDI               69        /*                                    */
#define C_ORI                70        /*                                    */
#define C_XORI               71        /*                                    */
#define C_SRI                72        /*                                    */
#define C_SLI                73        /*                                    */

#define C_PUSH               74        /*                                    */
#define C_POP                75        /*                                    */

#define C_HCONVU             76        /*                                    */
#define C_HCONVL             77        /*                                    */
#define C_COD                78        /*                                    */

#define C_ALLOCR             79        /*                                    */
#define C_ALLOCI             80        /*                                    */
#define C_POST               81        /*                                    */
#define C_FREE               82        /*                                    */

#define C_ALLOCLINK          83        /*                                    */
#define C_POSTLINK           84        /*                                    */
#define C_FREELINK           85        /*                                    */
#define C_LINKBUF            86        /*                                    */
#define C_RELINKBUF          87        /*                                    */
#define C_UNLINKBUF          88        /*                                    */
#define C_NEXTBUF            89        /*                                    */
#define C_SEARCHBUF          90        /*                                    */
#define C_FREEALL            91        /*                                    */
#define C_GETBUFSZ           92        /*                                    */
#define C_GETLNKSZ           93        /*                                    */

#define C_HEADGET            94        /*                                    */
#define C_HEADSET            95        /*                                    */
#define C_MEMSETR            96        /*                                    */
#define C_MEMSETI            97        /*                                    */
#define C_MEMSETM            98        /*                                    */
#define C_MEMMOVE            99        /*                                    */
#define C_MMOVEOF           100        /*                                    */
#define C_PEEK              101        /*                                    */
#define C_POKE              102        /*                                    */
#define C_RDCHAR            103        /*                                    */
#define C_RDSHORT           104        /*                                    */
#define C_RDINT             105        /*                                    */
#define C_WRCHARR           106        /*                                    */
#define C_WRSHORTR          107        /*                                    */
#define C_WRINTR            108        /*                                    */
#define C_WRCHARI           109        /*                                    */
#define C_WRSHORTI          110        /*                                    */
#define C_WRINTI            111        /*                                    */

#define C_STOC              112        /*                                    */
#define C_CLRS              113        /*                                    */
#define C_LEN               114        /*                                    */
#define C_CONCAT            115        /*                                    */
#define C_MID               116        /*                                    */
#define C_COPY              117        /*                                    */
#define C_COUNTR            118        /*                                    */
#define C_COUNTI            119        /*                                    */

#define C_ADRPGMR           120        /*                                    */
#define C_ADRSUBR           121        /*                                    */
#define C_ADRDATAR          122        /*                                    */
#define C_ADRREGR           123        /*                                    */

#define C_ADRPGMI           124        /*                                    */
#define C_ADRSUBI           125        /*                                    */
#define C_ADRDATAI          126        /*                                    */
#define C_ADRREGI           127        /*                                    */

#define C_WAITEVT           128        /*                                    */
#define C_SENDVMIO          129        /*                                    */
#define C_STOEVT            130        /*                                    */
#define C_GETEVT            131        /*                                    */
#define C_CLREVT            132        /*                                    */
#define C_RELAUT            133        /*                                    */
#define C_SETTOR            134        /*                                    */
#define C_SETTOI            135        /*                                    */
#define C_CLEARTO           136        /*                                    */

#define C_SENDI2C           137        /*                                    */
#define C_RECVI2C           138        /*                                    */
#define C_CTLPIO            139        /*                                    */
#define C_GETPIO            140        /*                                    */
#define C_SETPIO            141        /*                                    */
#define C_GETREG            142        /*                                    */
#define C_SETREG            143        /*                                    */


/*****************************************************************************
 * Code d'instruction rajoutees a partir du 01/03/2008. Etant donne que le   *
 * loader utilise les codes d'instruction de base et que celui-ci est fige,  *
 * il est interdit de modifier ces codes d'instructions.                     *
 *****************************************************************************/


#define C_ICOD              144        /*                                    */
#define C_CHKEVT            145        /*                                    */
#define C_VHALT             146        /*                                    */
#define C_VHALTEQ           147        /*                                    */
#define C_VHALTNE           148        /*                                    */
#define C_VHALTLT           149        /*                                    */
#define C_VHALTLE           150        /*                                    */
#define C_VHALTGT           151        /*                                    */
#define C_VHALTGE           152        /*                                    */

#define C_FIRSTEXT          153        /*                                    */


/* Instructions des programmes ----------------------------------------------*/

#define ENDCODE(x)          (C_ENDCODE ),(x)
#define ENDSUB(sub)         (C_ENDSUB  ),(sub)
#define SUB(sub)            (C_SUB     ),(sub)
#define LABEL(label)        (C_LABEL   ),(label)
#define DATA(ref,nb)        (C_DATA    ),(ref),(((nb)>>8)&0xFF),((nb)&0xFF)
#define STOP                (C_STOP    )

#define GOTO(label)         (C_GOTO    ),(label)
#define GOTOR(r,d,f,lab)    (C_GOTOR   ),(r),(d),(f),(lab)
#define GOTOEQ(r,lab)       (C_GOTOEQ  ),(r),(lab)
#define GOTONE(r,lab)       (C_GOTONE  ),(r),(lab)
#define GOTOLT(r,lab)       (C_GOTOLT  ),(r),(lab)
#define GOTOLE(r,lab)       (C_GOTOLE  ),(r),(lab)
#define GOTOGT(r,lab)       (C_GOTOGT  ),(r),(lab)
#define GOTOGE(r,lab)       (C_GOTOGE  ),(r),(lab)
#define GOSUB(lab,link)     (C_GOSUB   ),(lab),(link)   
#define JPSUB(n,lab,link)   (C_JPSUB   ),(n),(lab),(link)   
#define RETURN(link)        (C_RETURN  ),(link)

#define IGOTO(ir)           (C_IGOTO   ),(ir)
#define IGOTOR(r,d,f,ir)    (C_IGOTOR  ),(r),(d),(f),(ir)
#define IGOTOEQ(r,ir)       (C_IGOTOEQ ),(r),(ir)
#define IGOTONE(r,ir)       (C_IGOTONE ),(r),(ir)
#define IGOTOLT(r,ir)       (C_IGOTOLT ),(r),(ir)
#define IGOTOLE(r,ir)       (C_IGOTOLE ),(r),(ir)
#define IGOTOGT(r,ir)       (C_IGOTOGT ),(r),(ir)
#define IGOTOGE(r,ir)       (C_IGOTOGE ),(r),(ir)
#define IGOSUB(ir,link)     (C_IGOSUB  ),(ir),(link)   
#define IJPSUB(n,ir,link)   (C_IJPSUB  ),(n),(ir),(link)   
 
#define TASKR(r,n,ir)       (C_TASKR   ),(r),(n),(ir)
#define TASKI(v,n,sub)      (C_TASKI   ),(v),(n),(sub)
#define SWITCHR(r)          (C_SWITCHR ),(r)
#define SWITCHI(v)          (C_SWITCHI ),(v)

#define MOVER(rd,rs)        (C_MOVER   ),(rd),(rs)
#define ADDR(rd,r1,r2)      (C_ADDR    ),(rd),(r1),(r2)
#define SUBR(rd,r1,r2)      (C_SUBR    ),(rd),(r1),(r2)
#define MULR(rd,r1,r2)      (C_MULR    ),(rd),(r1),(r2)
#define DIVR(rd,r1,r2)      (C_DIVR    ),(rd),(r1),(r2)
#define MODR(rd,r1,r2)      (C_MODR    ),(rd),(r1),(r2)
#define ALIGNR(rd,r1,r2)    (C_ALIGNR  ),(rd),(r1),(r2)
#define ROUNDR(rd,r1,r2)    (C_ROUNDR  ),(rd),(r1),(r2)
#define MINR(rd,r1,r2)      (C_MINR    ),(rd),(r1),(r2)
#define MAXR(rd,r1,r2)      (C_MAXR    ),(rd),(r1),(r2)
#define CMPRU(rd,r1,r2)     (C_CMPRU   ),(rd),(r1),(r2)
#define MULRU(rd,r1,r2)     (C_MULRU   ),(rd),(r1),(r2)
#define DIVRU(rd,r1,r2)     (C_DIVRU   ),(rd),(r1),(r2)
#define MODRU(rd,r1,r2)     (C_MODRU   ),(rd),(r1),(r2)
#define MINRU(rd,r1,r2)     (C_MINRU   ),(rd),(r1),(r2)
#define MAXRU(rd,r1,r2)     (C_MAXRU   ),(rd),(r1),(r2)
#define ANDR(rd,r1,r2)      (C_ANDR    ),(rd),(r1),(r2)
#define ORR(rd,r1,r2)       (C_ORR     ),(rd),(r1),(r2)
#define XORR(rd,r1,r2)      (C_XORR    ),(rd),(r1),(r2)
#define SRR(rd,r1,r2)       (C_SRR     ),(rd),(r1),(r2)
#define SLR(rd,r1,r2)       (C_SLR     ),(rd),(r1),(r2)
#define NOTR(rd,rs)         (C_NOTR    ),(rd),(rs)

#define MOVEI(rd,v)         (C_MOVEI   ),(rd),( (UINT)(v)>>24      ),\
                                              (((UINT)(v)>>16)&0xFF),\
                                              (((UINT)(v)>> 8)&0xFF),\
                                              ( (UINT)(v)     &0xFF)
#define ADDI(rd,r1,v)       (C_ADDI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define SUBI(rd,r1,v)       (C_SUBI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MULI(rd,r1,v)       (C_MULI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define DIVI(rd,r1,v)       (C_DIVI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MODI(rd,r1,v)       (C_MODI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define ALIGNI(rd,r1,v)     (C_ALIGNI  ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define ROUNDI(rd,r1,v)     (C_ROUNDI  ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MINI(rd,r1,v)       (C_MINI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MAXI(rd,r1,v)       (C_MAXI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define CMPIU(rd,r1,v)      (C_CMPIU   ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MULIU(rd,r1,v)      (C_MULIU   ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define DIVIU(rd,r1,v)      (C_DIVIU   ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MODIU(rd,r1,v)      (C_MODIU   ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MINIU(rd,r1,v)      (C_MINIU   ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define MAXIU(rd,r1,v)      (C_MAXIU   ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define ANDI(rd,r1,v)       (C_ANDI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define ORI(rd,r1,v)        (C_ORI     ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define XORI(rd,r1,v)       (C_XORI    ),(rd),(r1),( (UINT)(v)>>24      ),\
                                                   (((UINT)(v)>>16)&0xFF),\
                                                   (((UINT)(v)>> 8)&0xFF),\
                                                   ( (UINT)(v)     &0xFF)
#define SRI(rd,r1,v)        (C_SRI     ),(rd),(r1),(v)
#define SLI(rd,r1,v)        (C_SLI     ),(rd),(r1),(v)
  
#define PUSH(nb)            (C_PUSH    ),(nb)
#define POP(nb)             (C_POP     ),(nb)

#define HCONVU(rd,rs)       (C_HCONVU  ),(rd),(rs)
#define HCONVL(rd,rs)       (C_HCONVL  ),(rd),(rs)
#define COD(rd,rs,ref,a,b)  (C_COD     ),(rd),(rs),(ref),(a),(b)
#define ICOD(rd,rs,rr,a,b)  (C_ICOD    ),(rd),(rs),(rr ),(a),(b)

#define ALLOCR(rd,ru,rn,rf) (C_ALLOCR  ),(rd),(ru),(rn),(rf)
#define ALLOCI(rd,ru,v,f)   (C_ALLOCI  ),(rd),(ru),((v)>>16),((v)>>8)&0xFF,\
                                                             ((v)&0xFF),(f)
#define POST(r)             (C_POST    ),(r)
#define FREE(r)             (C_FREE    ),(r)

#define ALLOCLINK(rd,ru,rn,rf)   (C_ALLOCLINK),(rd),(ru),(rn),(rf)
#define POSTLINK(r)              (C_POSTLINK ),(r)
#define FREELINK(r)              (C_FREELINK ),(r)
#define LINKBUF(l,b,o,n,t)       (C_LINKBUF  ),(l),(b),(o),(n),(t)
#define RELINKBUF(ld,ls,b,o,n,t) (C_RELINKBUF),(ld),(ls),(b),(o),(n),(t)
#define UNLINKBUF(l,b)           (C_UNLINKBUF),(l),(b)
#define NEXTBUF(rd,b,o,l)        (C_NEXTBUF  ),(rd),(b),(o),(l)
#define SEARCHBUF(rd,l,o,n,t,v)  (C_SEARCHBUF),(rd),(l),(o),(n),(t),(v)
#define FREEALL(r)               (C_FREEALL  ),(r)
#define GETBUFSZ(ro,rl,rsz,b)    (C_GETBUFSZ ),(ro),(rl),(rsz),(b)
#define GETLNKSZ(rn,rl,rsz,l)    (C_GETLNKSZ ),(rn),(rl),(rsz),(l)

#define HEADGET(rd,rs,n)    (C_HEADGET ),(rd),(rs),(n)
#define HEADSET(rd,n,rs)    (C_HEADSET ),(rd),(n),(rs)
#define MEMSETR(rd,r1,r2)   (C_MEMSETR ),(rd),(r1),(r2)
#define MEMSETI(rd,v,r2)    (C_MEMSETI ),(rd),(v),(r2)
#define MEMSETM(rd,nb)      (C_MEMSETM ),(rd),(nb)
#define MEMMOVE(rd,rs,r1)   (C_MEMMOVE ),(rd),(rs),(r1)
#define MMOVEOF(d,a,s,b,c)  (C_MMOVEOF ),(d),(a),(s),(b),(c)
#define PEEK(rd,rs,of,nb)   (C_PEEK    ),(rd),(rs),(of),(nb)
#define POKE(rd,of,rs,nb)   (C_POKE    ),(rd),(of),(rs),(nb)
#define RDCHAR(rd,rs,i)     (C_RDCHAR  ),(rd),(rs),((UCHAR)i)
#define RDSHORT(rd,r,o,i)   (C_RDSHORT ),(rd),(r),(o),((UCHAR)i)
#define RDINT(rd,r,o,i)     (C_RDINT   ),(rd),(r),(o),((UCHAR)i)
#define WRCHARR(rd,rs,i)    (C_WRCHARR ),(rd),(rs),((UCHAR)i)
#define WRSHORTR(d,s,o,i)   (C_WRSHORTR),(d),(s),(o),((UCHAR)i)
#define WRINTR(d,s,o,i)     (C_WRINTR  ),(d),(s),(o),((UCHAR)i)
#define WRCHARI(d,v,i)      (C_WRCHARI ),(d),(v),((UCHAR)i)
#define WRSHORTI(d,v,o,i)   (C_WRSHORTI),(d),((v)>>8),((v)&0xFF),(o),((UCHAR)i)
#define WRINTI(d,v,o,i)     (C_WRINTI  ),(d),( (UINT)(v)>>24      ),\
                                             (((UINT)(v)>>16)&0xFF),\
                                             (((UINT)(v)>> 8)&0xFF),\
                                             ( (UINT)(v)     &0xFF),\
                                         (o),((UCHAR)i)
#define STOC(sd,rs,act)     (C_STOC    ),(sd),(rs),(act)
#define CLRS(sd)            (C_CLRS    ),(sd)
#define LEN(rd,sd)          (C_LEN     ),(rd),(sd)
#define CONCAT(sd,s1,s2)    (C_CONCAT  ),(sd),(s1),(s2)
#define MID(sd,ss,deb,nb)   (C_MID     ),(sd),(ss),(deb),(nb)
#define COPY(sd,ss)         (C_COPY    ),(sd),(ss)
#define COUNTR(rd,rs,rv)    (C_COUNTR  ),(rd),(rs),(rv)
#define COUNTI(rd,rs,v)     (C_COUNTI  ),(rd),(rs),(v)

#define ADRPGMR(ra,rs,r)         (C_ADRPGMR ),(ra),(rs),(r)
#define ADRSUBR(ra,rs,r1,r2)     (C_ADRSUBR ),(ra),(rs),(r1),(r2)
#define ADRDATAR(ra,rs,r1,r2)    (C_ADRDATAR),(ra),(rs),(r1),(r2)
#define ADRREGR(ra,r)            (C_ADRREGR ),(ra),(r)

#define ADRPGMI(ra,rs,pgm)       (C_ADRPGMI ),(ra),(rs),(pgm)
#define ADRSUBI(ra,rs,pgm,ref)   (C_ADRSUBI ),(ra),(rs),(pgm),(ref)
#define ADRDATAI(ra,rs,pgm,ref)  (C_ADRDATAI),(ra),(rs),(pgm),(ref)
#define ADRREGI(ra,ref)          (C_ADRREGI ),(ra),(ref)

#define WAITEVT(r)          (C_WAITEVT ),(r)
#define SENDVMIO(r)         (C_SENDVMIO),(r)
#define STOEVT(r)           (C_STOEVT  ),(r)
#define GETEVT(r,v,c,n,u)   (C_GETEVT  ),(r),(v),(c),(n),(u)
#define CLREVT(r)           (C_CLREVT  ),(r)
#define RELAUT(r)           (C_RELAUT  ),(r)

#define SETTOR(rd,cd,r1)    (C_SETTOR  ),(rd),((cd)>>8),((cd)&0xFF),(r1)
#define SETTOI(rd,cd,va)    (C_SETTOI  ),(rd),((cd)>>8),((cd)&0xFF),\
                                            ( (UINT)(va)>>24      ),\
                                            (((UINT)(va)>>16)&0xFF),\
                                            (((UINT)(va)>> 8)&0xFF),\
                                            ( (UINT)(va)     &0xFF)
#define CLEARTO(r,cd)       (C_CLEARTO ),(r),((cd)>>8),((cd)&0xFF)

#define SENDI2C(b,w,t,f)    (C_SENDI2C ),(b),(w),(t),(f)
#define RECVI2C(b,w,t,l,s)  (C_RECVI2C ),(b),(w),(t),(l),(s)
#define CTLPIO(p,n,v)       (C_CTLPIO  ),(p),(n),(v)
#define GETPIO(p,n,v)       (C_GETPIO  ),(p),(n),(v)
#define SETPIO(p,n,v)       (C_SETPIO  ),(p),(n),(v)
#define GETREG(rd,rs,of,nb) (C_GETREG  ),(rd),(rs),(of),(nb)
#define SETREG(rd,of,rs,nb) (C_SETREG  ),(rd),(of),(rs),(nb)

#define CHKEVT(r)           (C_CHKEVT  ),(r)
#define VHALT               (C_VHALT   )
#define VHALTEQ(r)          (C_VHALTEQ ),(r)
#define VHALTNE(r)          (C_VHALTNE ),(r)
#define VHALTLT(r)          (C_VHALTLT ),(r)
#define VHALTLE(r)          (C_VHALTLE ),(r)
#define VHALTGT(r)          (C_VHALTGT ),(r)
#define VHALTGE(r)          (C_VHALTGE ),(r)

#define USHT(val)           (((val)>>8)&0xFF),((val)&0xFF)


/* Champs de l'en-tete de la structure Buf_head -----------------------------*/

#define HPOS                  0        /*                                    */
#define HNB                   1        /*                                    */
#define HSZ0                  2        /*                                    */
#define HSZ1                  3        /*                                    */
#define HBIGOF7               4        /*                                    */
#define HBIG                  5        /*                                    */
#define HUID                  6        /*                                    */
#define HFLAGS                7        /*                                    */
#define HREF                  8        /*                                    */


/* Numeros "directs" des registres 32 bits ----------------------------------*/

#define R0                    0        /* Registre R0                        */
#define R1                    1        /* Registre R1                        */
#define R2                    2        /* Registre R2                        */
#define R3                    3        /* Registre R3                        */
#define R4                    4        /* Registre R4                        */
#define R5                    5        /* Registre R5                        */
#define R6                    6        /* Registre R6                        */
#define R7                    7        /* Registre R7                        */
#define R8                    8        /* Registre R8                        */
#define R9                    9        /* Registre R9                        */
#define R10                  10        /* Registre R10                       */
#define R11                  11        /* Registre R11                       */
#define R12                  12        /* Registre R12                       */
#define R13                  13        /* Registre R13                       */
#define R14                  14        /* Registre R14                       */
#define R15                  15        /* Registre R15                       */
#define R16                  16        /* Registre R16                       */
#define R17                  17        /* Registre R17                       */
#define R18                  18        /* Registre R18                       */
#define R19                  19        /* Registre R19                       */
#define R20                  20        /* Registre R20                       */
#define R21                  21        /* Registre R21                       */
#define R22                  22        /* Registre R22                       */
#define R23                  23        /* Registre R23                       */
#define R24                  24        /* Registre R24                       */
#define R25                  25        /* Registre R25                       */
#define R26                  26        /* Registre R26                       */
#define R27                  27        /* Registre R27                       */
#define R28                  28        /* Registre R28                       */
#define R29                  29        /* Registre R29                       */
#define R30                  30        /* Registre R30                       */
#define R31                  31        /* Registre R31                       */
#define R32                  32        /* Registre R32                       */
#define R33                  33        /* Registre R33                       */
#define R34                  34        /* Registre R34                       */
#define R35                  35        /* Registre R35                       */
#define R36                  36        /* Registre R36                       */
#define R37                  37        /* Registre R37                       */
#define R38                  38        /* Registre R38                       */
#define R39                  39        /* Registre R39                       */
#define R40                  40        /* Registre R40                       */
#define R41                  41        /* Registre R41                       */
#define R42                  42        /* Registre R42                       */
#define R43                  43        /* Registre R43                       */
#define R44                  44        /* Registre R44                       */
#define R45                  45        /* Registre R45                       */
#define R46                  46        /* Registre R46                       */
#define R47                  47        /* Registre R47                       */
#define R48                  48        /* Registre R48                       */
#define R49                  49        /* Registre R49                       */
#define R50                  50        /* Registre R50                       */
#define R51                  51        /* Registre R51                       */
#define R52                  52        /* Registre R52                       */
#define R53                  53        /* Registre R53                       */
#define R54                  54        /* Registre R54                       */
#define R55                  55        /* Registre R55                       */
#define R56                  56        /* Registre R56                       */
#define R57                  57        /* Registre R57                       */
#define R58                  58        /* Registre R58                       */
#define R59                  59        /* Registre R59                       */
#define R60                  60        /* Registre R60                       */
#define R61                  61        /* Registre R61                       */
#define R62                  62        /* Registre R62                       */
#define R63                  63        /* Registre R63                       */
#define R64                  64        /* Registre R64                       */
#define R65                  65        /* Registre R65                       */
#define R66                  66        /* Registre R66                       */
#define R67                  67        /* Registre R67                       */
#define R68                  68        /* Registre R68                       */
#define R69                  69        /* Registre R69                       */
#define R70                  70        /* Registre R70                       */
#define R71                  71        /* Registre R71                       */
#define R72                  72        /* Registre R72                       */
#define R73                  73        /* Registre R73                       */
#define R74                  74        /* Registre R74                       */
#define R75                  75        /* Registre R75                       */
#define R76                  76        /* Registre R76                       */
#define R77                  77        /* Registre R77                       */
#define R78                  78        /* Registre R78                       */
#define R79                  79        /* Registre R79                       */
#define R80                  80        /* Registre R80                       */
#define R81                  81        /* Registre R81                       */
#define R82                  82        /* Registre R82                       */
#define R83                  83        /* Registre R83                       */
#define R84                  84        /* Registre R84                       */
#define R85                  85        /* Registre R85                       */
#define R86                  86        /* Registre R86                       */
#define R87                  87        /* Registre R87                       */
#define R88                  88        /* Registre R88                       */
#define R89                  89        /* Registre R89                       */
#define R90                  90        /* Registre R90                       */
#define R91                  91        /* Registre R91                       */
#define R92                  92        /* Registre R92                       */
#define R93                  93        /* Registre R93                       */
#define R94                  94        /* Registre R94                       */
#define R95                  95        /* Registre R95                       */
#define R96                  96        /* Registre R96                       */
#define R97                  97        /* Registre R97                       */
#define R98                  98        /* Registre R98                       */
#define R99                  99        /* Registre R99                       */
#define R100                100        /* Registre R100                      */
#define R101                101        /* Registre R101                      */
#define R102                102        /* Registre R102                      */
#define R103                103        /* Registre R103                      */
#define R104                104        /* Registre R104                      */
#define R105                105        /* Registre R105                      */
#define R106                106        /* Registre R106                      */
#define R107                107        /* Registre R107                      */
#define R108                108        /* Registre R108                      */
#define R109                109        /* Registre R109                      */
#define R110                110        /* Registre R110                      */
#define R111                111        /* Registre R111                      */
#define R112                112        /* Registre R112                      */
#define R113                113        /* Registre R113                      */
#define R114                114        /* Registre R114                      */
#define R115                115        /* Registre R115                      */
#define R116                116        /* Registre R116                      */
#define R117                117        /* Registre R117                      */
#define R118                118        /* Registre R118                      */
#define R119                119        /* Registre R119                      */
#define R120                120        /* Registre R120                      */
#define R121                121        /* Registre R121                      */
#define R122                122        /* Registre R122                      */
#define R123                123        /* Registre R123                      */
#define R124                124        /* Registre R124                      */
#define R125                125        /* Registre R125                      */
#define R126                126        /* Registre R126                      */
#define R127                127        /* Registre R127                      */


/* Alias des registres reserves communs .....................................*/

#define LINK                125        /* Registre de LINK pour GOSUB/RETURN */
#define TERR                126        /* Code d'erreur                      */
#define PSTACK              127        /* Pointeur de pile pour PUSH/POP     */
 

/* Numeros "indirects" des registres 32 bits --------------------------------*/

#define IR0                 128        /* Registre R0                        */
#define IR1                 129        /* Registre R1                        */
#define IR2                 130        /* Registre R2                        */
#define IR3                 131        /* Registre R3                        */
#define IR4                 132        /* Registre R4                        */
#define IR5                 133        /* Registre R5                        */
#define IR6                 134        /* Registre R6                        */
#define IR7                 135        /* Registre R7                        */
#define IR8                 136        /* Registre R8                        */
#define IR9                 137        /* Registre R9                        */
#define IR10                138        /* Registre R10                       */
#define IR11                139        /* Registre R11                       */
#define IR12                140        /* Registre R12                       */
#define IR13                141        /* Registre R13                       */
#define IR14                142        /* Registre R14                       */
#define IR15                143        /* Registre R15                       */
#define IR16                144        /* Registre R16                       */
#define IR17                145        /* Registre R17                       */
#define IR18                146        /* Registre R18                       */
#define IR19                147        /* Registre R19                       */
#define IR20                148        /* Registre R20                       */
#define IR21                149        /* Registre R21                       */
#define IR22                150        /* Registre R22                       */
#define IR23                151        /* Registre R23                       */
#define IR24                152        /* Registre R24                       */
#define IR25                153        /* Registre R25                       */
#define IR26                154        /* Registre R26                       */
#define IR27                155        /* Registre R27                       */
#define IR28                156        /* Registre R28                       */
#define IR29                157        /* Registre R29                       */
#define IR30                158        /* Registre R30                       */
#define IR31                159        /* Registre R31                       */
#define IR32                160        /* Registre R32                       */
#define IR33                161        /* Registre R33                       */
#define IR34                162        /* Registre R34                       */
#define IR35                163        /* Registre R35                       */
#define IR36                164        /* Registre R36                       */
#define IR37                165        /* Registre R37                       */
#define IR38                166        /* Registre R38                       */
#define IR39                167        /* Registre R39                       */
#define IR40                168        /* Registre R40                       */
#define IR41                169        /* Registre R41                       */
#define IR42                170        /* Registre R42                       */
#define IR43                171        /* Registre R43                       */
#define IR44                172        /* Registre R44                       */
#define IR45                173        /* Registre R45                       */
#define IR46                174        /* Registre R46                       */
#define IR47                175        /* Registre R47                       */
#define IR48                176        /* Registre R48                       */
#define IR49                177        /* Registre R49                       */
#define IR50                178        /* Registre R50                       */
#define IR51                179        /* Registre R51                       */
#define IR52                180        /* Registre R52                       */
#define IR53                181        /* Registre R53                       */
#define IR54                182        /* Registre R54                       */
#define IR55                183        /* Registre R55                       */
#define IR56                184        /* Registre R56                       */
#define IR57                185        /* Registre R57                       */
#define IR58                186        /* Registre R58                       */
#define IR59                187        /* Registre R59                       */
#define IR60                188        /* Registre R60                       */
#define IR61                189        /* Registre R61                       */
#define IR62                190        /* Registre R62                       */
#define IR63                191        /* Registre R63                       */
#define IR64                192        /* Registre R64                       */
#define IR65                193        /* Registre R65                       */
#define IR66                194        /* Registre R66                       */
#define IR67                195        /* Registre R67                       */
#define IR68                196        /* Registre R68                       */
#define IR69                197        /* Registre R69                       */
#define IR70                198        /* Registre R70                       */
#define IR71                199        /* Registre R71                       */
#define IR72                200        /* Registre R72                       */
#define IR73                201        /* Registre R73                       */
#define IR74                202        /* Registre R74                       */
#define IR75                203        /* Registre R75                       */
#define IR76                204        /* Registre R76                       */
#define IR77                205        /* Registre R77                       */
#define IR78                206        /* Registre R78                       */
#define IR79                207        /* Registre R79                       */
#define IR80                208        /* Registre R80                       */
#define IR81                209        /* Registre R81                       */
#define IR82                210        /* Registre R82                       */
#define IR83                211        /* Registre R83                       */
#define IR84                212        /* Registre R84                       */
#define IR85                213        /* Registre R85                       */
#define IR86                214        /* Registre R86                       */
#define IR87                215        /* Registre R87                       */
#define IR88                216        /* Registre R88                       */
#define IR89                217        /* Registre R89                       */
#define IR90                218        /* Registre R90                       */
#define IR91                219        /* Registre R91                       */
#define IR92                220        /* Registre R92                       */
#define IR93                221        /* Registre R93                       */
#define IR94                222        /* Registre R94                       */
#define IR95                223        /* Registre R95                       */
#define IR96                224        /* Registre R96                       */
#define IR97                225        /* Registre R97                       */
#define IR98                226        /* Registre R98                       */
#define IR99                227        /* Registre R99                       */
#define IR100               228        /* Registre R100                      */
#define IR101               229        /* Registre R101                      */
#define IR102               230        /* Registre R102                      */
#define IR103               231        /* Registre R103                      */
#define IR104               232        /* Registre R104                      */
#define IR105               233        /* Registre R105                      */
#define IR106               234        /* Registre R106                      */
#define IR107               235        /* Registre R107                      */
#define IR108               236        /* Registre R108                      */
#define IR109               237        /* Registre R109                      */
#define IR110               238        /* Registre R110                      */
#define IR111               239        /* Registre R111                      */
#define IR112               240        /* Registre R112                      */
#define IR113               241        /* Registre R113                      */
#define IR114               242        /* Registre R114                      */
#define IR115               243        /* Registre R115                      */
#define IR116               244        /* Registre R116                      */
#define IR117               245        /* Registre R117                      */
#define IR118               246        /* Registre R118                      */
#define IR119               247        /* Registre R119                      */
#define IR120               248        /* Registre R120                      */
#define IR121               249        /* Registre R121                      */
#define IR122               250        /* Registre R122                      */
#define IR123               251        /* Registre R123                      */
#define IR124               252        /* Registre R124                      */
#define IR125               253        /* Registre R125                      */
#define IR126               254        /* Registre R126                      */
#define IR127               255        /* Registre R127                      */


/* Valeurs possibles du parametre "act" de l'instruction STOC ...............*/

#define INT1               0x01        /* Copier un octet                    */
#define INT2               0x02        /* Copier un SHORT/USHORT             */
#define INT4               0x04        /* Copier un INT/UINT                 */
#define LSB2               0x12        /* b0..7   b8..15                     */
#define LSB4               0x14        /* b0..7   b8..15  b16..23 b24..31    */
#define MSB2               0x22        /* b8..15  b0..7                      */
#define MSB4               0x24        /* b24..31 b16..23 b8..15  b0..7      */


/* Contexte de la procedure "run_emu32" -------------------------------------*/

#define GLO_NB              256        /*                                    */
#define LOC_NB             1024        /*                                    */
#define TSTACK               64        /*                                    */
#define NBTASK                8        /* Monte de 4 a 8 taches              */
#define NBREF                 8        /*                                    */


/*****************************************************************************
 * RESOLUTION DES INDIRECTION SUR LES REGISTRES                              *
 * Le define ci-dessous sert a ameliorer la lisibilite des proceduresqui     *
 * sont les traitements des instructions, tout en veillant a l'optimisation  *
 * de celles-ci en temps de traitement. Il devrait aussi permettre d'eviter  *
 * des erreurs a force de reprendre les memes instructions.                  *
 * NB: ce define est utilise en version de production, quand TEST_INT n'est  *
 * defini et remplace la procedure "chk_reg()".                              *
 *****************************************************************************/


#define GET_REG(reg,adi,r) if ((r=adi) & 0x80) r = reg[r-128] ;


/*
    2    Structures and typedefs
    ____________________________
*/


typedef struct                         /* Description d'un programme EMU32   */
  BEGIN                                /* ---------------------------------- */
    const UCHAR    *pgm              ; /* Adresse de debut du programme      */
    USHORT         *psub             ; /* Positions des instructions SUB     */
    USHORT         *pdata            ; /* Position des instructions DATA     */
    USHORT         *plabel           ; /* Position des instructions LABEL    */
    USHORT         *flabel           ; /* Indices dans le tableau plabel     */
    void           (*const* inst)()  ; /* Ad tableau Ad de procedures        */
    const UCHAR    *size             ; /* Ad tableau de longueurs d'instr    */
    USHORT          tsubsize         ; /* Taille des tableau psub et flabel  */
    USHORT          tdatasize        ; /* Taille du tableau pdata            */
    USHORT          tlabsize         ; /* Taille du tableau plabel           */
    USHORT          padding          ; /* Aligner sur limite de 4 octets     */
  END               P32_desc         ; /* ---------------------------------- */

typedef struct                         /* Contexte d'execution               */
  BEGIN                                /* ---------------------------------- */

     /* Variables visibles du programme .....................................*/

    INT             reg[128]         ; /* Les 128 registres generaux         */
    INT             n                ; /* Numero de programme courant        */
    INT             sub              ; /* Numero de sous-programme courant   */
    INT             iptr             ; /* Registre pointeur d'instruction    */
    INT             task             ; /* Numero de la tache courante        */
    INT            *stack            ; /* Ad de la pile courante PUSH/POP    */
    UCHAR          *adi              ; /* Adresse de l'instruction courante. */
    UCHAR           cinst            ; /* Code de l'instruction courante.    */
    UCHAR           estop            ; /* Variable d'arret de l'interpreteur.*/

    /* Variables non visibles du programme ..................................*/

    USHORT          nbtask           ; /* Nombre de piles (1 a NBTASK)       */
    INT             siptr  [NBTASK]  ; /* Sauvegardes des registres IPTR     */
    INT             spstack[NBTASK]  ; /* Sauvegardes des registres PSTACK   */
    INT             slink  [NBTASK]  ; /* Sauvegardes des registres LINK     */
    INT            *stack0           ; /* Ad de la pile de numero 0          */
    UCHAR           ref    [NBREF ]  ; /* References a d'autres programmes   */

    /* Adresses et valeurs copies depuis la structure P32_desc ..............*/

    const UCHAR    *pgm              ; /* Adresse de debut du programme      */
    USHORT         *psub             ; /* Positions des instructions SUB     */
    USHORT         *pdata            ; /* Position des instructions DATA     */
    USHORT         *plabel           ; /* Position des instructions LABEL    */
    USHORT         *flabel           ; /* Indices dans le tableau plabel     */
    void           (*const* inst)()  ; /* Ad tableau Ad de procedures        */
    const UCHAR    *size             ; /* Ad tableau de longueurs d'instr    */
    USHORT          tsubsize         ; /* Taille des tableau psub et flabel  */
    USHORT          tdatasize        ; /* Taille du tableau pdata            */
    USHORT          tlabsize         ; /* Taille du tableau plabel           */
    USHORT          padding          ; /* Aligner sur limite de 4 octets     */
  END               E32_ctx          ; /* ---------------------------------- */


/*****************************************************************************
 * Pour les programmes de tests                                              *
 * - Elt         Une instruction d'un programme de test (5 INTs)             *
 * - Test_desc   Regroupe les 3 adresses d'un bloc de tests                  *
 *****************************************************************************/


/* Une instruction d'un programme de test -----------------------------------*/

typedef UINT        Elt[5]           ; /* Une instruction est 5 UINTs        */


/* Un bloc de tests ---------------------------------------------------------*/

typedef struct                         /* ---------------------------------- */
  BEGIN                                /* Description d'une suite de tests   */
    Elt           **test             ; /* Ad tableau d'ad de tableaux de Elt */
    CHAR          **nomtest          ; /* AD tableau d'ad de chaines         */
    UCHAR         **buffer           ; /* Ad tableau d'ad                    */
  END               Test_desc        ; /* -----------------------------------*/


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    _____________________________________
*/


  IWORD init_pgm32          (const UCHAR*,INT,INT,void (*const*)()            ,
                             const UCHAR*                                    );
  IWORD end_pgm32           (const UCHAR*                                    );
  IWORD init_emu32          (E32_ctx*,INT*,INT,const UCHAR*,INT              );
  IWORD link_emu32          (E32_ctx*,INT,UCHAR*                             );
  void  run_emu32           (E32_ctx*,S_evt*                                 );
  void  reg_get             (UCHAR*,UCHAR*,INT                               );
  void  reg_set             (UCHAR*,UCHAR*,INT                               );


#endif                                 /* End of EMU32_H.                    */
