/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/engine.h"              */
/*  Constants and definitions for automaton engine.                          */
/*                                                                           */
/*  Author : FA/JYA                     Last modification : 07/31/2019       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef ENGINE_H                       /* If this file is not already        */
#define ENGINE_H                       /* included, include it.              */


/*
    1    Defines
    ____________
*/


/* Penser a tenir a jour vmk2.c .............................................*/

#define EVT_PASS1          (INT)0x00000000  /* Passe 1                       */
#define EVT_PASS2          (INT)0x00008000  /* Passe 2                       */
#define EVT_MASK_DRVKBD    (INT)0x00000001  /* Mask driver clavier           */
#define EVT_MASK_DRVMSE    (INT)0x00000002  /* Mask driver souris            */
#define EVT_MASK_DRVCHR    (INT)0x00000004  /* Mask driver caractere         */
#define EVT_MASK_TLCM      (INT)0x00000008  /* Mask telecom                  */
#define EVT_MASK_DRVBLK    (INT)0x00000010  /* Mask driver block             */
#define EVT_MASK_AUTKBD    (INT)0x00000020  /* Mask automate clavier         */
#define EVT_MASK_AUTMSE    (INT)0x00000040  /* Mask automate souris          */
#define EVT_MASK_WTA       (INT)0x00000080  /* Mask Warning Trace Alarm      */
#define EVT_MASK_EXPOSE    (INT)0x00000100  /* Mask expose win manager       */
#define EVT_MASK_MODEND    (INT)0x00000200  /* Mask fin de module            */
#define EVT_MASK_TLLOAD    (INT)0x00000400  /* Mask telechargement           */
#define EVT_MASK_AC        (INT)0x00000800  /* Mask controle d'acces         */
#define EVT_MASK_INTERN    (INT)0x00001000  /* Mask autre evts internes      */
#define EVT_MASK_OTHERS    (INT)0x00002000  /* Mask evenement > 256          */


/* Masques sur evts pour tests et transcodage par defaut ....................*/

#define EVT_EQUAL          (INT)0x00000001  /* Valeur exacte                 */
#define EVT_ANY            (INT)0x00000002  /* Tous les codes                */
#define EVT_LIMITS         (INT)0x00000004  /* Bornes                        */
#define EVT_LIST           (INT)0x00000008  /* Elements liste bornee         */
#define EVT_TYPE           (INT)0x00000010  /* Type d'evenements             */
#define RES_EQUAL          (INT)0x00000001  /* Valeur exacte                 */
#define RES_ANY            (INT)0x00000002  /* Tous les reserves             */
#define RES_LIMITS         (INT)0x00000004  /* Bornes                        */
#define RES_LIST           (INT)0x00000008  /* Elements liste bornee         */
#define RES_MASK           (INT)0x00000010  /* Application d'un masque       */
#define PRI_STD                0  /* Event_filter: NFA_STD_P3      */
#define PRI_SRV                1  /* Event_filter: NFA_STD_PS      */


/* Valeurs speciales du champ "longueur" ....................................*/

#define OLD_SESSID            -2  /* Evenement obsolete            */


/*****************************************************************************
 * Codes d'evenements du VMOS : Il faut imperativement modifier le tableau   *
 * "nomcode[]" qui se trouvent dans "vmk/vmk2.c" des que l'on ajoute /       *
 * detruit / modifie un de ces define. L'ajout ne doit pas se faire          *
 * "a l'economie", c'est-a-dire en se contentant de rajouter le code a la    *
 * fin de la liste, en utilisant le premier numero libre. Meme si les numeros*
 * doivent etre re-affectes et que cela prend du temps, il faut le faire.    *
 * Attention aux codes d'evenements telecom, egalement presents dans les     *
 * handlers en assembleur.                                                   *
 *****************************************************************************/


/* Evenements issus de drivers ..............................................*/

#define DRV_KEY_PRESS          0            /* CLAVIER Touche enfoncee.      */
#define DRV_KEY_RELEASE        1            /* CLAVIER Touche relachee       */
#define DRV_MOUSE_PRESS        2            /* SOURIS  Bouton enfoncee       */
#define DRV_MOUSE_RELEASE      3            /* SOURIS  Bouton relache        */
#define DRV_MOUSE_MOVE         4            /* SOURIS  Deplacement           */
#define DRV_TOUCH_PRESS        5            /* Evenement appui tactile       */
#define DRV_TOUCH_RELEASE      6            /* Evenement relacher tactile    */
#define DRV_TOUCH_MOVE         7            /* Evenement deplacement tactile */
#define SMARTCARD_EVT          8            /* Presence/Abscence carte a puce*/
#define IND_POWER              9            /* Changement d'etat alimentation*/

/* Evenements issus de drivers EEPROM/FLASH .................................*/

#define PLR_DONE              10            /* PLR ok.                       */
#define PLR_ERROR             11            /* PLR impossible -> formatter.  */
#define ERASE_DONE            12            /* Erase completion event        */
#define ERASE_ERROR           13            /* Erase error event             */
#define PGM_DONE              14            /* Program completion event      */
#define PGM_ERROR             15            /* Program error event           */
#define BACKUP_WRITE          16            /* EEPROM request event          */
#define BACKUP_DONE           17            /* EEPROM completion  event      */
#define BACKUP_ERROR          18            /* Error       event             */
                                            /* 19 Unused                     */

#define EXPOSE_EVENT          20            /* WINDOW  Retracer fenetre      */
#define MOVE_CURSOR_END       21            /* MOVE_CURSOR fin d'execution   */
                                            /* 22..29 Inutilises             */


/*****************************************************************************
 * L'ordre relatif de AUT_KEY_SHORT a AUT_KEY_RELEASE ne doit PAS etre       *
 * modifie, de meme que l'ordre relatif de AUT_MOUSE_CLICK a AUT_MOUSE_MOVE. *
 * Ces valeurs servent d'intervales dans la procedure  iepanel_preambule     *
 * (kpaneln.c).                                                              *
 * De plus, la procedure "swi_kbd_select" de "kpan_inst.c" necessite que les *
 * deux groupes d'evenements AUT_KEY_*, PANEL_KEY_* soient obligatoirement   *
 * des codes consecutifs (servent d'indices dans des tableaux) et classes    *
 * dans l'ordre suivant :                                                    *
 * AUT_KEY_SHORT   AUT_KEY_LONG   AUT_KEY_XLONG   AUT_KEY_VALID   AUT_KEY_REL*
 * PANEL_KEY_SHORT PANEL_KEY_LONG PANEL_KEY_XLONG PANEL_KEY_VALIF PANEL_KEY_R*
 * Verifier dans ioaut.c ce qui est fait avec haut_rte[256] ...              *
 * Les numeros d'automates y sont redefinis, des tas d'evts des offsets dans *
 * des structures C.                                                         *
 *****************************************************************************/


#define PANEL_INIT            30            /* PANEL  Initialisation panel   */
#define PANEL_END             31            /* PANEL  Termination panel      */
#define PANEL_REFRESH         32            /* PANEL  Raffraichissement panel*/
#define PO_MOUSE_CLICK        33            /* WIDGET Click souris           */
#define PO_MOUSE_DCLICK       34            /* WIDGET Double-click souris    */
#define PO_MOUSE_CONTINUE     35            /* WIDGET Click continue         */
#define PO_MOUSE_RELEASE      36            /* WIDGET Relachement souris     */
#define PO_MOUSE_MOVE         37            /* WIDGET Mouvement souris       */
#define PO_MOUSE_ENTER        38            /* WIDGET Entree focus souris    */
#define PO_MOUSE_LEAVE        39            /* WIDGET Sortie focus souris    */
#define PO_KEY_SHORT          40            /* WIDGET Touche courte          */
#define PO_KEY_RELEASE        41            /* WIDGET Touche relachee        */
#define PO_KEY_ENTER          42            /* WIDGET Entree focus clavier   */
#define PO_KEY_LEAVE          43            /* WIDGET Sortie focus souris    */
#define PO_DEF_ENTER          44            /* WIDGET Entree focus defaut    */
#define PO_DEF_LEAVE          45            /* WIDGET Sortie focus defaut    */
#define PO_GRP_ENTER          46            /* WIDGET Selection groupe       */
#define PO_GRP_LEAVE          47            /* WIDGET Deselection groupe     */
#define PO_REFRESH            48            /* WIDGET Raffraichissement      */
                                            /* 49 Unused                     */
#define PO_KEY_LONG           50            /* WIDGET Touche longue          */
#define PO_KEY_XLONG          51            /* WIDGET Touche tres longue     */
#define PO_KEY_VALID          52            /* WIDGET Touche validee         */
#define PO_VALK_SHORT         53            /*                               */
#define PO_VALK_LONG          54            /*                               */
#define PO_VALK_XLONG         55            /*                               */
#define PO_VALK_RELEASE       56            /*                               */
#define PO_VALK_ENTER         57            /*                               */
#define PO_VALK_LEAVE         58            /*                               */
#define PO_VALK_VALID         59            /* Validation touche validation. */
                                            /*                               */
#define AUT_KEY_SHORT         60            /* KBD    Appui court            */
#define AUT_KEY_LONG          61            /* KBD    Appui long             */
#define AUT_KEY_XLONG         62            /* KBD    Appui tres long        */
#define AUT_KEY_VALID         63            /* KBD    Appui valide           */
#define AUT_KEY_RELEASE       64            /* KBD    Relachement            */
#define AUT_MOUSE_CLICK       65            /* MOUSE  Simple click           */
#define AUT_MOUSE_DCLICK      66            /* MOUSE  Double click           */
#define AUT_MOUSE_CONTINUE    67            /* MOUSE  Pression continue      */
#define AUT_MOUSE_RELEASE     68            /* MOUSE  Relachement            */
#define AUT_MOUSE_MOVE        69            /* MOUSE  Deplacement souris     */
                                            /*                               */
#define PANEL_KEY_SHORT       70            /* PANEL  Touche appui court     */
#define PANEL_KEY_LONG        71            /* PANEL  Touche appui long      */
#define PANEL_KEY_XLONG       72            /* PANEL  Touche appui tres long */
#define PANEL_KEY_VALID       73            /* PANEL  Touche validee         */
#define PANEL_KEY_RELEASE     74            /* PANEL  Touche relachee        */
#define PANEL_MOUSE_CLICK     75            /* PANEL  Simple click           */
#define PANEL_MOUSE_DCLICK    76            /* PANEL  Double click           */
#define PANEL_MOUSE_CONT      77            /* PANEL  Appui continu          */
#define PANEL_MOUSE_REL       78            /* PANEL  Relachement souris     */
#define PANEL_MOUSE_MOVE      79            /* PANEL  Deplacement souris     */
                                            /* 69     Inutilise              */
#define PANEL_SHOW            80            /* PANEL  va etre cache          */
#define PANEL_HID             81            /* PANEL  va etre montre         */
#define PANEL_RAISE           82            /* PANEL  va etre place au dessus*/
#define PANEL_LOWER           83            /* PANEL  va etre place en dessou*/
#define PANEL_RESIZE          84            /* Fond du widget redimensionne. */
#define PANEL_SET_POS         85            /* Fond du widget repositionne.  */
#define PANEL_DRAW            86            /* Evenement trace/refresh widget*/
#define PANEL_CLEAR           87            /* Evenement trace/refresh widget*/
                                            /* 78 Unused                     */
                                            /* 79 Unused                     */
#define PANEL_KEY_ENTER       90            /* Evenement trace/refresh widget*/
#define PANEL_KEY_LEAVE       91            /* Evenement trace/refresh widget*/
#define PANEL_MOUSE_ENTER     92            /* Evenement trace/refresh widget*/
#define PANEL_MOUSE_LEAVE     93            /* Evenement trace/refresh widget*/
#define PANEL_REQ             94            /* Requete pour les panels.      */
#define PANEL_REQ_DONE        95            /* Requete terminee avec succes. */
#define PANEL_REQ_ERROR       96            /* Requete terminee avec erreur. */
#define PANEL_REQ_DRAW        97            /* PANEL_DRAW envoyes.           */
#define DEF_KEY               98            /* PANDEF Clavier non utilise    */
#define DEF_MOUSE             99            /* PANDEF Souris  non utilisee   */
                                            /*                               */
#define SET_LANGUAGE_END     100            /* SET_LG fin de MAJ language    */
                                            /* 101 to 109 Unused             */

/* Evenements issus des thread / scripts / telechargements ..................*/

#define THREAD_START         110            /* Debut de thread.              */
#define THREAD_INTR          111            /* Interruption de thread.       */
#define THREAD_END           112            /* Fin de thread.                */
#define THREAD_ERROR         113            /* Erreur dans un thread.        */
#define REQ_SCRIPT           114            /* SCRIPT  : demande d'execution */
#define RESP_SCRIPT          115            /* SCRIPT  : fin d'execution     */
#define SET_DOWNLOADED       116            /* Fichier ressources telecharge */
#define SET_REF_SOLVED       117            /* References resolues           */
#define SET_INITIALIZED      118            /* Ressources initialisees       */
#define SET_LOADED           119            /* Ressources chargee/utilisable */
#define SET_LOAD_ABORTED     120            /* Chargement ressources annule  */
#define SET_UNLOADED         121            /* Ressources dechargees         */
#define DOWNLOAD_CONF        122            /* DNLOAD Telechargement termine */
#define MODULE_END           123            /* MODULE Indication fin module  */
#define MODULE_UNLOAD_END    124            /* MODULE fin de dechargement    */
                                            /* 125 to 129 Unused             */

/* Evenements du chargeur de librairie dynamique ............................*/

#define DL_OPEN_DONE         130            /* Fin de chargement.            */
#define DL_CLOSE_DONE        131            /* Fin de dechargement           */
                                         
/* Evenements DSMCC .........................................................*/

#define DSMCC_SRG_DONE       132            /* Fin telechargement du SRG     */
#define DSMCC_OBJ_DONE       133            /* Fin telechargement d'un objet */

/* Evenements de l'interpreteur MHEG5 .......................................*/

#define M5_ASY_QUIT          134            /* Fin IHM MHEG-5                */
#define M5_CI_DATA           135            /* Donnees recues module CI/CI+  */

/* Evenements d'emission de messages d'alarme ...............................*/

#define WRITE_ALARM          136            /* Emission d'une alarme.        */
                                            /* 137 to 139 Unused             */




/* Evenements entre app residente et apps interactives ......................*/

#define ITV_INIT             140            /* Evt d'initialisation          */
#define ITV_CMD              141            /* Commande a une app interactive*/
#define ITV_RES              142            /* Evt ress dispos/non dispos    */
#define ITV_SVC              143            /* Transmission mess d'un service*/
#define ITV_END              144            /* Evt de terminaison            */
#define ITV_INFO             145            /* Informations app interactive  */
#define ITV_REQ              146            /* Requete d'une app interactive */
#define ITV_RESTORE          147            /* Retablir reglages multimedia  */
#define ITV_ENO              148            /* Evenement EnOcean PJB Demo    */
                                            /* 149 Unused                    */

/* Evenements en provenance des service .....................................*/

#define REQ_CONF             150            /* Confirmation de reglage       */
#define REQ_SEND             151            /* Information                   */
                                            /* 152 Unused                    */
                                            /* 153 Unused                    */
                                            /* 154 Unused                    */
                                            /* 155 Unused                    */
                                            /* 156 Unused                    */
                                            /* 157 Unused                    */
                                            /* 158 Unused                    */
                                            /* 159 Unused                    */

/* Evenements des Controles d'acces .........................................*/

#define CA_RESP_INIT         160            /* Demarrage controle d'acces.   */
#define CA_RESP_END          161            /* Arret controle d'acces.       */
#define CA_TABLE_SURVEY      162            /* Demande surveillance table DVB*/
#define CA_ACTIVE_EVT        163            /* Etat fonctionnement CA modifie*/
#define CA_CARD_EVT          164            /* Modif du statut CA d'une carte*/
#define CA_RESP_SETVAL       165            /* Reponse modif de parametres.  */
#define CA_RESP_GETVAL       166            /* Reponse de lect de parametres.*/
#define CA_STREAM_STATUS     167            /* Accesssibilite stream elem.   */
#define CA_REQ_PIN           168            /* Requete de code PIN par le CA */
#define CA_RESP_PIN          169            /* Saisie code PIN utilisateur   */
#define CA_REQ_USER          170            /* Requete CA vers utilisateur   */
#define CA_RESP_USER         171            /* Reponse utilisateur.          */
#define CA_IND_REPORT        172            /* Indication CA.                */
#define CA_POPUP             173            /* Gestion de Pop-Up CA.         */
#define CA_SYSTEM_ERR        174            /* Erreur systeme du CA.         */
#define CA_CHANNEL_LOCK      175            /* Verrouillage CA d'un programme*/
                                            /* 176 Inutilise                 */
                                            /* 177 Inutilise                 */
                                            /* 178 Inutilise                 */
                                            /* 179 Inutilise                 */

                                            /* 180 to 189 Unused             */
                                            /* 190 to 199 Unused             */



/* Fin de la tranche reservee 20 A 189 ......................................*/

/* Evenements de l'API Telecom / drivers caracteres .........................*/
/* Attention l'ordre des codes ci-dessous est utilise par la table "dpsaut(]"*/
/* de drv_itf.c                                                              */

#define REQ_INIT             200            /* TLCM Demande initialisation   */
#define REQ_END              201            /* TLCM Demande terminaison      */
#define REQ_ALLOC            202            /* TLCM Demande allocation       */
#define REQ_FREE             203            /* TLCM Demande liberation       */
#define REQ_OPEN             204            /* TLCM Demande ouverture        */
#define REQ_CLOSE            205            /* TLCM Demande fermeture        */
#define REQ_ALLOC_SUB        206            /* TLCM Demande alloc sous-cnl   */
#define REQ_FREE_SUB         207            /* TLCM Demande lib. sous-cnl    */
#define REQ_CONNECT          208            /* TLCM Demande connexion        */
#define REQ_LISTEN           209            /* TLCM Attente connexion        */
#define REQ_DISCONNECT       210            /* TLCM Demande deconnexion      */
#define REQ_ABORT            211            /* TLCM Abandon (de)connexion    */
#define REQ_WRITE            212            /* TLCM Demande emission         */
#define REQ_READ             213            /* TLCM Demande lecture          */
#define REQ_PUT              214            /* TLCM Demande ecriture bloc    */
#define REQ_GET              215            /* TLCM Demande lecture bloc     */
#define REQ_SETVAL           216            /* TLCM Demande parametrage      */
#define REQ_GETVAL           217            /* TLCM Demande lecture param    */
#define REQ_RPC              218            /* TLCM Demande lecture param    */
                                            /* 209 Inutilise                 */
#define RESP_INIT            210            /* TLCM Reponse a REQ_INIT       */
#define RESP_END             211            /* TLCM Reponse a REQ_END        */
#define RESP_ALLOC           212            /* TLCM Reponse a REQ_ALLOC      */
#define RESP_FREE            213            /* TLCM Reponse a REQ_FREE       */
#define RESP_OPEN            214            /* TLCM Reponse a REQ_OPEN       */
#define RESP_CLOSE           215            /* TLCM Reponse a REQ_CLOSE      */
#define RESP_ALLOC_SUB       216            /* TLCM Reponse a REQ_ALLOC_SUB  */
#define RESP_FREE_SUB        217            /* TLCM Reponse a REQ_FREE_SUB   */
#define RESP_CONNECT         218            /* TLCM Reponse a REQ_CONNECT    */
#define RESP_LISTEN          219            /* TLCM Reponse a REQ_LISTEN     */
#define RESP_DISCONNECT      220            /* TLCM Reponse a REQ_DISCONNECT */
#define RESP_ABORT           221            /* TLCM Reponse a REQ_ABORT      */
#define RESP_WRITE           222            /* TLCM Reponse a REQ_WRITE      */
#define RESP_READ            223            /* TLCM Reponse a REQ_READ       */
#define RESP_PUT             224            /* TLCM Reponse a REQ_PUT        */
#define RESP_GET             225            /* TLCM Reponse a REQ_GET        */
#define RESP_SETVAL          226            /* TLCM Reponse a REQ_SETVAL     */
#define RESP_GETVAL          227            /* TLCM Reponse a REQ_GETVAL     */
#define RESP_RPC             228            /* TLCM Reponse a REQ_RPC        */
                                            /* 229 Unused                    */
#define IND_DISCONNECT       230            /* TLCM Indication de deconnexion*/
#define IND_REPORT           231            /* TLCM Indication modif param   */
#define IND_PNP              232            /* TLCM Indication branchement   */
#define IND_DATA             233            /* TLCM Indication de donnees    */
                                            /* 233 Inutilise                 */
                                            /* 234 Inutilise                 */
                                            /* 235 Inutilise                 */
                                            /* 236 Inutilise                 */
                                            /* 237 Inutilise                 */
                                            /* 238 Inutilise                 */
                                            /* 239 Inutilise                 */
#define REQ2RESP (RESP_INIT-REQ_INIT)


#define REQ_ALLOC_BUF        240            /* MEMBUF Demande allocation     */
#define REQ_FREE_BUF         241            /* MEMBUF Demande liberation     */
#define REQ_ALLOC_LINK       242            /* MEMBUF Demande allocation     */
#define REQ_FREE_LINK        243            /* MEMBUF Demande liberation     */
#define REQ_ALLOC_ALI        244            /* MEMBUF Demande allocation     */
#define REQ_REALLOC          245            /* MEMBUF Demande re-allocation  */
#define REQ_POST_BUF         246            /* MEMBUF Demande post_buf       */
#define REQ_TAKE_MUT         247            /* MUTEX Operation request       */
#define REQ_RELEASE_MUT      248            /* MUTEX Operation request       */
                                            /* 249 Unused                    */

#define RESP_ALLOC_BUF       250            /* MEMBUF Reponse a REQ_ALLOC    */
#define RESP_FREE_BUF        251            /* MEMBUF Reponse a REQ_FREE     */
#define RESP_ALLOC_LINK      252            /* MEMBUF Reponse a REQ_ALLOC    */
#define RESP_FREE_LINK       253            /* MEMBUF Reponse a REQ_FREE     */
#define RESP_ALLOC_ALI       254            /* MEMBUF Reponse a REQ_ALLOC_ALI*/
#define RESP_REALLOC         255            /* MEMBUF Reponse a REQ_REALLOC  */
#define RESP_POST_BUF        256            /* MEMBUF Reponse a REQ_POST_BUF */
#define RESP_TAKE_MUT        257            /* MUTEX take response           */
#define RESP_RELEASE_MUT     258            /* MUTEX Operation response      */
                                            /* 259 Unused                    */



/* Evenements de l'API fichier / drivers blocs ..............................*/
/* Attention l'ordre des codes ci-dessous est utilise par la table "volaut(]"*/
/* de dro_itf.c                                                              */

#define REQ_MOUNT            260            /* FILE Demande montage partition*/
#define REQ_UMOUNT           261            /* FILE Demande demontage part   */
#define REQ_VINFO            262            /* FILE Demande info volume      */
#define REQ_CREDIR           263            /* FILE Demande creation dir     */
#define REQ_DELDIR           264            /* FILE Demande destruction dir  */
#define REQ_CREFILE          265            /* FILE Demande creation fichier */
#define REQ_DELFILE          266            /* FILE Demande destruction fic  */
#define REQ_RENFILE          267            /* FILE Demande destruction fic  */
#define REQ_FLIST            268            /* FILE Demande liste de fichiers*/
#define REQ_FINFO            269            /* FILE Demande informations fic */
#define REQ_FOPEN            270            /* FILE Demande ouverture fichier*/
#define REQ_FCLOSE           271            /* FILE Demande fermeture fichier*/
#define REQ_PSEEK            272            /* FILE Demande pos ptr ecriture */
#define REQ_FPUT             273            /* FILE Demande ecriture bloc    */
#define REQ_GSEEK            274            /* FILE Demande pos ptr lecture  */
#define REQ_FGET             275            /* FILE Demande lecture bloc     */
                                            /* 276 Unused                    */
                                            /* 277 Unused                    */
                                            /* 278 Unused                    */
                                            /* 279 Unused                    */
#define RESP_MOUNT           280            /* FILE Reponse montage partition*/
#define RESP_UMOUNT          281            /* FILE Reponse demontage part   */
#define RESP_VINFO           282            /* FILE Reponse info volume      */
#define RESP_CREDIR          283            /* FILE Reponse creation dir     */
#define RESP_DELDIR          284            /* FILE Reponse destruction dir  */
#define RESP_CREFILE         285            /* FILE Reponse creation fichier */
#define RESP_DELFILE         286            /* FILE Reponse destruction fic  */
#define RESP_RENFILE         287            /* FILE Reponse destruction fic  */
#define RESP_FLIST           288            /* FILE Reponse liste de fichiers*/
#define RESP_FINFO           289            /* FILE Reponse informations fic */
#define RESP_FOPEN           290            /* FILE Reponse ouverture fichier*/
#define RESP_FCLOSE          291            /* FILE Reponse fermeture fichier*/
#define RESP_PSEEK           292            /* FILE Reponse pos ptr ecriture */
#define RESP_FPUT            293            /* FILE Reponse ecriture bloc    */
#define RESP_GSEEK           294            /* FILE Reponse pos ptr lecture  */
#define RESP_FGET            295            /* FILE Reponse lecture bloc     */
                                            /* 296 Unused                    */
                                            /* 297 Unused                    */
                                            /* 298 Unused                    */
                                            /* 299 Unused                    */


/* Evenements de l'afficheur des sous-titres DVB ............................*/

#define DVBSTL_STOPPED       380            /* Decodeur afficheur arrete     */
#define DVBSTL_ERR           381            /* Overflow donnees entrantes.   */
#define DVBSTL_DISPLAY       382            /* Demande de flush applicatif.  */
#define DVBSTL_CLEAR         383            /* Demande d'effacement          */
                                            /* 384 Inutilise                 */
                                            /* 385 Inutilise                 */
                                            /* 386 Inutilise                 */
                                            /* 387 Inutilise                 */
                                            /* 388 Inutilise                 */
                                            /* 389 Inutilise                 */


/* Evenements de l'afficheur teletexte ......................................*/

#define TTXT_DISPLAY         390            /* Page    a afficher            */
#define TTXT_HEADER          391            /* En-tete a afficher            */
                                            /* 392 Inutilise                 */
                                            /* 393 Inutilise                 */
                                            /* 394 Inutilise                 */
                                            /* 395 Inutilise                 */
                                            /* 396 Inutilise                 */
                                            /* 397 Inutilise                 */
                                            /* 398 Inutilise                 */
                                            /* 399 Inutilise                 */


/* Codes d'evenements du VMIO ...............................................*/

#define DRV_I2C_END          400            /* Fin E/S I2C                   */
#define EVTS_IO_END          401            /* Fin E/S disque ou autre       */
#define IT_RX                402            /* IT de reception               */
#define IT_TX                403            /* IT de fin d'emission          */
#define IT_INS               404            /* IT insertion de carte         */
#define IT_EXT               405            /* IT extraction de carte        */
#define IT_SYN0              406            /* IT de synchro HDCP            */
#define IT_SYN127            407            /* IT de synchro HDCP            */
#define EVTS_ASY_END         408            /* Fin E/S driver ASY            */
                                            /* 409 Inutilise                 */


/* Evenements de requetes ...................................................*/

#define REQ_CMD              410            /* Demande de demarrage          */
#define REQ_RESET            411            /* Demande reset de carte/device */
#define REQ_PTS              412            /* Demande envoi de PTS          */
#define REQ_WRITES           413            /* Demande ecriture I2C          */
#define REQ_SUBREAD          414            /* Demande select puis lect I2C  */
#define REQ_READES           415            /* Demande lecture I2C           */
#define REQ_WRITEEP          416            /* Demande ecriture EEPROM I2C   */
#define REQ_READEEP          417            /* Demande lecture  EEPROM I2C   */
#define REQ_ENDS             418            /* Demande terminaison systeme   */
#define REQ_CHANGE           419            /* Demande changement de RCU     */

#define RESP_CMD             420            /* Response to REQ_CMD           */
#define RESP_RESET           421            /* Response to REQ_RESET         */

/* Evenements de time-out ...................................................*/

#define TO_POW               430            /* Time-out POWER                */
#define TO_LED               431            /* Time-out LED                  */
#define TO_DIS               432            /* Time-out DISPLAY              */
#define TO_FRE               433            /* Time-out FRONT-END            */
#define TO_SWI               434            /* Time-out SWITCH               */
#define TO_SMC               435            /* Time-out SMC (carte a puce)   */
#define TO_COM               436            /* Time-out I2C                  */
#define TO_STEP              437            /* Time-out etape suivante I2C/  */
#define TO_RCU               438            /* Time-out RCU non reception    */
#define TO_SKIP              439            /* Time-out RCU fin de surdite   */
 
/* Evenements conditions ....................................................*/

#define C_WAIT               440            /* Condition d'attente           */
#define C_ERROR              441            /* Condition d'erreur            */
#define C_RUN                442            /* Condition de lancement        */
#define C_HALT               443            /* Condition d'arret             */
#define C_MORE               444            /* Condition de continuation     */
#define C_OPOSITIF           445            /* Condition RESP_OPEN positif   */
#define C_ONEGATIF           446            /* Condition RESP_OPEN negatif   */
#define C_OPENED             447            /* Ouverture reussie             */
#define C_OPEN               447            /* Ouverture reussie sans err    */
#define C_NOTOPENED          448            /* Ouverture echouee             */
#define C_NOTOPEN            448            /* Ouverture echouee sans err    */
#define C_ERRIO              449            /* Erreur d'entree/sortie        */
#define C_CLOSED             450            /* Driver ferme                  */
#define C_NOMORE             451            /* Negation de C_MORE            */
#define C_INACTIVE           452            /* Desactive                     */
#define C_IDLE               453            /* Au repos                      */
#define C_END                454            /* Fin de sequence               */
#define C_READ               455            /* Lecture a faire               */
#define C_WRITE              456            /* Ecriture a faire              */
#define C_SYN                457            /* IT_SYN en attente             */
                                            /* 458 Unused                    */
                                            /* 459 Unused                    */


/* Evenements de l'automate PVR .............................................*/

#define REL_SHIFT            460            /* Nouvelles donnees timeshift   */
#define DMX_PVR_STA          461            /* Notif chgt etat de dmx_pvr    */
                                            /* 462 Unused                    */
                                            /* 463 Unused                    */
                                            /* 464 Unused                    */
                                            /* 465 Unused                    */
                                            /* 466 Unused                    */
                                            /* 467 Unused                    */
                                            /* 468 Unused                    */
                                            /* 459 Unused                    */


/* Evenements de l'automate DSK .............................................*/

#define TO_DSK1              470            /* Time-out I/O disque           */
#define TO_DSK2              471            /* Time-out standby disque       */
#define BUS_GOT              472            /* Recuperation bus apres attente*/
                                            /* 473 Unused                    */
                                            /* 474 Unused                    */
                                            /* 475 Unused                    */
                                            /* 476 Unused                    */
                                            /* 477 Unused                    */
                                            /* 478 Unused                    */
                                            /* 479 Unused                    */


/* Evenements de l'automate FAN .............................................*/

#define TO_FAN               480            /* Time-out FAN                  */
#define C_SATUR              481            /* Condition PWM sature          */
                                            /* 482 Unused                    */
                                            /* 483 Unused                    */
                                            /* 484 Unused                    */
                                            /* 485 Unused                    */
                                            /* 486 Unused                    */
                                            /* 487 Unused                    */
                                            /* 488 Unused                    */
                                            /* 489 Unused                    */


/* Evenements de l'automate USB .............................................*/

#define USB_CSC              490            /*                               */
#define USB_TORESET          491            /*                               */
#define USB_IOEND            492            /*                               */


/* Evenements de l'automate SCSI ............................................*/

#define TO_SCSI              493            /*                               */
                                            /* 494 Inutilise                 */
                                            /* 495 Inutilise                 */
                                            /* 496 Inutilise                 */
                                            /* 497 Inutilise                 */
                                            /* 498 Inutilise                 */
                                            /* 499 Inutilise                 */

#define PANEL_ID               0            /* Id ressource panel            */
#define DICT_ID                1            /* Id ressource dictionnaire     */
#define CHANNEL_ID             2            /* Id ressource telecom          */
#define EXTERN_ID              3            /* Id ressource applicative      */


/* Evenements de l'automate UMS .............................................*/

#define UMS_INQUIRY          500            /*                               */
#define UMS_RQSENSE          501            /*                               */
#define UMS_TUREADY          502            /*                               */
#define UMS_C_NODATA         503            /*                               */
#define UMS_READ10           504            /*                               */
#define UMS_RCAPACITY        505            /*                               */
#define UMS_WRITE10          506            /*                               */
                                            /* 497 Inutilise                 */
                                            /* 498 Inutilise                 */
                                            /* 499 Inutilise                 */


/*
    2    Structures and typedefs
    ____________________________
*/


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of ENGINE_H.                   */
