/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/setelt.h"              */
/*  Constants and definitions for memory data model.                         */
/*                                                                           */
/*  Author : JYA                        Last modification : 20/08/2018       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef SETELT_H                       /* If this file is not already        */
#define SETELT_H                       /* included, include it.              */


/*
    1    Defines
    ____________
*/


/* Champ "etat" d'un contexte de chargement statique ........................*/

#define STSET_EMPTY              0     /* Vide                               */
#define STSET_WAITING_DOWNLOAD   1     /* Attend fin telechargement fichier  */
#define STSET_WAITING_SOLVE_REF  2     /* Attend fin chargement references   */
#define STSET_WAITING_INIT       3     /* Attend fin initialisation          */
#define STSET_WAITING_LOADED     4     /* Attend passage utilisable          */
#define STSET_LOADED             5     /* Ressources utilisables             */
#define STSET_WAITING_UNLOAD     6     /* Attend fin dechargement            */
#define STSET_WAITING_LOAD       7     /* Attend debut de chargement         */
#define STSET_NB                 8     /* Transition table size              */


/*  Champ "etat" d'une reference ............................................*/

#define STREF_EMPTY           0        /* Vide                               */
#define STREF_DECLARED        1        /* Declaree                           */
#define STREF_SOLVING         2        /* Attend resolution                  */
#define STREF_SOLVED          3        /* Resolue                            */


/*  Macro ...................................................................*/

#define SET_REF_LOAD(a,b)   (a)->load_etat = ((a)->load_etat AND 0x0F) OR \
                                             ((b) << 4);
#define SET_REF_ETAT(a,b)   (a)->load_etat = ((a)->load_etat AND 0xF0) OR \
                                             ((b)     );
#define GET_REF_LOAD(a)   (((a)->load_etat >> 4) AND 0x0F)
#define GET_REF_ETAT(a)   (((a)->load_etat     ) AND 0x0F)

#define HSET_SET(a)    ( (INT)(a)        AND SET_ID_INVALID)
#define HSET_PRI(a)    (((INT)(a) >> 11) AND 0x001F)


/*
    2    Structures and typedefs
    ____________________________
*/


/*  Reference a un ensemble .................................................*/

typedef union                          /* Specifique de definition d'une ref.*/
  BEGIN                                /* ---------------------------------- */
    UCHAR           uc[4]            ; /* 4 UCHAR                            */
    USHORT          us[2]            ; /* 2 USHORT                           */
    UINT            ui               ; /* 1 UINT                             */
    UCHAR          *puc              ; /* 1 pointeur d'UCHAR                 */
  END               Hres_spe         ; /* ---------------------------------- */

typedef struct                         /* Reference a ensemble de ressources */
  BEGIN                                /* ---------------------------------- */
    Hres_spe        spec             ; /* Valeur specifique associee         */
    INT             nom              ; /* Num nom d'ensemble si pas charge OU*/
                                       /* Identifiant d'ensemble si charge   */
    USHORT          prv_set          ; /* Ensemble et num de ref contenant   */
    USHORT          prv_num          ; /* la ref preced. vers meme ensemble  */
    USHORT          nxt_set          ; /* Ensemble et num de ref contenant   */
    USHORT          nxt_num          ; /* la ref suivante vers meme ensemble */
    UCHAR           rid              ; /* Type de ressources d'ensemble OU   */
                                       /* Type de l'ensemble reference       */
    UCHAR           load_etat        ; /* Etat limite chargement ET          */
                                       /* Etat de la reference               */
    UCHAR           prv_type         ; /* Type ensemble ref preced. meme ens.*/
    UCHAR           nxt_type         ; /* Type ensemble ref suiv.   meme ens.*/
                                    
 END                Hres_ref         ; /* ---------------------------------- */


/*  Contexte de chargement ..................................................*/

typedef struct                         /* Contexte statique d'un ensemble    */
  BEGIN                                /* ---------------------------------- */
    USHORT          nb_ref           ; /* Nb ref vers d'autres ensembles     */
    USHORT          fer_set          ; /* Id premier ensemble qui reference  */
    USHORT          fer_num          ; /* Num de ref du premier ensemble     */
    UCHAR           fer_type         ; /* Type du premier ensemble           */
    UCHAR           ldyn             ; /* Contexte dynamique associe         */
    UCHAR           nb_load          ; /* Nombre de demandes de chargement   */
    UCHAR           rid              ; /* Type de ressources                 */
    UCHAR           etat             ; /* Etat du chargement de cet ensemble */
  END               Hres_sta         ; /* ---------------------------------- */

typedef struct                         /* Contexte dynamique d'un ensemble   */
  BEGIN                                /* ---------------------------------- */
    INT             fid              ; /* Identifiant du nom de fichier      */
    USHORT          set              ; /* Numero de l'ensemble dans son type */
    UCHAR           type             ; /* Type de l'ensemble                 */
    UCHAR           rid              ; /* Type de ressources                 */
  END               Hres_dyn         ; /* ---------------------------------- */


/*  Associations nom <-> partie / ensemble ..................................*/

typedef struct                         /* Association nom <-> ensemble       */
  BEGIN                                /* ---------------------------------- */
    INT             num              ; /* Numero du nom                      */
    USHORT          offset           ; /* Offset de l'ensemble dans le type  */
    USHORT          acces            ; /* Droits d'acces                     */
    USHORT          spe              ; /* Specifique au type de l'ensemble   */
    UCHAR           type             ; /* Type de l'ensemble                 */
  END               Hset_nom         ; /* ---------------------------------- */

typedef struct                         /* Association nom <-> partie         */
  BEGIN                                /* ---------------------------------- */
    INT             num              ; /* Numero nom renvoye par id t_add()  */
    USHORT          offset           ; /* Offset de partie dans l'ensemble   */
    USHORT          acces            ; /* Droits d'acces/attributs           */
  END               Helt_nom         ; /* ---------------------------------- */
                                                             
typedef struct                         /* Association nom <-> ensemble       */
  BEGIN                                /* ---------------------------------- */
    IWORD          init              ; /* Numero procedure d'init            */
    UCHAR        **rom               ; /* Adresse de l'ensemble              */
    UCHAR          type              ; /* Type de l'ensemble                 */
    USHORT         offset            ; /* Offset de l'ensemble dans le type  */
  END              Hset_rom          ; /* ---------------------------------- */


/*  Interface vers un module dedie ..........................................*/

typedef struct                         /* Interface pour un type de ressource*/
  BEGIN                                /* ---------------------------------- */

    CHAR           *nom              ; /*                                    */

    /*************************************************************************
     * Les procedures suivantes sont utilisees pour initialiser et finaliser *
     * le module dedie au type de ressources.                                *
     *************************************************************************/

    IWORD           (*init  )(IWORD) ; /*                                    */
    void            (*end   )(IWORD) ; /*                                    */

    /************************************************************************* 
     * Les procedures suivantes sont utilisees lors du chargement d'un       * 
     * fichier de ressources. Elles sont appelees principalement par les     * 
     * procedures de traitement des transitions de l'automate de chargement. * 
     *************************************************************************/

    IWORD           (*load          )(IWORD,CHAR*,IWORD,UCHAR*,USHORT*) ;
    IWORD           (*load_init_ref )(IWORD,IWORD,IWORD,INT,IWORD,IWORD);
    IWORD           (*load_init_res )(IWORD,IWORD,IWORD,IWORD)          ;
    IWORD           (*load_init_exe )(IWORD,IWORD,IWORD)                ;
    IWORD           (*load_abort    )(IWORD,IWORD,IWORD)                ;      
    IWORD           (*unload        )(IWORD,IWORD,IWORD,IWORD,IWORD)    ;
    IWORD           (*unload_end    )(IWORD,IWORD,IWORD,IWORD,IWORD)    ;
    IWORD           (*get_deffil    )(IWORD,CHAR*,CHAR*)                ;
    IWORD           (*get_defext    )(IWORD,CHAR*)                      ;
    IWORD           (*get_defmod    )(IWORD,CHAR*)                      ;
    IWORD           (*get_refres    )(IWORD,INT,CHAR*,INT*)             ;
    IWORD           (*check_module  )(IWORD,IWORD,IWORD,IWORD)          ;

    /*************************************************************************
     * Les valeurs numeriques suivantes sont des indicateurs de comportement *
     * utilises lors du chargement et du dechargement d'un fichier de        *
     * ressources de ce type :                                               *
     * wait_end_unload   : definit le comportement lorsque la procedure      *
     *                     res_load() appelee pour charger une ressource     *
     *                     referencee renvoie le code de retour RES_UNLOAD.  *
     *                     0 : annuler le chargement du fichier de ressources*
     *                     1 : attendre l'evenement RES_UNLOADED puis        *
     *                         rappeler la procedure res_load() pour         *
     *                         essayer de charger la ressource referencee    *
     * share             : ressources partagees (OUI/NON:1/0)                *
     * ernok             : ne pas effacer meme si pas reference (OUI/NON:1/0)*
     * casse             : casse pour les symboles LOWER/UPPER/NOTHING       *
     * vlnam             : variables locales ont un nom (OUI/NON:1/0)        *
     *************************************************************************/

    CHAR            wait_end_unload  ; /* Reaction a RES_UNLOAD.             */
    CHAR            share            ; /* Ressource partagee : 0/1 : NON/OUI */
    CHAR            ernok            ; /* Ne doit pas etre efface meme si pas*/
    CHAR            casse            ; /* Casse des symboles : LOWER/NOTHING */
    CHAR            vlnam            ; /* Var locales ont un nom OUI/NON     */
 
    /*************************************************************************
     * Les procedures suivantes sont utilisees pour initialiser et finaliser *
     * l'interpretation d'instructions de cet interpreteur.                  *
     * Elles sont appelees par le module scr_auto.c                          *
     *************************************************************************/

    const CHAR     *nint             ; /* Nom du language                    */

    IWORD           (*alloc_exe      ) (IWORD,INT,IWORD)         ;
    IWORD           (*free_exe       ) (IWORD,INT,IWORD)         ;
    IWORD           (*select_exe     ) (IWORD,INT,IWORD)         ;
    IWORD           (*unselect_exe   ) (IWORD,INT,IWORD)         ;
    IWORD           (*search_method  ) (CHAR*,INT,INT*,INT*,INT*);
    IWORD           (*get_subset     ) (INT,INT,INT,INT*)        ;
 
    /*************************************************************************
     * L'adresse suivante est l'adresse des adresses de procedure C          *
     * de traitement des micro-instructions utilisees par ce language.       *
     *************************************************************************/

    void (* const *ie_tab)()         ; /* Adr traitements inst elementaires  */
 
    /*************************************************************************
     * Les adresses suivantes sont des adresses de programme de              *
     * micro-instructions utilisees pour executer des actions propres        *
     * a ce languague dans la boucle globale d'interpretation.               *
     *************************************************************************/

    const INT      *preambule        ; /* Reprise de l'execution apres arret */
    const INT      *switch_lang      ; /* Changement de methode librairie    */
    const INT      *read_inst        ; /* Lecture de la prochaine instruction*/
    const INT      *call_1st_method  ; /* Appel de la premiere methode.      */
    const INT      *push_method      ; /* Empiler une methode.               */
    const INT      *end_pop_method   ; /* Finalise depilement d'une methode  */
    const INT      *erreur           ; /* Traitement d'une erreur/exception  */
  END               Hres_int         ; /* reference                          */


/*
    3    Public variable
    _______________________
*/


extern USHORT       hload_etat   []  ; /* Table d'etats voie logique         */
extern UCHAR        hload_sp     []  ; /* Stack pointers                     */
extern UINT         hload_rteid  []  ; /* Table d'etats voie logique         */
extern USHORT       hload_sessid []  ; /* Table d'etats voie logique         */
                                       /*                                    */
extern UCHAR *** const hset_module   ; /* Adresses des ensembles MODULE      */
extern UCHAR *** const hset_script   ; /* Adresse des ensembles scripts      */
extern UCHAR *** const hset_class    ; /* Adresse des ensembles classes      */
extern UCHAR *** const hset_style    ; /* Adresse des ensembles styles       */
extern UCHAR *** const hset_aut      ; /* Adresse des ensembles aut widgets  */
extern UCHAR *** const hset_laf      ; /* Adresse des ensembles laf panels   */
extern UCHAR *** const hset_eadr     ; /*                                    */
extern USHORT    const hset_imax []  ; /*                                    */
extern UCHAR *** const hset_iadr []  ; /*                                    */
                                       /*                                    */
extern const INT       hset_root_init; /*                                    */
extern const INT       hset_root_page; /*                                    */
extern const UCHAR     hres_dyn_max  ; /* Nombre de  chargements             */
                                       /*                                    */
extern Hres_dyn        hres_dyn  []  ; /* Table  des chargements             */
extern Hres_int       *hres_int  []  ; /* Interface de chargement            */
extern UCHAR         **hset_adr  []  ; /*                                    */
                                       /*                                    */
extern CHAR   hres_typ[][RES_SIZE+1] ; /* Type de fichiers _WORK_            */


/*
    4    Prototypes of public procedures
    ____________________________________
*/


  IWORD set_init            (void                                            );
  IWORD set_end             (void                                            );
  IWORD set_res2resid       (CHAR*,UCHAR*                                    );
  IWORD set_resid2res       (INT,CHAR*                                       );
  IWORD set_add_ref         (IWORD,IWORD,CHAR*,CHAR*,CHAR*,IWORD,Hres_ref*   );
  IWORD set_load            (CHAR*,CHAR*,CHAR*,INT*,INT*,INT*,INT*           );
  IWORD set_load2           (IWORD,INT,UCHAR*,USHORT*                        );
  IWORD set_unload          (INT,INT,INT,INT*                                );
  IWORD set_load_abort      (INT,INT,INT*                                    );
  IWORD set_new             (INT,INT,CHAR*,INT*,INT,INT,INT,INT,INT*         );
  IWORD set_del             (INT,INT                                         );
  IWORD set_new_name        (INT,INT,CHAR*,INT,INT,INT*                      );
  IWORD set_new_name2       (INT,INT,INT,INT,INT                             );
  IWORD set_get_name_off    (INT,INT*                                        );
  IWORD set_del_name        (INT,INT,CHAR*,INT*                              );
  IWORD set_del_name2       (INT,INT,INT                                     );
  IWORD set_root_del        (INT                                             );
  IWORD set_root_del2       (INT,INT                                         );
  IWORD elt_new_name        (INT,INT,INT,CHAR*,INT,INT*                      );
  IWORD elt_new_name2       (INT,INT,INT,INT,INT                             );
  IWORD elt_get_name_off    (UCHAR*,INT,INT*                                 );
  IWORD elt_del_name        (INT,INT,INT,CHAR*,INT*                          );
  IWORD elt_del_names       (INT,INT,INT                                     );
  IWORD elt_del_name2       (INT,INT,INT,INT                                 );
  IWORD elt_del_name3       (UCHAR*,INT                                      );
  IWORD set_sch             (CHAR*,INT*,INT*,INT*,INT*                       );
  IWORD elt_sch             (INT,INT,CHAR*,INT*,INT*,INT*                    );
  IWORD set_sch2            (INT,INT*,INT*,INT*                              );
  IWORD elt_sch2            (INT,INT,INT,INT*,INT*                           );
  void  set_move            (UCHAR**,INT,UCHAR*,UCHAR*                       );
  IWORD set_get_name        (INT,INT,INT,CHAR*,INT*                          );
  IWORD elt_get_name        (INT,INT,INT,CHAR*,INT*                          );
  IWORD set_get_name2       (INT,INT,INT,INT*,INT*                           );
  IWORD elt_get_name2       (INT,INT,INT,INT*,INT*                           );
  IWORD elt_new             (INT,INT,INT,CHAR*,INT*,INT,INT*,INT*            );
  IWORD elts_new            (INT,INT,INT,INT,INT*                            );
  IWORD elt_del             (INT,INT,INT*                                    );
  IWORD elt_set_att         (CHAR*,CHAR*,INT ,INT*                           );
  IWORD elt_get_att         (CHAR*,CHAR*,INT*,INT*                           );
  IWORD get_set_max         (INT,INT*,INT*                                   );
  IWORD get_set_id          (CHAR*,INT*,INT*,INT*                            );
  IWORD get_set_name        (INT,INT,CHAR*,INT*                              );
  IWORD get_elt_max         (CHAR*,INT*,INT*                                 );
  IWORD get_elt_id          (CHAR*,CHAR*,INT*,INT*                           );
  IWORD get_elt_name        (INT,INT,CHAR*,INT*                              );
  IWORD set_show            (INT,INT                                         );
  IWORD set_get_deffil      (IWORD,CHAR*,CHAR*                               );
  IWORD set_get_file        (CHAR*,CHAR*,CHAR*,UCHAR*,CHAR*, INT*,INT*       );


#endif                                 /* End of SETELT_H.                   */
