/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/telecom.h"             */
/*  Constants and definitions for tags and general purposes.                 */
/*                                                                           */
/*  Author : FA                         Last modification : 07/15/2019       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef TELECOM_H                      /* If this file is not already        */
#define TELECOM_H                      /* included, include it.              */


/*
    1    Defines
    ____________
*/

/* Parametres flags des interfaces ..........................................*/

/* Ces bits sont expres a la meme position que les bits correspondants dans  */
/* les identifiants memoire "memuid". Prudence s'ils sont decales.           */

#define POOL0         (INT)0x00000000  /* Alloc dans partition 0             */
#define POOL1         (INT)0x00001000  /* Alloc dans partition 1             */
#define POOL2         (INT)0x00002000  /* Alloc dans partition 2             */
#define POOL3         (INT)0x00003000  /* Alloc dans partition 3             */
                                       /*                                    */
#define NBLOCKING_CON (INT)0x00010000  /* Connect/disconnect non bloquants   */
#define NBLOCKING_IO  (INT)0x00020000  /* Read/write         non bloquants   */
#define NBLOCKING_VAL (INT)0x00040000  /* Setval/getval      non bloquants   */
#define NBLOCKING_EXE (INT)0x00080000  /* Execute/RPC        non bloquants   */
#define NBLOCKING_MSK (INT)0x000F0000  /* OR of the 4 previous bits          */
                                       /*                                    */
#define ROUTE_IND     (INT)0x00100000  /* Demande de routage des IND_xxx     */
#define ROUTE_IND2    (INT)0x00200000  /* Demande de routage des IND_xxx     */

#define NOMOREDATA    (INT)0x00000000  /* Trame complete recue               */
#define MOREDATA      (INT)0x00400000  /* Encore des donnees a venir         */
#define OOB           (INT)0x00800000  /* Marquage donnees "out-of-band"     */
                                       /*                                    */
#define CALL          (INT)0x01000000  /* Ouverture en appel.                */
#define LISTEN        (INT)0x02000000  /* Ouverture en ecoute.               */
#define BRUTAL        (INT)0x04000000  /* Deconnexion brutale (non negociee) */
#define SOURCE        (INT)0x08000000  /* Pour "drv_start"                   */
                                       /*                                    */
#define RCV_MODE      (INT)0x10000000  /* Drapeau b28 : mode de remontee.    */
#define   PDU_RCV     (INT)0x00000000  /*   Remontee des donnees PDU par PDU.*/
#define   SOCKET_RCV  (INT)0x10000000  /*   Remontee des donnees par troncons*/
                                       /*                                    */
#define MEM_TYPE      (INT)0x20000000  /* Drapeau b29 : type de memoire.     */
#define   BUFFER_TYPE (INT)0x00000000  /*   Buffer telecom alloue par driver */
#define   ANYMEM_TYPE (INT)0x20000000  /*   Zone memoire fournie par le user */

#define BUF_TYPE      (INT)0x40000000  /* Drapeau b30 : type de buffer       */
#define     DATA_TYPE (INT)0x00000000  /*   Buffer telecom alloue par driver */
#define     LINK_TYPE (INT)0x40000000  /*   Zone memoire fournie par le user */

/* Evenement REPORT - Numeros des tags ......................................*/

#define TAG_ASY_CTS          (INT) 8   /* Driver ASY, tag CTS.               */
#define TAG_ASY_DSR          (INT) 9   /* Driver ASY, tag DSR.               */
#define TAG_ASY_RI           (INT) 10  /* Driver ASY, tag RI.                */
#define TAG_ASY_DCD          (INT) 11  /* Driver ASY, tag DCD.               */

#define TAG_SMC_STATE        (INT) 2   /* Driver SMC, tag STATE.             */

#define TAG_SWI_INP8TV       (INT) 21  /* Driver SWI, tag INP8_TV.           */
#define TAG_SWI_INP8VCR      (INT) 27  /* Driver SWI, tag INP8_VCR.          */
#define TAG_SWI_VIDSYNC      (INT) 36  /* Driver SWI, tag INP8_VCR.          */

#define TAG_VID_XPS          (INT)  0  /* Driver VID, tag XPS                */
#define TAG_VID_YPS          (INT)  1  /* Driver VID, tag YPS                */
#define TAG_VID_WPS          (INT)  2  /* Driver VID, tag WPS                */
#define TAG_VID_HPS          (INT)  3  /* Driver VID, tag HPS                */
#define TAG_VID_HSIZE        (INT)  4  /* Driver VID, tag HSIZE              */
#define TAG_VID_VSIZE        (INT)  5  /* Driver VID, tag VSIZE              */
#define TAG_VID_VIDFORMAT    (INT)  6  /* Driver VID, tag VID_FORMAT         */
#define TAG_VID_WSS          (INT)  7  /* Driver VID, tag WSS                */
#define TAG_VID_AFD          (INT)  8  /* Driver VID, tag AFD                */
#define TAG_VID_STATE        (INT)  9  /* Driver VID, tag STATE              */
#define TAG_VID_STATUS       (INT) 10  /* Driver VID, tag STATUS             */
#define TAG_VID_DAFD         (INT) 11  /* Driver VID, tag DAFD               */
#define TAG_VID_DAR          (INT) 12  /* Driver VID, tag DAR                */
#define TAG_VID_DFCXSCALE    (INT) 13  /* Driver VID, tag DFCXSCALE          */
#define TAG_VID_DFCXOFF      (INT) 14  /* Driver VID, tag DFCXOFF            */
#define TAG_VID_DFCYSCALE    (INT) 15  /* Driver VID, tag DFCYSCALE          */
#define TAG_VID_DFCYOFF      (INT) 16  /* Driver VID, tag DFCYOFF            */
#define TAG_VID_PICT_NUM     (INT) 17  /* Driver VID, tag PICT_NUM           */
#define TAG_VID_PICT_FST     (INT) 18  /* Driver VID, tag PICT_FST           */
#define TAG_VID_RSPEED       (INT) 19  /* Driver VID, tag RSPEED             */
#define TAG_VID_DSTATE       (INT) 20  /* Driver VID, tag DSTATE             */

#define TAG_PVR_CURFIL       (INT)  2  /* Driver PVR, tag CURFIL.            */
#define TAG_PVR_STATUS       (INT) 16  /* Driver PVR, tag STATUS.            */

#define TAG_STR_REC_STATE    (INT)  0  /* Driver STR, tag REC_STATE.         */
#define TAG_STR_PLA_STATE    (INT)  1  /* Driver STR, tag PLA_STATE.         */
#define TAG_STR_TSB_STATE    (INT)  2  /* Driver STR, tag TSB_STATE.         */
#define TAG_STR_TSB_MODE     (INT)  3  /* Driver STR, tag TSB_MODE.          */
#define TAG_STR_TSB_SPEED    (INT)  4  /* Driver STR, tag TSB_SPEED.         */
#define TAG_STR_TSB_BEGIN    (INT)  5  /* Driver STR, tag TSB_BEGIN.         */
#define TAG_STR_TSB_MRK      (INT)  6  /* Driver STR, tag TSB_MRK.           */
#define TAG_STR_TSB_MRK_OUT  (INT)  7  /* Driver STR, tag TSB_MRK_OUT.       */
#define TAG_STR_PLA_MODE     (INT)  8  /* Driver STR, tag TSB_MODE.          */
#define TAG_STR_PLA_SPEED    (INT)  9  /* Driver STR, tag TSB_MODE.          */
#define TAG_STR_PLA_MRK      (INT) 10  /* Driver STR, tag PLA_MRK.           */
#define TAG_STR_COPYPERCENT  (INT) 11  /* Driver STR, tag COPYPERCENT.       */
#define TAG_STR_PLA_DRV_SEGID (INT) 12 /* Driver STR, tag PLA_DRV_SEGID.     */
#define TAG_STR_TSB_DRV_SEGID (INT) 13 /* Driver STR, tag TSB_DRV_SEGID.     */
#define TAG_STR_MP4_STATUS   (INT) 14  /* Driver STR, tag MP4_STATUS.        */
#define TAG_STR_DEADL        (INT) 15  /* Driver STR, tag DEADL              */
#define TAG_STR_CILIC        (INT) 16  /* Driver STR, tag CILIC (licence CI+)*/
#define TAG_STR_CIPIN        (INT) 17  /* Driver STR, tag CIPIN (PinInfo CI+)*/
#define TAG_STR_HLS_XML      (INT) 18  /* Driver STR, tag HLS_XML            */

#define TAG_FAN_SPEED        (INT)  0  /* Driver FAN, tag SPEED.             */
#define TAG_FAN_TEMP         (INT)  1  /* Driver FAN, tag TEMP.              */

#define TAG_USB_STATE        (INT)  0  /* Driver USB, tag STATE              */

#define TAG_ATA_STATE        (INT)  0  /* Driver disque ATA, tag STATE.      */
#define TAG_ATA_POWER        (INT)  1  /* Driver disque ATA, tag POWER.      */

#define TAG_ETH_STATE        (INT)  0  /* Driver ETH, tag STATE              */

#define TAG_IP_TYPE          (INT)  0  /* Driver IP, tag TYPE                */
#define TAG_IP_ADDRESS       (INT)  1  /* Driver IP, tag ADDRESS.            */
#define TAG_IP_NETMASK       (INT)  2  /* Driver IP, tag NETMASK.            */
#define TAG_IP_GATEWAY       (INT)  3  /* Driver IP, tag GATEWAY.            */
#define TAG_IP_DNS1          (INT)  4  /* Driver IP, tag DNS1.               */
#define TAG_IP_DNS2          (INT)  5  /* Driver IP, tag DNS2.               */
#define TAG_IP_DHCP          (INT)  6  /* Driver IP, tag DHCP.               */
#define TAG_IP_STATE         (INT)  7  /* Driver IP, tag IP_STATE.           */
#define TAG_MIP_GRPEMPTY     (INT) 13  /* Driver IP, multicast tag GRPSTATE  */
#define TAG_MIP_GRPNONEMPTY  (INT) 14  /* Driver IP, multicast tag GRPSTATE  */
#define TAG_TCP_STATE        (INT) 25  /* Driver IP, tag TCP_STATE.          */
#define TAG_TCP_URG          (INT) 26  /* Driver IP, tag URG.                */
#define TAG_TCP_PIPE         (INT) 27  /* Driver IP, pour IND_REPORT fin pipe*/

#define TCP_CLOSED           (INT)  0  /* Driver IP, TCP_STATE=CLOSED        */
#define TCP_LISTEN           (INT)  1  /* Driver IP, TCP_STATE=LISTEN        */
#define TCP_SYN_SENT         (INT)  2  /* Driver IP, TCP_STATE=SYN_SENT      */
#define TCP_SYN_RCVD         (INT)  3  /* Driver IP, TCP_STATE=SYN_RCVD      */
#define TCP_ESTAB            (INT)  4  /* Driver IP, TCP_STATE=ESTAB         */
#define TCP_CLOSE_WAIT       (INT)  5  /* Driver IP, TCP_STATE=CLOSE_WAIT    */
#define TCP_LAST_ACK         (INT)  6  /* Driver IP, TCP_STATE=LAST_ACK      */
#define TCP_FIN_WAIT_1       (INT)  7  /* Driver IP, TCP_STATE=FIN_WAIT_1    */
#define TCP_FIN_WAIT_2       (INT)  8  /* Driver IP, TCP_STATE=FIN_WAIT_2    */
#define TCP_CLOSING          (INT)  9  /* Driver IP, TCP_STATE=CLOSING       */
#define TCP_TIME_WAIT        (INT) 10  /* Driver IP, TCP_STATE=TIME_WAIT     */
                                       
#define TAG_MP3_TYPE         (INT)  0  /* Driver MP3, tag TYPE               */
#define TAG_MP3_NAME         (INT)  1  /* Driver MP3, tag NAME               */
#define TAG_MP3_STATE        (INT)  2  /* Driver MP3, tag STATE              */
#define TAG_MP3_VERSION      (INT)  3  /* Driver MP3, tag VERSION            */
#define TAG_MP3_DURATION     (INT)  4  /* Driver MP3, tag DURATION           */
#define TAG_MP3_INFO         (INT)  5  /* Driver MP3, tag INFO               */
#define TAG_MP3_FNAME        (INT)  6  /* Driver MP3, tag FNAME              */
#define TAG_MP3_VALUE        (INT)  7  /* Driver MP3, tag VALUE              */
#define TAG_MP3_IMGLEN       (INT)  8  /* Driver MP3, tag IMGLEN             */
#define TAG_MP3_IMGTYPE      (INT)  9  /* Driver MP3, tag IMGTYPE            */
#define TAG_MP3_POSITION     (INT) 10  /* Driver MP3, tag POSITION           */

#define TAG_ASI_CARRIER      (INT)  3  /* Driver ASI, tag CARRIER.           */
#define TAG_ASI_SYNC         (INT)  4  /* Driver ASI, tag SYNC.              */
                            
#define TAG_GLUE_STATUS      (INT)  0  /* Driver GLUE, tag STATUS.           */
                            
#define CRC16                (INT)  0  /* Calcul Check-Sum avec CRC16.       */
#define FCS                  (INT)  1  /* Calcul Check-Sum avec FCS.         */
                            
#define COND_GET_TEXT        (INT)  0  /* Demande d'une page html.           */
#define COND_GET_IMAGET      (INT)  1  /* Demande d'une image jpg ou gif.    */
#define COND_DOWNLOAD        (INT)  2  /* Demande d'un volume Hyperpanel.    */
#define COND_SENDREQ         (INT)  3  /* Emission d'une demande a REQUETE.  */
#define COND_SET_QTAB        (INT)  4  /* Mise en attente d'une requete.     */
#define COND_GET_QTAB        (INT)  5  /* Recuperation d'une requete.        */
#define COND_SENDHTTP        (INT)  6  /* Emission d'une reponse a un client.*/
#define DATA_IND_UP          (INT)  7  /* Prise de ligne.                    */
#define DATA_IND_DOWN        (INT)  8  /* Liberation de ligne.               */
#define DATA_IND_RESET       (INT)  9  /* Reset de ligne.                    */

#define TRP_MAGIC1     (INT)0x98DF2289 /* Valeurs des 10 mots magiques       */
#define TRP_MAGIC2     (INT)0x12720A80 /* utilises par "srv_str.c" pour      */
#define TRP_MAGIC3     (INT)0x98385411 /* construire les donnees privees     */
#define TRP_MAGIC4     (INT)0x5A898C12 /* dans un enregistrement de type     */
#define TRP_MAGIC5     (INT)0xBB391304 /* "Transport Stream".                */
#define TRP_MAGIC6     (INT)0x7DD39219 /*                                    */
#define TRP_MAGIC7     (INT)0x02842710 /*                                    */
#define TRP_MAGIC8     (INT)0x8293420E /*                                    */
#define TRP_MAGIC9     (INT)0x238E27C6 /*                                    */

#define STR_FREE        0              /* Contexte de streaming libre.       */
#define STR_HTTP        1              /* Contexte alloue pour HTTP.         */
#define STR_RTP         2              /* Contexte alloue pour RTP.          */



/* Types de tag .............................................................*/

#define TAG_INT            (INT)         0  /* Tag type entier.              */
#define TAG_ENUM           (INT)         1  /* Tag type enumeration.         */
#define TAG_IOD            (INT)         2  /* Tag type IOD.                 */
#define TAG_STR            (INT)         3  /* Tag type chaine.              */
#define TAG_MEM            (INT)         4  /* Tag type zone memoire.        */
#define TAG_LSHT           (INT)         5  /* Tag type liste d'entier SHORT.*/
#define TAG_LINT           (INT)         6  /* Tag type liste d'entier INT.  */


/* Definitions des droits d'acces et classes de procedures ..................*/

#define CLASS_Ax           (INT)         0  /* Classe 0 ALLOC                */
#define CLASS_Sx           (INT)         1  /* Classe 1 ALLOC_SUB*           */
#define CLASS_Cx           (INT)         2  /* Classe 2 OPEN CONNECT         */
#define CLASS_Lx           (INT)         3  /* Classe 3 LISTEN               */
#define CLASS_Ox           (INT)         4  /* Classe 4 SETVAL GETVAL RPC    */
                                            /*                               */
#define BIT_I              (INT)         0  /* Bit 0 Liste d'initialisation  */
#define BIT_W              (INT)         1  /* Bit 1 Liste d'ecriture        */
#define BIT_R              (INT)         2  /* Bit 2 Liste de lecture        */
#define BIT_X              (INT)         3  /* Bit 3 Nom de methode          */
                                            /*                               */
#define TAG_AI             (INT)0x00000001  /* Droit d'acces AI              */
#define TAG_AW             (INT)0x00000002  /* Droit d'acces AW              */
#define TAG_SI             (INT)0x00000010  /* Droit d'acces SI              */
#define TAG_SW             (INT)0x00000020  /* Droit d'acces SW              */
#define TAG_CW             (INT)0x00000200  /* Droit d'acces CW              */
#define TAG_LW             (INT)0x00002000  /* Droit d'acces LW              */
#define TAG_OW             (INT)0x00020000  /* Droit d'acces OW              */
#define TAG_OR             (INT)0x00040000  /* Droit d'acces OR              */
#define TAG_OX             (INT)0x00080000  /* Droit d'acces OX              */
                                            /*                               */
#define TAG_INI            (INT)0x00000011  /* TAG_*I                        */
#define TAG_RO             (INT)0x00040000  /* TAG_*R                        */
#define TAG_WO             (INT)0x00022222  /* TAG_*W                        */
#define TAG_EXE            (INT)0x00080000  /* TAG_*X                        */
#define TAG_RW             (INT)0x00062222  /* TAG_RO | TAG_WO               */
                                            /*                               */
#define MOD_SESSID_CD      (INT)         1  /* Condition mod_sessid_cond ask.*/


/* Numeros de tag pour les IND_REPORT par driver ............................*/

#define TAG_AUD_STATE      (INT)         0  /* Driver AUD, tag STATE.        */
#define TAG_AUD_MPCNL      (INT)         1  /* Driver AUD, tag MPCNL.        */
#define TAG_AUD_AACCNL     (INT)         2  /* Driver AUD, tag AACCNL.       */
                                            
#define TAG_DMX_STATE      (INT)         0  /* Driver DMX, tag STATE.        */
#define TAG_DMX_OUTSTATE   (INT)         1  /* Driver DMX, tag OUT_STATE     */
#define TAG_DMX_VBIVPS     (INT)         2  /* Driver DMX, tag VBI_VPS       */
#define TAG_DMX_VBIWSS     (INT)         3  /* Driver DMX, tag VPI_WSS.      */
#define TAG_DMX_BITRATE    (INT)         4  /* Driver DMX, tag BITRATE       */
                                            
#define TAG_FRE_MODTYPE    (INT)        42  /* Driver FRE, tag MODTYPE       */
#define TAG_FRE_FECRATE    (INT)        43  /* Driver FRE, tag FECRATE       */
#define TAG_FRE_AGC        (INT)        47  /* Driver FRE, tag AGC.          */
#define TAG_FRE_BER        (INT)        48  /* Driver FRE, tag BER.          */
#define TAG_FRE_STATUS     (INT)        49  /* Driver FRE, tag STATUS.       */
#define TAG_FRE_TUNERERR   (INT)        52  /* Driver FRE, tag TUNERERR.     */
#define TAG_FRE_DEMODERR   (INT)        53  /* Driver FRE, tag DEMODERR.     */
                                            
#define TAG_PCMCIA_SLOT    (INT)         3  /* Int PCMCIA, tag SLOTSTATE.    */
#define TAG_PCMCIA_MANU    (INT)         4  /* Int PCMCIA, tag MANU.         */
#define TAG_PCMCIA_PROD    (INT)         5  /* Int PCMCIA, tag PROD.         */
#define TAG_PCMCIA_INTER   (INT)         6  /* Int PCMCIA, tag INTERFACE.    */
#define TAG_PCMCIA_BUFSIZE (INT)         7  /* Int PCMCIA, tag BUFSIZE.      */
                                            
#define TAG_HLS_STATUS     (INT)         0  /* Driver HLS, tag STATUS        */
#define TAG_HLS_PAT        (INT)         1  /* Driver HLS, tag PAT           */
#define TAG_HLS_MESSAGE    (INT)         2  /* Driver HLS, tag MESSAGE       */


/*
    2    Structures and typedefs
    ____________________________
*/


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of TELECOM_H.                  */
