/*****************************************************************************/
/*                                                                           */
/*  HyperPanel OS - App container       File "stm32py/src/vm.h"              */
/*  Constants and definitions specific to stm32py targets.                   */
/*                                                                           */
/*  Author : FA                         Last modification : 02/15/2019       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


#ifndef VM_H                           /* Debut compilation conditionnelle.  */
#define VM_H                           /* Identificateur de cet include.     */

#define VM_STM32M4                     /* Identificateur de VM.              */

#define _LITTLE_ENDIAN_                /* Format interne des mots machines.  */
#define _IOT_                          /* Type de VM Engine.                 */
#define _LIBCALL_DIRECT_               /* Appel direct procedures librairie  */
#define _LIBMEM_                       /* Redefinition des procedures mem*() */
#define _LIBSTR_                       /* Redefinition des procedures str*() */

#include <stdarg.h>                    /* Nombre d'arguments variable        */

                                       /* Definitions de types standards.    */
typedef char             HYPER_CHAR  ; /* Entier signe     sur 1 octet.      */
typedef unsigned char    HYPER_UCHAR ; /* Entier non signe sur 1 octet.      */
typedef short            HYPER_SHORT ; /* Entier signe     sur 2 octets.     */
typedef unsigned short   HYPER_USHORT; /* Entier non signe sur 2 octets.     */
typedef int              HYPER_INT   ; /* Entier signe     sur 4 octets.     */
typedef unsigned int     HYPER_UINT  ; /* Entier non signe sur 4 octets.     */
typedef long long        HYPER_LONG  ; /* Entier signe     sur 8 octets.   */
typedef unsigned long long HYPER_ULONG ; /* Entier non signe sur 8 octets.   */
typedef float            HYPER_FLOAT ; /* Reel             sur 4 octets.     */
typedef double           HYPER_DOUBLE; /* Reel             sur 8 octets.     */

#define HYPER_MAXLONG  (int)0x7FFFFFFF /* Valeur max. pour LONG signe.       */
#define HYPER_MAXULONG (int)0xFFFFFFFF /* Valeur max. pour LONG non signe.   */

#define HYP_BYTE_ORDER   1             /* Format interne des mots machines.  */
#define HNULL            0             /* Pointeur nul.                      */
#define HMAXUIWORD       0xffffffff    /* Valeur maximum mot non signe       */
#define STDEXT           (INT)4        /* Longueur d'une extension de fichier*/
#define NBPT             (INT)16       /* Nb de car. identifiant un nom PTalk*/
#define STDNAME          (INT)32       /* Longueur d'un nom de fichier.      */
#define MAX_DFNAME       (INT)8        /* Longueur max nom  (0 non compris)  */
#define MAX_DISKPATH     (INT)255      /* Longueur max path (0 non compris)  */
#define MAXCPIOBJ        64            /* Nb max d'objets par ctx cpi.       */
#define SCRBIB           20            /* Nb max de bibliotheques par script */
#define H0               0             /* Constante 0 sur 4 octets.          */
#define H1               1             /* Constante 1 sur 4 octets.          */
#define HN              -1             /* Constante -1 sur 4 octets.         */
#define H2               2             /* Constante 2 sur 4 octets.          */
#define SDRAM_SERVICES   320 * 1024    /* Taille donnees applicatives.       */

/* Pour les procedures a nombre de parametres variables                      */

#define VA_ALIST        CHAR *a,...    /*                                    */
#define VA_DCL                         /*                                    */
#define VA_LIST         va_list        /*                                    */
#define VA_START(x)     va_start(x,a)  /*                                    */
#define VA_1ST(x,y)     a              /*                                    */
#define VA_ARG(x,y)     va_arg(x,y)    /*                                    */
#define VA_END(x)       va_end(x)      /*                                    */

/* Passage des octets d'un entier de l'ordre MOTOROLA a l'ordre machine      */
/*                                                                           */
/* /!\ Ces implementations ont le bon gout d'etre transformee en une seule   */
/*     instruction ARM par le compilateur que l'on utilise, et d'etre        */
/*     correctes quand elle sont appelees dans la branche vraie d'un if :    */
/*     if ( ... )                                                            */
/*       MACRO(...);                                                         */
/*     else                                                                  */
/*       ...       ;                                                         */
/*                                                                           */
 
#define SWAP2(a)                       /* Transforme un entier sur           */\
 do { unsigned short *v = a          ; /* 2 octets au format motorola en     */\
    *v = (*v >> 8)                     /* un entier au format machine.       */\
       | (*v << 8)                   ; /*                                    */\
 } while (0)                           /*                                    */

#define SWAP4(a)                       /* Transforme un entier sur           */\
 do { unsigned int *v = a            ; /* 4 octets au format motorola en     */\
    *v = ((*v >> 24)             )     /* 4 octets au format motorola en     */\
       | ((*v >>  8) & 0x0000FF00)     /* un entier au format machine.       */\
       | ((*v <<  8) & 0x00FF0000)     /*                                    */\
       | ((*v << 24)             )   ; /*                                    */\
 } while (0)                           /*                                    */

#define SWAPN(a,n)                     /* Swappe les octets d'un             */\
 do {int _c,_j;UCHAR *_a=(UCHAR*)(a);  /* mot de n octets motorola en un     */\
    for(_j=0;_j LT ((n)>>1);_j++)      /* mot au format machine.             */\
    {_c=*(_a+_j);*(_a+_j)=*(_a+(n)-1-_j);*(_a+(n)-1-_j)=_c;}} while(0)

/* Passage des octets d'un entier de l'ordre machine a l'ordre MOTOROLA      */
 
#define MOTOROLA_2(a)   SWAP2(a)       /* Transforme un entier sur           */\
                                       /* 2 octets au format machine en      */\
                                       /* entier au format motorola.         */

#define MOTOROLA_4(a)   SWAP4(a)       /* Transforme un entier sur           */\
                                       /* 4 octets au format machine en      */\
                                       /* un entier au format motorola.      */\

#define MOTOROLA_N(a,n) SWAPN(a,n)     /* Swappe les octets d'un             */\
                                       /* mot de n octets machine en un      */\
                                       /* mot au format motorola.            */\

/* Passage des octets d'un entier de l'ordre machine a l'ordre INTEL         */
 
#define INTEL_2(a)                     /* Ne rien faire.                     */
#define INTEL_4(a)                     /* Ne rien faire.                     */
#define INTEL_8(a,n)                   /* Ne rien faire.                     */


/*****************************************************************************
 *      Translations entre adresse pour devices et adresse pour CPU.         *
 *****************************************************************************
 * . PHYS_AD transforme une adresse CPU en une adresse physique, pour        *
 *   utilisation directe par un device. Cette macro est volontairement non   *
 *   castee en pointeur, car du point de vue du CPU cette adresse n'est pas  *
 *   valide.                                                                 *
 * . RAM_AD  transforme une physique utilisee par un device en adresse       *
 *   HORS DU CACHE utilisable par le CPU a travers une MMU.                  *
 * . CPU_AD  transforme une physique utilisee par un device en adresse       *
 *   DANS LE CACHE utilisable par le CPU a travers une MMU.                  *
 *****************************************************************************/
      
#define PHYS_AD(x) (UINT)(x)
#define CPU_AD(x)  (UCHAR*)(x)
#define RAM_AD(x)  (UCHAR*)(x)


/*****************************************************************************
 * Barriere memoire.                                                         *
 *****************************************************************************
 * Une barriere memoire est une instruction qui met le CPU en attente de la  *
 * fin de toutes les ecritures precedentes en RAM. Cette instruction est     *
 * utilisee typiquement apres avoir ecrit en RAM des donnees destinees a     *
 * etre lues par le hardware, juste avant de demander au hardware d'aller    *
 * lire ces donnees.                                                         *
 *   On utilise une Data Memory Barrier. Les processeurs ARMv7-M proposent   *
 *   egalement une Data Synchronization Barrier. La premiere interdit toute  *
 *   transaction avec la memoire situee apres la barriere dans l'ordre du    *
 *   programme de s'executer tant que les transactions avec la memoire qui   *
 *   la precedent ne sont pas terminees. La seconde est plus forte et        *
 *   interdit l'execution de TOUTE instruction apres la barriere.            *
 *****************************************************************************/

#define FLUSH_VAR(var) BEGIN __asm__ __volatile__ ("DMB"); END

#ifndef hmemcpy                        /* Specifique windows.                */
#define hmemcpy   memcpy               /* Specifique windows.                */
#endif                                 /* SPecifique windows.                */

#define hsem_init   vmos_sem_i         /* Hyperpanel pour la gestion         */
#define hsem_signal vmos_sem_s         /* des taches.                        */

#endif                                 /* Fin de compilation conditionnelle  */


/*****************************************************************************
 * Alignement memoire.                                                       *
 *****************************************************************************
 * Le standard C le plus recent (C11) specifie un operateur d'alignement.    *
 * Ce n'est pas le meme, mais celui-la est reconnu par GCC et Clang.         *
 * Le plus portable jusqu'a preuve du contraire consiste a le mettre entre   *
 * le type et le nom du premier champ:                                       *
 *                                                                           *
 *     typedef struct                              /+ S                   +/ *
 *       BEGIN                                     /+ ------------------- +/ *
 *         int ALIGN(16) a                       ; /+ Champ a             +/ *
 *         int b                                 ; /+ Champ b             +/ *
 *         int c                                 ; /+ Champ c             +/ *
 *       END S                                   ; /+ ------------------- +/ *
 *                                                                           *
 *****************************************************************************/

#define ALIGN(x) __attribute__((aligned(x)))


void  *memset   ( void *       , int          , unsigned int );
void  *memcpy   ( void *       , const void * , unsigned int );
void  *memmove  ( void *       , const void * , unsigned int );
int    memcmp   ( const void * , const void * , unsigned int );
int    strcmp   ( const char * , const char *                );
int    strncmp  ( const char * , const char * , unsigned int );
char  *strcpy   ( char *       , const char *                );
char  *strncpy  ( char *       , const char * , unsigned int );
char  *strcat   ( char *       , const char *                );
char  *strncat  ( char *       , const char * , unsigned int );
char  *strchr   ( const char * , int                         );
char  *strrchr  ( const char * , int                         );
unsigned int strlen ( const char *                           );
