/*
**  hello_read.c - Sample code for HyperpanelOS ===========================  **
**                                                                           **
**  This simple code is located into the Application Container, it is run    **
**  by the VMK sub-operating system. On the other hand, the I/O container    **
**  runs all the drivers that are VMIO Finite State machines.                **
**                                                                           **
**  The goal of this small aplication is to write a single message           **
**  "Hello World" to serial port ASY0, then read 4 input characters, echo    **
**  each inputted character, and repeat this again and again                 **
**  =======================================================================  **
*/


/* Includes files and external references ...................................*/

#include <hypos.h>                     // Hyperpanel OS basic interfaces
#include <drv_asy.h>                   // Prototype of "asy_write"

#include "./mytsk.h"                   // Interface of "mytsk.c"



/* Beginning of the code ----------------------------------------------------

loop_app_tsk        Entry point for create_task - Main loop

*/


/*  Procedure loop_app_tsk ----------------------------------------------------

    Purpose : This is our task main loop.
*/

int loop_app_tsk (void *param)
  {
    int             cpt              ; // Counter of messages, external loop
    char            mess[80]         ; // Message to be sent
    int             i                ; // Inner Loop counter
    unsigned char   rep              ; // Received input character
    int             ret              ; // Return code for "asy_read"

/*****************************************************************************
 * We have two intricated loops, using "cpt" and "i" as loop counter. At     *
 * each step of the external loop, we print an "Hello World" message. Then   *
 * the inner loop is executed 4 times, at each step we read one character    *
 * we echo it.                                                               *
 *****************************************************************************/

    for ( cpt = 0 ;; cpt++)            // Forever loop
      {
        hsprintf(mess               ,  // We build in "mess" the message
          "\r\n%6d  Hello World : " ,  // to be sent
           cpt                     ) ; //

        asy_write(0              ,     // We write on ASY0
            (unsigned char*)mess ,     // the "mess" message
            strlen(mess)           ) ; // Count of bytes to be sent

        for ( i = 0; i < 4; i++ )      // Read and echo 4 bytes/characters
          {
            asy_read(0     ,           // We read on ASY0
                     &rep  ,           // only 1 character (byte) that
                     1     ,           // we store in the "rep" 1 byte buffer
                     &ret    )       ; // Count of read bytes / error code

            asy_write(0     ,          // We echo on ASY0
                      &rep  ,          // the just received byte
                      1       )      ; //
          }
      }

    return 0                         ;
  }



