/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS - App container       File "vmos/sys/space_appcont.c"      */
/*  App container configurable static data.                                  */
/*                                                                           */
/*  Author : JYA                        Last modification : 11/11/2018       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Purpose of this module
            1.1  Definition of static RAM arrays
            1.2  Inclusion of static ROM data

         2  Include files

         3  External imported variables

         4  Code packages 
            4.xx Package vmk - VMOS kernel
            4.xx Package memory - Memory manager
            4.xx Package file - File system
            4.xx Package varenv - VMOS environment
            4.xx Package module - PanTalk module
            4.xx Package ptkint - PanTalk loader
            4.xx Package style - Widget style loader
            4.xx Package aut - PanTalk automaton loader
            4.xx Package laf - PanTalk Look&Feel loader
            4.xx Package clalib - PanTalk class library
            4.xx Package fileref - General ressource loader
            4.xx Package hypfile - Fichier memoire
            4.xx Package hpchp - HPC interface
            4.xx Package class - PanTalk class
            4.xx Package panel - Panel manager
            4.xx Package exec - Interpreter
            4.xx Package gra - Graphic interface
            4.xx Package telecom - Telecom interface
            4.xx Package message - Message handling
            4.xx Package vminfo - VMOS status
            4.xx Package path - Driver PATH
            4.xx Package pcmcia - PCM driver & DVBCI protocol
            4.xx Package posix - POSIX interface for VMK threads
            4.xx Package pow - POWER driver
            4.xx Package sec - Security driver
            4.xx Package elfdl - Dynamic library
            4.xx Package wbk - WebKit browser
            4.xx Package nfb - NetFront browser
            4.xx Package acces - conditionnal acces
            4.xx Package load - Ressource generic loader
            4.xx Package stm32 - Ressource specific for smt32

         5  vmos_driver table packages

         6  Application langage dictionnaries packages 
            6.1  Packages lg00 - Application language (english) 
            6.2  Packages lg01 - Application language (french) -
            6.3  Packages lg02 - Application language (deutch) -
            6.4  Packages lg03 - Application language (spanish) 
            6.5  Packages lg04 - Application language (italian) 
            6.6  Packages lg05 - Application language (polish) -
            6.7  Packages lg06 - Application language (russian) 
            6.8  Packages lg07 - Application language (turquish)
            6.9  Packages lg08 - Application language (czech) --
            6.10 Packages lg09 - Application language (danish) -
            6.11 Packages lg10 - Application language (dutch) --
            6.12 Packages lg11 - Application language (swedish) 
            6.13 Packages lg12 - Application language (finnish) 
            6.14 Packages lg13 - Application language (greek) --
            6.15 Packages lg14 - Application language (arabic) -
            6.16 Packages lg15 - Application language (galician)

         7  Messages packages
            7.1  Packages msg_err - VMOS error messages
            7.2  Packages msg_war - VMOS warning messages
            7.3  Packages msg_inf - VMOS info messages
            7.4  Packages msg_fil - VMOS file system messages
            7.5  Packages msg_mem - VMOS memory manager messages
            7.6  Packages msg_brw - VMOS browser messages
            7.7  Packages msg_ptk - VMOS PanTalk script messages
            7.8  Packages msg_mth - VMOS PanTalk method messages
            7.9  Packages msg_tlc - VMOS telecom messages
            7.10 Packages msg_pco - VMOS p-code messages
            7.11 Packages msg_cal - VMOS PanTalk procedurescall messages
            7.12 Packages msg_mfi - VMOS file system more messages
            7.13 Packages msg_aut - VMOS automaton messages
            7.14 Packages msg_mme - VMOS memory manager more messages
            7.15 Packages msg_mhg - VMOS MHEG-5 messages
            7.16 Packages msg_thr - VMOS thread messages
            7.17 Packages msg_tcp - VMOS TCP messages
            7.18 Packages msg_tsk - VMOS task manager messages
            7.19 Packages msg_ca  - VMOS Access Control messages
            7.20 Packages msg_ci  - VMOS DCBC-I messages

         8  External exported variables


  
    1    Purpose of this module
    ___________________________


    1.1  Definition of static RAM arrays

         This module contains all the static RAM arrays of the application
container. Each array size is a define which value is defined in one
"space_xx.h" file. By using different copies of the "space_xx.h" file we can
customize the size of the RAM arrays.


         The "space_xx.h" file is normally automatically generated using the
"create" tool from the Hyperpanel workshop. But for IOT's versions of the OS,
we do not deliver the workshop and in such a case the "space_xx.h" file is
created by the developer. We use the term "package" that corresponds to a
fixed set of C modules, for example when the VMOS "File" package is made of 3
C modules that are df.c, mdf.c and hfdisk.c. When this "package" (those 3 C
modules) are used, we need to define 10 RAM arrays that are "df_vol[]",
"df_dsk[]", "df_o[]", "df_ctx[]", "df_etat[]", "df_sp[]", "pdf_ct[]",
"mdf_dfram[]", "mdf_dfrom[]]" and "mdf_mem_fnb[]". The definition of those ten
arrays are located in the present "space_appcont.c" as follows:


#ifdef PKG_file                        /+                                    +/
                                       /+                                    +/
extern  IWORD       init_df(void)    ; /+                                    +/
#define INIT_FILE   init_df          , /+ Initialization procedure           +/
                                       /+                                    +/
const UCHAR  df_maxo   = MAX_FIC     ; /+ Maximum number of opened files     +/
const USHORT df_maxfic = MAX_NBFIC   ; /+ Maximum number of files per direc  +/
const UCHAR  df_maxvol = MAX_VOL     ; /+ Maximum number of volumes          +/
const UCHAR  df_maxdsk = DFMAX_PATH  ; /+ Maximum number of paths            +/
const USHORT df_maxdir = MAX_NBDIR   ; /+ Max repertoire/volume              +/
                                       /+                                    +/
Df_vol       df_vol     [MAX_VOL]    ; /+ Volume table                       +/
Df_dsk       df_dsk     [DFMAX_PATH] ; /+ repertoire                         +/
Df_o         df_o       [MAX_FIC  ]  ; /+ Open files table                   +/
Df_ctx       df_ctx     [MAX_FIC  ]  ; /+ Static context table               +/
USHORT       df_etat    [MAX_FIC*4]  ; /+ Etats et adresses des contextes    +/
UCHAR        df_sp      [MAX_FIC*4]  ; /+ Stack pointers                     +/
Df_ctx      *pdf_ctx    [MAX_FIC*4]  ; /+ d'interpretation de fichiers.      +/
Df_fram     *mdf_dfram  [MAX_NBDIR]  ; /+ Adresses des listes de             +/
Df_from     *mdf_dfrom  [MAX_NBDIR]  ; /+ fichiers RAM et ROM.               +/
SHORT        mdf_mem_fnb[MAX_NBDIR*2]; /+ Nombre de fichiers listes.         +/
                                       /+                                    +/
#else                                  /+                                    +/
#define INIT_FILE                      /+ No initialization procedure in     +/
                                       /+ "henv_start[]"                     +/
#endif                                 /+                                    +/

         In order to be compiled, this piece of code needs that the PKG_file
macro is defined, and that MAX_FIC, MAX_NBFIC, MAX_VOL, DFMAX_PATH and MAX_NBDIR
are defined and are integer constants. Those will be located within one 
"space_xx.h" file, that indeed is inclueded in the present "space_appcont.c".
Here below is an example :

#define PKG_file 
#define MAX_FIC      16 
#define MAX_NBFIC   160 
#define MAX_NBDIR    32 
#define MAX_VOL      16 
#define DFMAX_PATH   12 


         It has to be noted that the source code of the 3 modules df.c, mdf.c 
and hfdisk.c is not provided to customers, that however may be able to customize
the different sizes, without compiling again the source codes that are not
provided. So the source codes df.c, mdf.c and hfdisk.c do not use the defines,
but static const variables "df_maxo", "df_maxfic", "df_maxvol", "df_maxdsk" and
"df_maxdir".

         The present module contains a table named "henv_start[]" that holds a
list of initialization packages procedures that have to be called once upon
application container start. Indeed, this table entry has to contain the address
of the "init_df" procedure only and only if the PKG_file package is used, is
linked to the OS. So the INIT_FILE macro is not empty if the package is used and
other wise it is empty. The INIT_FILE macro is used to initialize one line of
the "henv_start[]" const array.



    1.2  Inclusion of static ROM data

         A package may not include any executable code at all but for example
only RAM or ROM data. For example, the user messages are stored in ROM and each
set of the messages for a dedicated langage is a dedicated package


*/


/* #ifndef _DRO_                           _WORK_ API driver                  */
/* #define drv_getval drv_getval2          _WORK_ API driver                  */
/* #define drv_rpc    drv_rpc2             _WORK_ API driver                  */
/* #endif                                  _WORK_ API driver                  */



/*
    2    Include files
    __________________
*/


#include <autkbd.h>                    /* Structures et constantes autkbd    */
#include <vmk.h>                       /* Moteur definition                  */
#include <drv.h>                       /* Use Lreg                           */
#include <file.h>                      /* Structures file                    */
#include <gra.h>                       /* Structures interface graphique     */
#include <hhpf.h>                      /* Structures fichiers memoire        */
#include <mem_dat.h>                   /* Structure memdat                   */
#include <mem_seg.h>                   /* Structure memseg                   */
#include <memsmall.h>                  /* Structure memsmall                 */
#include <memstr.h>                    /* Structure memstr                   */
#include <module.h>                    /* Constantes de gestion des modules  */
#include <loadm.txt>                   /* RES_SIZE, LOADER/SET_TYPE          */
#include <setelt.h>                    /* Structure Hres_int                 */
#include <varenv.h>                    /* Environnement interface            */
#include <vmk_posix.h>                 /* HPL POSIX implementation.          */
#include <filem.txt>                   /* Mnemoniques extensions de fichiers */
#include <messagem.txt>                /* MERR, MWAR, ...                    */

#ifndef _IOT_                          /* Not an iot profile.                */
#include <dict.h>                      /* Dictionary Dict structure          */
#include <pan.h>                       /* Gestionnaire de panels             */
#endif                                 /* Not an iot profile.                */



/*
    3  External imported variables
    ______________________________
*/

extern const Df_driver  FAT_voldrv   ; /* Desc. interface du driver FAT      */
extern const Df_driver  FDF_voldrv   ; /* Desc. interface du driver FDF      */
extern const Df_driver  HDF_voldrv   ; /* Desc. interface du driver HDF      */
extern const Df_driver  MDF_voldrv   ; /* Desc. interface du driver MDF      */
extern const Df_driver  glue_voldrv  ; /* Desc. interface du driver GLUE     */
extern const Dps_driver asi_driver   ; /* Desc. interface du driver ASI      */
extern const Dps_driver asy_driver   ; /* Desc. interface du driver ASY      */
extern const Dps_driver ata_driver   ; /* Desc. interface du driver ATA      */
extern const Dps_driver aud_driver   ; /* Desc. interface du driver AUD      */
extern const Dps_driver ci_driver    ; /* Desc. interface du driver CI       */
extern const Dps_driver den_driver   ; /* Desc. interface du driver DEN      */
extern const Dps_driver dhcp_driver  ; /* Desc. interface du service DHCP    */
extern const Dps_driver dis_driver   ; /* Desc. interface du driver DIS      */
extern const Dps_driver dmx_driver   ; /* Desc. interface du driver DMX      */
extern const Dps_driver dns_service  ; /* Desc. interface du service DNS     */
extern const Dps_driver dsm_driver   ; /* Desc. interface du driver DSM      */
extern const Dps_driver empty_driver ; /* Desc. interface du driver FAKE vide*/
extern const Dps_driver eno_driver   ; /* Desc. interface du driver ENO      */
extern const Dps_driver eth_driver   ; /* Desc. interface du driver ETH      */
extern const Dps_driver fan_driver   ; /* Desc. interface du driver FAN      */
extern const Dps_driver fcgi_service ; /* Desc. interface du service FASTCGI */
extern const Dps_driver fct_driver   ; /* Desc. interface du driver FACTTEST */
extern const Dps_driver fre_driver   ; /* Desc. interface du driver FRE      */
extern const Dps_driver glue_service ; /* Desc. interface du service GLUE    */
extern const Dps_driver hls_service  ; /* Desc. interface du driver HLS      */
extern const Dps_driver http_service ; /* Desc. interface du driver HTTP     */
extern const Dps_driver ip_driver    ; /* Desc. interface du driver IP       */
extern const Dps_driver kbditf_driver; /* Desc. interface du driver KBDITF   */
extern const Dps_driver led_driver   ; /* Desc. interface du driver LED      */
extern const Dps_driver lo_driver    ; /* Desc. interface du driver LO       */
extern const Dps_driver mp3_service  ; /* Desc. interface du driver MP3      */
extern const Dps_driver nand_driver  ; /* Desc. interface du driver NAND     */
extern const Dps_driver oad_service  ; /* Desc. interface du service OAD     */
extern const Dps_driver pcm_driver   ; /* Desc. interface du driver PCM      */
extern const Dps_driver play_driver  ; /* Desc. interface du driver PLAY     */
extern const Dps_driver pow_driver   ; /* Desc. interface du driver POWER    */
extern const Dps_driver pth_driver   ; /* Desc. interface du driver PATH     */
extern const Dps_driver smc_driver   ; /* Desc. interface du driver SMC      */
extern const Dps_driver so_driver    ; /* Desc. interface du protocole SOCKET*/
extern const Dps_driver stl_driver   ; /* Desc. interface du driver STL      */
extern const Dps_driver str_service  ; /* Desc. interface du driver STR      */
extern const Dps_driver swi_driver   ; /* Desc. interface du driver SWI      */
extern const Dps_driver telnet_service;/* Desc. interface du service TELNET  */
extern const Dps_driver tls_driver   ; /* Desc. interface du driver TLS      */
extern const Dps_driver ums_driver   ; /* Desc. interface du driver UMS      */
extern const Dps_driver usbd_driver  ; /* Desc. interface du driver USBD     */
extern const Dps_driver usbitf_driver; /* Desc. interface du driver USBITF   */
extern const Dps_driver vid_driver   ; /* Desc. interface du driver VID      */
extern const Sys_driver blt_driver   ; /* Desc. interface du driver EEP      */
extern const Sys_driver pipe_driver  ; /* Desc. interface du driver PIPE     */
extern const Sys_driver sec_driver   ; /* Desc. interface du driver SECURITY */
extern const Sys_driver Sys_eep      ; /* Desc. interface du driver EEP      */
extern const Sys_driver gpio_driver  ; /* Desc. interface du driver GPIO     */
extern const Sys_driver dac_driver   ; /* Desc. interface du driver DAC      */
extern const Sys_driver adc_driver   ; /* Desc. interface du driver ADC      */
                                       /*                                    */
extern IWORD init_telecom   (void)   ; /*                                    */
extern IWORD end_telecom    (void)   ; /*                                    */
extern IWORD init_auttime   (void)   ; /*                                    */
extern IWORD end_auttime    (void)   ; /*                                    */
extern IWORD init_autkbd    (void)   ; /*                                    */



/*
    4  Code packages 
    ________________
*/


/* 4.xx Package vmk - VMOS kernel ------------------------------------------ */

#ifdef PKG_vmk                         /*                                    */
                                       /*                                    */
const UCHAR  maxroute      = MAXROUTE; /* Nb total de routes.                */
const SHORT  fai_size      = FAI_SIZE; /* Nombre d'elements dans "fai_evt[]" */
const UCHAR  kbd_max       = KBD_MAX ; /* Nombre de voies logiques.          */
const UCHAR  hmot_nautmax  = NAUTMAX ; /* Nombre maximum d'automates         */
const UCHAR  hmot_ntomax   = NTOMAX  ; /* 10/50 Nombre maximum de Time - Out */
                                       /*                                    */
S_aut       hmot_aut    [NAUTMAX    ]; /* Description des automate           */
S_evt       fai_evt     [FAI_SIZE   ]; /* Elements des files internes du VMK */
UCHAR       evt_lock    [FAI_SIZE   ]; /* Locks    des files internes du VMK */
Route       route       [MAXROUTE   ]; /* Tableau global des routes.         */
Sess_cond   sess_cond   [MAXCOND    ]; /* Tableau global des conditions.     */
const USHORT sess_cond_max = MAXCOND ; /* Nb total de conditions.            */
                                       /*                                    */
struct s_to     tabto[NTOMAX]        ; /* Tableau de structures TO           */
                                       /*                                    */
const USHORT stack_sz[] =              /* Table des tailles de piles         */
              BEGIN                    /* (unite: 1 Ko).                     */
                STACK_SZ0,             /*                                    */
                STACK_SZ1,             /*                                    */
                STACK_SZ2,             /*                                    */
                STACK_SZ3,             /*                                    */
                STACK_SZ4              /*                                    */
              END                    ; /*                                    */
                                       /*                                    */
const USHORT stack_nb[] =              /* Table des nombres de piles         */
              BEGIN                    /* de chaque taille.                  */
                STACK_NB0            , /*                                    */
                STACK_NB1            , /*                                    */
                STACK_NB2            , /*                                    */
                STACK_NB3            , /*                                    */
                STACK_NB4              /*                                    */
              END                    ; /*                                    */
                                       /*                                    */
const UINT   all_stack_sz = 1024 * (   /* Taille en octets de                */
                STACK_SZ0*STACK_NB0  + /* l'ensemble des piles               */
                STACK_SZ1*STACK_NB1  + /* cumulees.                          */
                STACK_SZ2*STACK_NB2  + /*                                    */
                STACK_SZ3*STACK_NB3  + /*                                    */
                STACK_SZ4*STACK_NB4) ; /*                                    */
                                       /*                                    */
INT          stack [1024 * (           /* L'ensembles des piles              */
                STACK_SZ0*STACK_NB0  + /* allouables, alignees.              */
                STACK_SZ1*STACK_NB1  + /*                                    */
                STACK_SZ2*STACK_NB2  + /*                                    */
                STACK_SZ3*STACK_NB3  + /*                                    */
                STACK_SZ4*STACK_NB4)/ZI]; /*                                 */
                                       /*                                    */
#ifndef _IOT_                          /* Not an iot profile.                */
USHORT      etkbd       [KBD_MAX    ]; /* Etat de chaque voie logique.       */
UCHAR       spkbd       [KBD_MAX    ]; /* Stack pointer for each LW          */
SHORT       code_evt    [NAUTMAX*2  ]; /* codes evts continue_script         */
CHAR        kbd_stack   [KBD_MAX    ]; /* Pile des voies logique.            */
Kbd_ctx     kbd_ctx     [KBD_MAX    ]; /* Contexte de chaque voie logique.   */
IWORD         (*tabptrint[NAUTMAX])(); /* Tableau des adresses des           */
                                       /* procedure d'interpretation         */
#endif                                 /* Not an iot profile.                */

extern IWORD init_pipe(void)         ; /*                                    */

#define INIT_PIPE init_pipe          , /*                                    */

/*****************************************************************************
 * Each task is declared as a name, a group number, an auto-start flag and   *
 * an entry point, such as :                                                 *
 * #define INIT_VMOS "VMOS", 1, 1, init_vmos                                 *
 *****************************************************************************/

const UCHAR ntaskmax   =TASK_SIZE    ; /* Nombre maximum de taches.          */
const UCHAR ntsemmax   =TASK_SEM_SIZE; /* Nombre max. de semaphores.         */
const UCHAR nb_stack_sz=NB_STACK_SZ  ; /* Nb de tailles de piles.            */

Task_ctx    task_ctx    [TASK_SIZE  ]; /* Contexte des taches.               */
USHORT      task_etat   [TASK_SIZE  ]; /* Etat des taches.                   */
UCHAR       task_pstack [TASK_SIZE  ]; /* Stack pointers                     */
Task_system task_sys_ctx[TASK_SIZE  ]; /* Contexte systeme des taches        */
UINT        used_stack  [NB_STACK_SZ]; /* Table allocation des piles         */
                                       /*                                    */
Task_sem    task_sem  [TASK_SEM_SIZE]; /* Semaphores des taches.             */

#endif                                 /*                                    */

#ifndef PKG_vmos                       /* If VMOS included _WORK_            */
    IWORD           vlgv             ; /*                                    */

#endif                                 /*                                    */


/* 4.xx Package memory ----------------------------------------------------- */

#ifdef PKG_memory                      /*                                    */
                                       /*                                    */
extern IWORD         fin_mem(void)   ; /*                                    */
                                       /*                                    */
#define END_MEM      fin_mem         , /* Fermeture                          */
                                              /*                             */
const USHORT high_max        = SIZE_HIGH_SEG; /* Nombre max de segments HIGH */
const INT    mid_seg_size    = MID_SEG_SIZE ; /* Taille d'un segment MID_SEG */
const UCHAR  mid_seg_ctx_max = SIZE_MID_SEG ; /* Nb d'utilisateurs           */
const UCHAR  str_ctx_max     = SIZE_MID_SEG ; /* Nb d'utilisateurs STR       */ 
const UCHAR  dat_ctx_max     = SIZE_MID_SEG ; /* Nb d'utilisateurs STR       */ 
                                              /*                             */
High_des    high_des[SIZE_HIGH_SEG+1]; /* Description segments   HIGH        */
Desc_str_ctx str_ctx [SIZE_MID_SEG  ]; /* Table des utilisateurs STR         */
Desc_dat_ctx dat_ctx [SIZE_MID_SEG  ]; /* Table des utilisateurs STR         */
                                       /*                                    */
UCHAR    *mid_seg_ctx[SIZE_MID_SEG  ]; /* Table des utilisateurs             */
UCHAR     mid_seg_typ[SIZE_MID_SEG  ]; /* Table des types d'utilisateurs     */
                                       /*                                    */
INT  high_gran     = SMALL_HIGH_GRAN ; /* Taille d'une zone HIGH small       */
INT  high_nb_page  = SMALL_HIGH_PAGE ; /* Nb de zones par page HIGH          */
                                       /*                                    */
#else                                  /*                                    */
#define END_MEM                        /*                                    */
#endif                                 /*                                    */


/* 4.xx Package file ------------------------------------------------------- */

#ifdef PKG_file                        /*                                    */
                                       /*                                    */
extern  IWORD        init_df(void)   ; /*                                    */
#define INIT_FILE    init_df         , /* Initialisation                     */
                                       /*                                    */
const UCHAR  df_maxo   = MAX_FIC     ; /* Nombre d'entrees dans df_o.        */
const USHORT df_maxfic = MAX_NBFIC   ; /* Max fichiers/repertoire            */
const UCHAR  df_maxvol = MAX_VOL     ; /* Nombre maximal de volumes declares */
const UCHAR  df_maxdsk = DFMAX_PATH  ; /* Nombre maximal de fichiers dans le */
const USHORT df_maxdir = MAX_NBDIR   ; /* Max repertoire/volume              */
                                       /*                                    */
Df_vol       df_vol [MAX_VOL]        ; /*                                    */
Df_dsk       df_dsk [DFMAX_PATH]     ; /* repertoire                         */
Df_o         df_o   [MAX_FIC  ]      ; /* Table des fichiers ouverts.        */
Df_ctx       df_ctx [MAX_FIC  ]      ; /* Contextes statiques.               */
USHORT       df_etat[MAX_FIC*4]      ; /* Etats et adresses des contextes    */
UCHAR        df_sp  [MAX_FIC*4]      ; /* Stack pointers                     */
Df_ctx      *pdf_ctx[MAX_FIC*4]      ; /* d'interpretation de fichiers.      */
Df_fram     *mdf_dfram  [MAX_NBDIR]  ; /* Adresses des listes de             */
Df_from     *mdf_dfrom  [MAX_NBDIR]  ; /* fichiers RAM et ROM.               */
SHORT        mdf_mem_fnb[MAX_NBDIR*2]; /* Nombre de fichiers listes.         */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_FILE                      /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package varenv - VMOS environment ---------------------------------- */

#ifdef PKG_varenv                      /*                                    */
                                       /*                                    */
extern IWORD        init_env(void)   ; /*                                    */
extern Hint_varenv  interface_varenv ; /*                                    */
                                       /*                                    */
#define VARENV_INT &interface_varenv   /*                                    */
#define INIT_ENV    init_env         , /* Initialisation                     */
                                       /*                                    */
#ifdef VARENV_FILE                     /*                                    */
const CHAR varenv_file[]=VARENV_FILE ; /*                                    */
      CHAR run_ini[STDNAME] = ""     ; /*                                    */
      CHAR run_cfg[STDNAME] = ""     ; /*                                    */
#else                                  /*                                    */
const CHAR varenv_file[]="null"      ; /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#else                                  /*                                    */
extern IWORD        init_env(void)   ; /*                                    */
#define VARENV_INT   HNULL             /*                                    */
#define INIT_ENV init_env ,            /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package module ----------------------------------------------------- */

#ifdef PKG_module                      /*                                    */
                                       /*                                    */
extern  IWORD       init_module(void); /*                                    */
extern  Hres_int    mod_v5           ; /*                                    */
                                       /*                                    */
#define INIT_MODULE   init_module    , /* Initialisation                     */
#define HLOAD_MOD    &mod_v5           /* Interface de chargement            */
                                            /*                               */
const USHORT hmod_max    = MODULE_SIZE    ; /* Nombre de modules au total    */
const USHORT hmod_sta_nb = MODULE_STATIC  ; /* Nombre contextes statiques    */
Hmod_ctx     hmod_sta     [MODULE_STATIC] ; /* Table  contextes statiques    */
                                            /*                               */
#else                                  /*                                    */
#define INIT_MODULE                    /*                                    */
#define HLOAD_MOD HNULL                /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package ptkint - PanTalk loader ------------------------------------ */

#ifdef PKG_ptkint                      /*                                    */
                                       /*                                    */
extern  Hres_int ptk_isc             ; /* Interface ISC                      */
extern  Hres_int ptk_pan             ; /* Interface PAN                      */
                                       /*                                    */
#define HLOAD_PTK_ISC &ptk_isc         /*                                    */
#define HLOAD_PTK_PAN &ptk_pan         /*                                    */
                                       /*                                    */
const UCHAR ptlk_maxobj=MAXCPIOBJ+ZI - /* Max number of objects              */
                    (MAXCPIOBJ AND 3); /* referenced per thread              */
                                       /*                                    */
#else                                  /*                                    */
#define HLOAD_PTK_ISC  HNULL           /* Interface ISC                      */
#define HLOAD_PTK_PAN  HNULL           /* Interface PAN                      */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package style - Widget style loader -------------------------------- */

#ifdef PKG_style                       /*                                    */
                                       /*                                    */
extern  Hres_int         sty_v5      ; /* Interface                          */
#define HLOAD_STYLE     &sty_v5        /*                                    */
        USHORT hsty_stfv[STYLE_SIZE] ; /* Pile de parcours                   */
                                       /*                                    */
const   USHORT hsty_max = STYLE_SIZE ; /* Nombre max. d'ensembles de styles. */
                                       /*                                    */
#else                                  /*                                    */
#define HLOAD_STYLE      HNULL         /*                                    */
#define STYLE_SIZE       0             /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package aut - PanTalk automaton loader ----------------------------- */

#ifdef PKG_aut                         /*                                    */
                                       /*                                    */
extern  Hres_int         aut_v5      ; /* Interface                          */
#define HLOAD_AUT       &aut_v5        /*                                    */
                                       /*                                    */
const USHORT haut_max  = AUT_SIZE    ; /* Nombre d'ensembles AUT             */
                                       /*                                    */
#else                                  /*                                    */
#define HLOAD_AUT        HNULL         /*                                    */
#define AUT_SIZE         0             /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package laf - PanTalk Look&Feel loader ----------------------------- */

#ifdef PKG_laf                         /*                                    */
                                       /*                                    */
extern  Hres_int         laf_v5      ; /* Interface                          */
#define HLOAD_LAF       &laf_v5        /*                                    */
                                       /*                                    */
const USHORT hlaf_max  = LAF_SIZE    ; /* Nombre max. d'ensembles de L&Feel  */
                                       /*                                    */
#else                                  /*                                    */
#define HLOAD_LAF        HNULL         /*                                    */
#define LAF_SIZE         0             /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package clalib ----------------------------------------------------- */

#ifdef PKG_clalib                      /*                                    */

extern  IWORD       init_cla_lib(void);/*                                    */
#define INIT_CLALIB init_cla_lib,      /* Initialisation                     */

#else                                  /*                                    */

#define INIT_CLALIB                    /*                                    */

#endif                                 /*                                    */
 

/* 4.xx Package fileref ---------------------------------------------------- */

#ifdef PKG_fileref                     /*                                    */
                                       /*                                    */
extern IWORD      init_file_ref(void); /*                                    */
extern IWORD      end_file_ref (void); /*                                    */
#define INIT_FILEREF init_file_ref   , /*                                    */
#define END_FILEREF  end_file_ref    , /*                                    */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_FILEREF                   /*                                    */
#define END_FILEREF                    /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package hypfile - Fichier memoire ---------------------------------- */

#ifdef PKG_hypfile                     /*                                    */
                                       /*                                    */
extern IWORD        init_heap(void)  ; /*                                    */
extern IWORD        init_stream(void); /*                                    */
#define INIT_HEAP   init_heap        , /*                                    */
#define INIT_STREAM init_stream      , /*                                    */
                                           /*                                */
const UCHAR hhpf_max     = HYPFILE_SIZE  ; /* Nombre de fichiers au total    */
const UCHAR hstr_ctx_max = HPF_STREAM_CTX; /* Nombre de contextes            */
const UCHAR hstr_des_max = HPF_STREAM_DES; /* Nombre de contextes            */
                                           /*                                */
Hhpf_ctx    hhpf_ctx [HYPFILE_SIZE  ]; /* Contextes des fichiers             */
Hstr_ctx    hstr_ctx [HPF_STREAM_CTX]; /* Structures des contextes           */
Hstr_ctx    hstr_des [HPF_STREAM_DES]; /* Structures des contextes           */
UCHAR       heapid   [SIZE_MID_SEG  ]; /* Relation heap <-> str/dat          */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_HEAP                      /*                                    */
#define INIT_STREAM                    /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package hpchp - HPC interface ---------------------------------------*/

#ifdef PKG_hpchp                       /*                                    */

const Dict * const hpchp_prodict = & PTKINT_PRODICT ;  /* Dict procedures    */
const Dict * const ptk_prodict   = & PTKINT_PRODICT ;  /* Dict procedures    */
const Dict * const hpchp_mnedict = & PTKINT_MNEDICT ;  /* Dict mnemoniques   */

#define HPCHP_NBDICT 2                 /* Existence flag                     */
#define HPCHP_DICT & PTKINT_PRODICT  , \
                   & PTKINT_MNEDICT  , /*                                    */
                                       /*                                    */
#else                                  /*                                    */
                                       /*                                    */
#ifndef _IOT_                          /* Not an iot profile.                */
#define HPCHP_NBDICT 1                 /* Existence flag                     */
#define HPCHP_DICT & PTKINT_PRODICT ,  /*                                    */

const Dict * const ptk_prodict = & PTKINT_PRODICT ;  /* Dict procedures      */

#endif                                 /*                                    */
#endif                                 /*                                    */


/* 4.xx Package class ------------------------------------------------------ */

#ifdef PKG_class                       /*                                    */
                                       /*                                    */
#include <classe.h>                    /* Hcla_ctx.                          */
                                       /*                                    */
extern  IWORD        class_init(void); /*                                    */
extern  Hres_int     cla_v5          ; /*                                    */
                                       /*                                    */
#define INIT_CLASS     class_init    , /* Initialisation                     */
#define HLOAD_CLA      &cla_v5         /* Interface de chargement            */
                                       /*                                    */
const USHORT hcla_max = CLASS_SIZE   ; /* Nombre maximum de classes PanTalk. */
                                       /*                                    */
#if CLASS_STATIC > 0                   /*                                    */
const USHORT hcla_sta_nb=CLASS_STATIC; /* Nombre contextes statiques         */
Hcla_ctx     hcla_sta[CLASS_STATIC]  ; /* Table  contextes statiques         */
                                       /*                                    */
#else                                  /*                                    */
const USHORT hcla_sta_nb = 0         ; /*                                    */
Hcla_ctx    *hcla_sta    = HNULL     ; /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_CLASS                     /*                                    */
#define HLOAD_CLA HNULL                /*                                    */
#endif                                 /*                                    */


/* 4.xx Package panel ------------------------------------------------------ */

#ifdef PKG_panel                       /*                                    */
                                       /*                                    */
extern  Hres_int    panel_scr        ; /*                                    */
extern  IWORD       init_npanel(void); /*                                    */
                                       /*                                    */
#define INIT_NPANEL     init_npanel  , /* Initialisation                     */
#define HLOAD_SCR_PANEL &panel_scr     /* Interface de chargement            */
                                       /*                                    */
const UCHAR   panmax = PANEL_SIZE    ; /* Nombre maximum de panels charges.  */
NPanel        ntpa    [PANEL_SIZE+1] ; /*                                    */
                                       /*                                    */
CHAR * const iopanv5_clanom[] =        /* Anciens types de widget (toolkit)  */
               BEGIN                   /*                                    */
                 HNULL               , /* objnull                            */
                 CUI_CLASS_FILENAME  , /* panel      (Panel )                */
                 BOX_CLASS_FILENAME  , /* button     (Action)                */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* textbox    (Text)                  */
                 BOX_CLASS_FILENAME  , /* framebox   (Frame)                 */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 WBACK_CLASS_FILENAME, /* soupanel   (SubPanel)              */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* bargraph   (Bargraph)              */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* trigger    (Trigger)               */
                 DSCRL_CLASS_FILENAME, /* (unused)                           */
                 DSCRL_CLASS_FILENAME, /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 BOX_CLASS_FILENAME  , /* (unused)                           */
                 CUI_CLASS_FILENAME  , /* tvbutt     (Button)                */
                 CUI_CLASS_FILENAME  , /* tvtrig     (Command)               */
               END                   ; /*                                    */
                                       /*                                    */
#else                                  /*                                    */
#define  INIT_NPANEL                   /*                                    */
#define HLOAD_SCR_PANEL HNULL          /*                                    */
#endif                                 /*                                    */


/* 4.xx Package exec ------------------------------------------------------- */

#ifdef PKG_exec                        /*                                    */
                                       /*                                    */
#include <executif.h>                  /* Structures executifs               */
                                       /*                                    */
extern  IWORD        scr_init(void)  ; /*                                    */
#define INIT_EXEC    scr_init,         /* Initialisation                     */
                                       /*                                    */
const USHORT hscr_max = SCRIPT_SIZE  ; /* Nombre max. de scripts charges     */
const USHORT hexe_max = THREAD_SIZE  ; /* Nombre max de thread en memoire.   */
const UCHAR  hexe_max_met=SIZE_SCRLEV; /* Nombre methodes empilees.          */
                                       /*                                    */
USHORT       hexe_etat [THREAD_SIZE] ; /* Table d'etats voie logique         */
UCHAR        hexe_sp   [THREAD_SIZE] ; /* Stack pointers                     */
Hexe_fra0    hexe_fra0 [THREAD_SIZE] ; /* Table frame methode 0.             */
USHORT       drv_etat  [THREAD_SIZE] ; /* Etat vl automate driver            */
                                       /*                                    */
Hexe_call    hexe_calls[SIZE_SCRLEV*THREAD_SIZE] ; /*Table methodes empilees */
                                       /*                                    */
#if SCRIPT_STATIC > 0                  /*                                    */
const USHORT hscr_sta_nb=SCRIPT_STATIC;/* Nombre contextes statiques         */
Hscr_ctx     hscr_sta[SCRIPT_STATIC] ; /* Table  contextes statiques         */
                                       /*                                    */
#else                                  /*                                    */
const USHORT hscr_sta_nb = 0         ; /*                                    */
Hscr_ctx     hscr_sta[1]             ; /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#if THREAD_STATIC > 0                  /*                                    */
const USHORT hexe_sta_nb=THREAD_STATIC;/* Nombre contextes statiques         */
Hexe_ctx     hexe_ctx [THREAD_SIZE  ]; /* Table  contextes statiques         */
Hexe_cpi     hexe_cpi [THREAD_STATIC]; /* Table  contextes statiques         */
                                       /*                                    */
#else                                  /*                                    */
const USHORT hexe_sta_nb = 0         ; /*                                    */
Hexe_ctx     hexe_ctx [1]            ; /*                                    */
Hexe_cpi     hexe_cpi [1]            ; /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_EXEC                      /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* Package gra --------------------------------------------------------------*/

#ifdef PKG_gra                         /*                                    */
                                       /*                                    */
Gra_dsp    gra_dsp   [NB_GRADISP]    ; /*                                    */
Gra_dsp   *gra_dspadr[MAXSCR][MAXLAY]; /*                                    */
                                       /*                                    */
const UCHAR gra_winmax  = NB_GRAWIN  ; /*                                    */
Gra_win     gra_win      [NB_GRAWIN] ; /*                                    */
Gra_img     gra_img      [NB_GRAWIN] ; /*                                    */
                                       /*                                    */
const INT   gra_recmax  = NB_GRAREC  ; /*                                    */
Gra_rec     gra_rec      [NB_GRAREC] ; /*                                    */
                                       /*                                    */
const UCHAR gra_outlnmax=NB_GRAOUTLN ; /*                                    */
UCHAR      *gra_outln   [NB_GRAOUTLN]; /*                                    */
                                       /*                                    */
const UCHAR gra_areamax =NB_GRAAREA  ; /*                                    */
UCHAR      *gra_area    [NB_GRAAREA] ; /*                                    */
                                       /*                                    */
const UCHAR gra_pxmmax  =NB_GRAPXM   ; /*                                    */
Gra_pxm    *gra_pxm     [NB_GRAPXM]  ; /*                                    */
                                       /*                                    */
const UCHAR gra_lutmax  =NB_GRALUT   ; /*                                    */
UCHAR      *gra_lut     [NB_GRALUT]  ; /*                                    */
#endif                                 /*                                    */


/* 4.xx Package telecom - Telecom interface ---------------------------------*/

#ifdef PKG_telecom                     /*                                    */
                                       /*                                    */
#define STATUS_TLCM  status_tlcm     , /* Procedure de status telecom.       */
#define NAME_TLCM   "telecom"        , /* Libelle.                           */
#else                                  /*                                    */
#define STATUS_TLCM                    /*                                    */
#define NAME_TLCM                      /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package message ---------------------------------------------------- */

#ifdef PKG_message                     /*                                    */
                                       /*                                    */
extern  IWORD      init_message(void); /*                                    */
#define INIT_MESSAGE init_message    , /* Initialisation                     */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_MESSAGE                   /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 4.xx Package vminfo - VMOS status ----------------------------------------*/

#ifdef PKG_vminfo                      /*                                    */
                                       /*                                    */
extern IWORD status_am     ()        ; /*                                    */
extern IWORD status_class  ()        ; /*                                    */
extern IWORD status_mem    ()        ; /*                                    */
extern IWORD status_module ()        ; /*                                    */
extern IWORD status_script ()        ; /*                                    */
extern IWORD status_set    ()        ; /*                                    */
extern IWORD status_tlcm   ()        ; /*                                    */
                                       /*                                    */
IWORD (* const status_proc[])()=       /* Table procedures d'etats.          */
  BEGIN                                /*                                    */
    status_am      ,  status_set     , /*                                    */
    status_module  , status_class    , /*                                    */
    trien          , status_mem      , /*                                    */
    trien          ,  status_route   , /*                                    */
    STATUS_TLCM       status_script  , /*                                    */
    HNULL                              /*                                    */
  END                                ; /*                                    */
                                       /*                                    */
const CHAR * const status_name[]     = /* Libelles etats disponibles         */
  BEGIN                                /*                                    */
    "run"          , "set"           , /*                                    */
    "module"       , "class"         , /*                                    */
    "file"         , "memory"        , /*                                    */
    "buffers"      , "event"         , /*                                    */
     NAME_TLCM        "script"       , /*                                    */
     HNULL                             /*                                    */
  END                                ; /*                                    */
                                       /*                                    */
#else                                  /*                                    */
                                       /*                                    */
#ifndef _IOT_                          /* Not used with iot profiles.        */
const CHAR * const status_name[]     = /* Libelles etats disponibles         */
  BEGIN                                /*                                    */
    HNULL                              /*                                    */
  END                                ; /*                                    */
#endif                                 /* Not used with iot profiles.        */
                                       /*                                    */
#endif                                 /*                                    */




/* 4.xx Package path - Driver PATH ------------------------------------------*/

#ifdef PKG_pth                                   /*                          */
#define PTH_DRV  ((Sys_driver*)&pth_driver),     /*                          */
#else                                            /*                          */
#define PTH_DRV                                  /*                          */
#endif                                           /*                          */


/* 4.xx Packages pcmcia - PCM driver & DVBCI protocol -----------------------*/

#ifdef PKG_pcmcia                                /*                          */
#define PCM_DRV  ((Sys_driver*)&pcm_driver),     /*                          */
#define CI_DRV   ((Sys_driver*)&ci_driver),      /*                          */
#else                                            /*                          */
#define PCM_DRV                                  /*                          */
#define CI_DRV                                   /*                          */
#endif                                           /*                          */


/* 4.xx Package posix - POSIX interface for VMK threads. ------------------- */

#ifdef PKG_posix                       /*                                    */
                                       /*                                    */
extern  IWORD    init_vmk_posix(void); /* Module vmk_posix.c                 */
#define INIT_POSIX  init_vmk_posix,    /*                                    */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_POSIX                     /*                                    */
                                       /*                                    */
#endif                                 /* PKG_posix ------------------------ */


/* 4.xx Package pow - POWER driver ------------------------------------------*/

#ifdef PKG_pow                                   /*                          */
#define POW_DRV  ((Sys_driver*)&pow_driver),     /*                          */
#else                                            /*                          */
#define POW_DRV                                  /*                          */
#endif                                           /*                          */


/* 4.xx Package sec - Security driver ---------------------------------------*/

#ifdef PKG_sec                                   /*                          */
IWORD sec_scw    = 0                           ; /* CW non securises a priori*/
IWORD sec_rnd    = 0                           ; /* Pas de Rndomizer a priori*/
IWORD sec_sk_aes = 0                           ; /* Pas de clef secrete      */
#define SEC_DRV  ((Sys_driver*)&sec_driver),     /*                          */
#else                                            /*                          */
                                                 /*                          */
#ifndef _IOT_                                    /* Not used in iot profile. */
IWORD sec_scw    = 0                           ; /* CW non securises.        */
IWORD sec_rnd    = 0                           ; /* Pas de Randomizer. priori*/
IWORD sec_sk_aes = 0                           ; /* Pas de clef secrete      */
#define SEC_DRV                                  /*                          */

IWORD sec_aes_encrypt(src,dst,nbo,knum,chain,mode,cbk,p1,p2,aut,vl,ret)
  UCHAR *src,*dst; INT nbo,knum,chain,mode; void *cbk; INT p1,p2;
  UINT aut,vl; INT *ret;
  { return(-1); }

IWORD sec_aes_decrypt(src,dst,nbo,knum,chain,mode,cbk,p1,p2,aut,vl,ret)
  UCHAR *src,*dst; INT nbo,knum,chain,mode; void *cbk; INT p1,p2;
  UINT aut,vl; INT *ret;
  { return(-1); }

IWORD sec_aes_init(step) IWORD step ;
  { return(-1); }

IWORD sec_get_rnd(rnd) IWORD *rnd;  
  { return(-1); }   

IWORD sec_alloc_user_key(num,ret) IWORD *num; INT *ret;
  { *num=-1; *ret=-1 ; return(-1); }

IWORD sec_free_user_key(num,ret) IWORD num; INT *ret;
  { *ret=-1 ; return(-1); }

IWORD sec_set_user_key(num,type,chain,key,ret)
  IWORD num,type,chain; UCHAR *key; INT *ret;
  { *ret=-1 ; return(-1); }

#endif                                           /* Not used in iot profile. */
#endif                                           /*                          */


/* 4.xx Package elfdl ------------------------------------------------------ */

#ifdef PKG_elfdl

extern IWORD       init_elf_dl(void) ; /*                                    */
#define INIT_ELFDL init_elf_dl       , /* Initialisation                     */

#else

#define INIT_ELFDL                     /* Initialisation                     */

#endif


/* 4.xx Package wbk - WebKit internet browser ------------------------------ */

#ifdef PKG_wbk                         /*                                    */
                                       /*                                    */
extern IWORD         init_wbk(void)  ; /*                                    */
extern Hres_int      wbk_Hlod        ; /*                                    */
#define INIT_BRW     init_wbk        , /* Initialisation                     */
#define HLOAD_BRW    &wbk_Hlod         /*                                    */
                                       /*                                    */
#else                                  /*                                    */


/* 4.xx Package nfb - NetFront Access internet browser --------------------- */

#ifdef PKG_nfb

extern IWORD         init_nfb(void)  ; /*                                    */
extern Hres_int      nfb_Hlod        ; /*                                    */
#define INIT_BRW     init_nfb        , /* Initialisation                     */
#define HLOAD_BRW    &nfb_Hlod         /*                                    */

#else

#if ((defined PKG_nx) || (defined PKG_elfdl))

#define INIT_BRW                       /* Initialisation                     */
#define HLOAD_BRW    HNULL             /*                                    */
 
#else

#ifndef _IOT_
IWORD __fpscr_values[2]              ; /*                                    */
IWORD brw_alloc(ctxid,memuid,thread  ) /*                                    */
             INT ctxid,memuid,*thread; /*                                    */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD parse_ait_table(heap,ait)        /*                                    */
      INT heap; UCHAR* ait ;           /*                                    */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */

#define INIT_BRW                       /*                                    */
#define HLOAD_BRW    HNULL             /*                                    */
#endif
                                       /*                                    */
#endif                                 /* PKG_nx                             */
#endif                                 /* PKG_nfb                            */
#endif                                 /* PKG_wbk                            */


/* 4.xx Package acces - Embedded acces control ----------------------------- */

#ifdef PKG_acces                       /*                                    */

#include <acces.h>                     /* Structures controle d'acces        */
                                       /*                                    */
const   IWORD  nb_ca  = NB_CA        ; /* Nombre de modules CA.              */
const   IWORD  nb_cas = NB_CAS       ; /* Nombre de slots CA.                */
CA_desc ca_desc[NB_CA ]              ; /* Descriptions des modules CA.       */
Drv_tag ca_tag [NB_CA ]              ; /* Pointeurs sur les tables de tags CA*/
CA_ctx  ca_ctx [NB_CAS]              ; /* Contextes des slots CA.            */
                                       /*                                    */
extern  IWORD       init_ca_api(void); /* Module ac_api.                     */
#define INIT_AC     init_ca_api      , /*                                    */
                                       /*                                    */
#if defined PKG_cav                    /* Conditionnal access 1 .............*/
extern  IWORD        init_ca_va(void); /*                                    */
#define INIT_CA1     init_ca_va      , /* Initialisation des modules.        */
#else                                  /*                                    */
#define INIT_CA1                       /*                                    */
IWORD VA_check_vn(a,b,c,d)             /*                                    */
                         INT a,b,c,*d; /*                                    */
  { *d = 1; return(0); }               /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#if defined PKG_cae                    /* Conditionnal access 2 .............*/
extern  IWORD       init_ca_es(void) ; /*                                    */
#define INIT_CA2    init_ca_es       , /*                                    */
#else                                  /*                                    */
#define INIT_CA2                       /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#if defined PKG_cac                    /* Conditionnal access 3 .............*/
extern  IWORD       init_ca_cnx(void); /*                                    */
#define INIT_CA3    init_ca_cnx      , /*                                    */
#else                                  /*                                    */
#define INIT_CA3                       /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#if defined PKG_cam                    /* Conditionnal access 4 .............*/
UINT mg_svn                          = /*                                    */
   (0x09000100|(((UINT)TVO_NB)<<16)) ; /*                                    */
extern  IWORD        init_ca_mg(void); /*                                    */
#define INIT_CA4     init_ca_mg      , /*                                    */
#else                                  /*                                    */
#define INIT_CA4                       /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#if defined PKG_casm                   /* Conditionnal access 5 .............*/
extern  IWORD        init_ca_sm(void); /*                                    */
#define INIT_CA5     init_ca_sm      , /*                                    */
#else                                  /*                                    */
#define INIT_CA5                       /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
#if defined PKG_dvbci                  /* DVB-CI ............................*/
extern  IWORD      init_ca_dvbci(void);/*                                    */
#define INIT_DVBCI init_ca_dvbci     , /*                                    */
#else                                  /*                                    */
#define INIT_DVBCI                     /*                                    */
#endif                                 /*                                    */
                                       /*                                    */
IWORD (* const init_ca_spe[])() =      /* Initialisations des CAs.           */
  BEGIN                                /*                                    */
    INIT_CA1                           /*                                    */
    INIT_CA2                           /*                                    */
    INIT_CA3                           /*                                    */
    INIT_CA4                           /*                                    */
    INIT_CA5                           /*                                    */
    INIT_DVBCI                         /*                                    */
    HNULL                              /*                                    */
  END                                ; /*                                    */
                                       /*                                    */
#else                                  /*                                    */
#define INIT_AC                        /*                                    */
#endif                                 /*                                    */

#if defined PKG_tkdma                  /* TKDMA .............................*/
const UCHAR tkdma_present = 1        ; /* Presence du TKDMA.                 */
#else                                  /*                                    */
#if defined PKG_sti71xx                /*                                    */
const UCHAR tkdma_present = 0        ; /* Absence du TKDMA.                  */
                                       /*                                    */
IWORD init_tkdma(void)                 /* Procedure d'init vide.             */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD end_tkdma(void)                  /* Procedure de terminaison vide.     */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD tkdma_send_key(adsc,rdsc,par,typ,val) /* Procedure de transmition des  */
  UCHAR *adsc                        ; /* cles vide.                         */
  UIWORD rdsc,par,typ                ; /*                                    */
  UCHAR *val                         ; /*                                    */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD tkdma_aes(sens,src,dst,nbo,cbk,p1,p2) /* Procedure vide de chiffrement */
  IWORD sens; UCHAR *src,*dst;         /* et dechiffrement AES.              */
  UINT nbo; void (*cbk)(); UINT p1,p2; /*                                    */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD tkdma_aes_cbk(par)               /* Procedure vide de cbk AES.         */
  INT par;                             /*                                    */
  BEGIN                                /*                                    */
    return(-1)                       ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD handlerTKD_71xx(v,par)           /* Handler d'IT TKDMA vide.           */
  IWORD v,par                        ; /*                                    */
  BEGIN                                /*                                    */
   return(0)                         ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD tkdma_scw_mode(mode,keytype,key) /*                                    */
  IWORD mode , keytype ;  UCHAR *key ; /*                                    */
  BEGIN                                /*                                    */
   return(DEV_IMPOSSIBLE)            ; /*                                    */
  END_PROC                             /*                                    */
                                       /*                                    */
IWORD tkdma_set_ukey(num,type,mode,key)/*                                    */
  UIWORD num,type,mode;  UCHAR *key  ; /*                                    */
  BEGIN                                /*                                    */
   return(DEV_IMPOSSIBLE)            ; /*                                    */
  END_PROC                             /*                                    */
#endif                                 /*                                    */
#endif                                 /*                                    */


/* 4.xx Package load - Ressource generic loader ---------------------------- */

#ifdef PKG_load                        /*                                    */
                                       /*                                    */
extern IWORD set_init()              ; /* Initialisation                     */
extern IWORD set_end()               ; /* Termination                        */
                                       /*                                    */
#define INIT_HLOAD     set_init      , /*                                    */
#define END_HLOAD      set_end       , /*                                    */
                                       /*                                    */
const INT   hset_root_init =  0      ; /*                                    */
const INT   hset_root_page = 60      ; /*                                    */
const UCHAR hres_dyn_max   =LOAD_SIZE; /* Nombre de  chargements             */
                                       /*                                    */
Hres_dyn    hres_dyn     [LOAD_SIZE] ; /* Table  des chargements             */
USHORT      hload_etat   [LOAD_SIZE] ; /* Table d'etats voie logique         */
UCHAR       hload_sp     [LOAD_SIZE] ; /* Stack pointers table               */
UINT        hload_rteid  [LOAD_SIZE] ; /* Table d'etats voie logique         */
USHORT      hload_sessid [LOAD_SIZE] ; /* Table d'etats voie logique         */
                                       /*                                    */
Hres_int  *hres_int[]                = /* Interface de chargement            */
  BEGIN                                /*                                    */
    HNULL                            , /* 00 - INVALID                       */
    HLOAD_MOD                        , /* 01 - RES_NUM_MOD                   */
    HLOAD_CLA                        , /* 02 - RES_NUM_CLA                   */
    HLOAD_PTK_ISC                    , /* 03 - RES_NUM_PTK_ISC               */
    HLOAD_PTK_PAN                    , /* 04 - RES_NUM_PTK_PAN               */
    HLOAD_STYLE                      , /* 05 - RES_NUM_STYLE                 */
    HLOAD_SCR_PANEL                  , /* 06 - RES_NUM_SCR_PANEL             */
    HLOAD_AUT                        , /* 07 - RES_NUM_AUT                   */
    HLOAD_LAF                        , /* 08 - RES_NUM_LAF                   */
    HNULL                            , /* 09 - (unused)                      */
    HLOAD_BRW                        , /* 10 - RES_NUM_BRW                   */
  END                                ; /*                                    */
                                       /*                                    */
CHAR       hres_typ[][RES_SIZE+1]    = /* Type de fichiers _WORK_            */
  BEGIN                                /*                                    */
    ""                               , /* 00 - INVALID                       */
    RES_MOD                          , /* 01 - RES_NUM_MOD                   */
    RES_CLA                          , /* 02 - RES_NUM_CLA                   */
    RES_PTK_ISC                      , /* 03 - RES_NUM_PTK_ISC               */
    RES_PTK_PAN                      , /* 04 - RES_NUM_PTK_PAN               */
    RES_STYLE                        , /* 05 - RES_NUM_STYLE                 */
    RES_SCR_PANEL                    , /* 06 - RES_NUM_SCR_PANEL             */
    RES_AUT                          , /* 07 - RES_NUM_AUT                   */
    RES_LAF                          , /* 08 - RES_NUM_LAF                   */
    RES_MHEG5                        , /* 09 - RES_NUM_MHEG5                 */
    RES_BRW                          , /* 10 - RES_NUM_BRW                   */
 END                                 ; /*                                    */
                                       /*                                    */
UCHAR **hset_adr [ MODULE_SIZE       + /*                                    */
                   SCRIPT_SIZE       + /*                                    */
                   CLASS_SIZE        + /*                                    */
                   STYLE_SIZE        + /*                                    */
                   AUT_SIZE          + /*                                    */
                   LAF_SIZE          + /*                                    */
                   1                ]; /*                                    */
                                       /*                                    */
UCHAR *** const hset_iadr[]          = /*                                    */
  BEGIN                                /*                                    */

    HNULL                                                                     ,
    &hset_adr[0]                                                              ,
    &hset_adr[MODULE_SIZE]                                                    ,
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE]                                        ,
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE]                             ,
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE]                             ,
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE+STYLE_SIZE]                  ,
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE+STYLE_SIZE+AUT_SIZE]         ,
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE+STYLE_SIZE+AUT_SIZE+LAF_SIZE], 
    &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE+STYLE_SIZE+AUT_SIZE+LAF_SIZE],

  END                                ; /*                                    */
                                       /*                                    */
UCHAR *** const hset_eadr            = /*                                    */
               &hset_adr[MODULE_SIZE + /*                                    */
                         SCRIPT_SIZE + /*                                    */
                         CLASS_SIZE  + /*                                    */
                         STYLE_SIZE  + /*                                    */
                         AUT_SIZE    + /*                                    */
                         LAF_SIZE -1]; /*                                    */
                                       /*                                    */
USHORT    const hset_imax[]  =         /* Table des maximums                 */
                  BEGIN                /* d'elements par                     */
                    0                , /*                                    */
                    MODULE_SIZE      , /*                                    */
                    SCRIPT_SIZE      , /* type d'ensemble.                   */
                    CLASS_SIZE       , /*                                    */
                    0                , /*                                    */
                    STYLE_SIZE       , /*                                    */
                    AUT_SIZE         , /*                                    */
                    LAF_SIZE         , /*                                    */
                    0                , /*                                    */
                  END                ; /*                                    */
                                       /*                                    */
UCHAR *** const hset_module          = /*                                    */
          &hset_adr[0]                                                     ;
                                       /*                                    */
UCHAR *** const hset_script          = /*                                    */
          &hset_adr[MODULE_SIZE                                           ];
                                       /*                                    */
UCHAR *** const hset_class           = /*                                    */
          &hset_adr[MODULE_SIZE+SCRIPT_SIZE                               ];
                                       /*                                    */
UCHAR *** const hset_style           = /*                                    */
          &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE                    ];
                                       /*                                    */
UCHAR *** const hset_aut             = /*                                    */
          &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE+STYLE_SIZE         ];
                                       /*                                    */
UCHAR *** const hset_laf             = /*                                    */
          &hset_adr[MODULE_SIZE+SCRIPT_SIZE+CLASS_SIZE+STYLE_SIZE+AUT_SIZE];
                                       /*                                    */
#else                                  /*                                    */
#define INIT_HLOAD                     /*                                    */
#define END_HLOAD                      /*                                    */
                                       /*                                    */
#endif                                 /*                                    */



/* Various global variables -------------------------------------------------*/



/*
    5  vmos_driver table packages
    _____________________________
*/


/* 5.xx Package mb86 - VMOS drivers for hd200 set-topbox --------------------*/

#ifdef PKG_mb86                        /*                                    */
                                       /*                                    */
#ifdef PKG_vmos                             /* If VMOS included              */
IWORD init_vmos(CHAR*,CHAR*)              ; /*                               */
#define INIT_VMOS "VMOS", 1, 1, init_vmos , /*   VMOS Hyperpanel.            */
#else                                       /* Otherwise,                    */
#define INIT_VMOS                           /*   do not declare              */
#endif                                      /*                               */

#ifdef PKG_vmkuser                          /* If VMK app included,          */
IWORD VMK_USER_PROC(CHAR*,CHAR*)          ; /*                               */
#define INIT_VMK_USER \                     /*   start it.                   */\
        VMK_USER_NAME, 1, 1, VMK_USER_PROC, /*                               */
#else                                       /* Otherwise,                    */
#define INIT_VMK_USER                       /*   do not declare              */
#endif                                      /*                               */

#ifdef PKG_enigma                           /* If Enigma included,           */
IWORD init_enigma(CHAR*,CHAR*)            ; /*                               */
#define INIT_ENIGMA                         /*   Enigma access control.      */\
            "Enigma_CA", 2, 1, init_enigma, /*                               */
#else                                       /* Otherwise,                    */
#define INIT_ENIGMA                         /*   do not declare              */
#endif                                      /*                               */

const Task_grp task_grp[] =            /* Definition des groupes de taches   */
  BEGIN                                /* ---------------------------------- */
                                       /* Groupes de taches "temps reel" ... */
    INIT_VMOS                          /* VMOS   Hyperpanel.                 */
    INIT_VMK_USER                      /* VMK User App.                      */
                                       /* ---------------------------------- */
                                       /* Groupes de taches "standard" ..... */
    INIT_ENIGMA                        /* Controle d'acces Enigma.           */
                                       /* ---------------------------------- */
    ""             , 9 , 9 , HNULL   , /* Marque de fin de liste ........... */
  END                                ; /* ---------------------------------- */

const Sys_driver * const vmos_driver[]=/* Drivers table for mb86.            */
  BEGIN                                /*                                    */
    (Sys_driver*)&Sys_eep            , /* 0                                  */
    (Sys_driver*)&MDF_voldrv         , /* 1                                  */
    (Sys_driver*)&FDF_voldrv         , /* 2                                  */
    (Sys_driver*)&glue_voldrv        , /* 4                                  */
    (Sys_driver*)&kbditf_driver      , /* 5                                  */
    (Sys_driver*)&den_driver         , /* 6                                  */
    (Sys_driver*)&led_driver         , /* 7                                  */
    (Sys_driver*)&asy_driver         , /* 8                                  */
    (Sys_driver*)&fre_driver         , /* 9                                  */
    (Sys_driver*)&dmx_driver         , /* 10                                 */
    (Sys_driver*)&aud_driver         , /* 11                                 */
    (Sys_driver*)&vid_driver         , /* 12                                 */
    (Sys_driver*)&smc_driver         , /* 13                                 */
    (Sys_driver*)&eth_driver         , /* 14                                 */
    (Sys_driver*)&lo_driver          , /* 15                                 */
    (Sys_driver*)&ip_driver          , /* 16                                 */
    (Sys_driver*)&play_driver        , /* 17                                 */
    (Sys_driver*)&dns_service        , /* 18                                 */
    (Sys_driver*)&glue_service       , /* 19                                 */
    (Sys_driver*)&http_service       , /* 20                                 */
    (Sys_driver*)&str_service        , /* 16                                 */
    (Sys_driver*)&mp3_service        , /* 21                                 */
    (Sys_driver*)&hls_service        , /* 22                                 */
    (Sys_driver*)&pipe_driver        , /* 23                                 */
    (Sys_driver*)&dis_driver         , /* 24                                 */
    HNULL                            , /* 25 Fin de la table                 */
  END                                ; /*                                    */

Hint_varenv * const hint_varenv      = /*                                    */
                         VARENV_INT  ; /* Package structure interface        */
                                       /*                                    */
IWORD (* const henv_start[])()       = /* Procedures d'initialisation        */
                 BEGIN                 /*                                    */
                   init_telecom      , /*                                    */
                   INIT_HEAP           /*                                    */
                   INIT_STREAM         /*                                    */
                   INIT_CLASS          /*                                    */
                   INIT_FILE           /*                                    */
                   INIT_ENV            /*                                    */
                   INIT_MESSAGE        /*                                    */
                   init_auttime      , /*                                    */
                   INIT_MODULE         /*                                    */
                   INIT_EXEC           /*                                    */
                   INIT_HLOAD          /*                                    */
                   init_autkbd       , /*                                    */
                   INIT_FILEREF        /*                                    */
                   INIT_NPANEL         /*                                    */
                   INIT_AC             /*                                    */
                   INIT_BRW            /*                                    */
                   INIT_ELFDL          /*                                    */
                   INIT_CLALIB         /*                                    */
                   INIT_POSIX          /*                                    */
                   INIT_PIPE           /*                                    */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
                                       /*                                    */
IWORD (* const henv_stop[])()        = /* Procedures de fin                  */
                 BEGIN                 /*                                    */
                   END_HLOAD           /*                                    */
                   END_FILEREF         /*                                    */
                /* scr_fin , */        /* _WORK_                             */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
                                       /*                                    */
#endif                                 /*                                    */


/* 5.xx Package sti71xx - VMOS drivers for all sh4 set-topboxes -------------*/

#ifdef PKG_sti71xx                     /*                                    */
                                       /*                                    */
#ifdef PKG_vmos                             /* If VMOS included              */
IWORD init_vmos(CHAR*,CHAR*)              ; /*                               */
#define INIT_VMOS "VMOS", 1, 1, init_vmos , /*   VMOS Hyperpanel.            */
#else                                       /* Otherwise,                    */
#define INIT_VMOS                           /*   do not declare              */
#endif                                      /*                               */

#ifdef PKG_vmkuser                          /* If VMK app included,          */
IWORD VMK_USER_PROC(CHAR*,CHAR*)          ; /*                               */
#define INIT_VMK_USER \                     /*   start it.                   */\
        VMK_USER_NAME, 1, 1, VMK_USER_PROC, /*                               */
#else                                       /* Otherwise,                    */
#define INIT_VMK_USER                       /*   do not declare              */
#endif                                      /*                               */

#ifdef PKG_enigma                           /* If Enigma included,           */
IWORD init_enigma(CHAR*,CHAR*)            ; /*                               */
#define INIT_ENIGMA                         /*   Enigma access control.      */\
            "Enigma_CA", 2, 1, init_enigma, /*                               */
#else                                       /* Otherwise,                    */
#define INIT_ENIGMA                         /*   do not declare              */
#endif                                      /*                               */

const Task_grp task_grp[] =            /* Definition des groupes de taches   */
  BEGIN                                /* ---------------------------------- */
                                       /* Groupes de taches "temps reel" ... */
    INIT_VMOS                          /* VMOS   Hyperpanel.                 */
    INIT_VMK_USER                      /* VMK User App.                      */
                                       /* ---------------------------------- */
                                       /* Groupes de taches "standard" ..... */
    INIT_ENIGMA                        /* Controle d'acces Enigma.           */
                                       /* ---------------------------------- */
    ""             , 9 , 9 , HNULL   , /* Marque de fin de liste ........... */
  END                                ; /* ---------------------------------- */

#include <htimer.h>                    /*                                    */
                                       /*                                    */
Timer        timer       [TIMER_SIZE]; /*                                    */
UCHAR        timer_size = TIMER_SIZE ; /*                                    */
                                       /*                                    */
#if (DRV_FRE EQ 0)                     /*                                    */
#define FRE_DRV                        /*                                    */
#else                                  /*                                    */
#define FRE_DRV  (Sys_driver*)&fre_driver,  /*                               */
#endif                                 /*                                    */
                                       /*                                    */
#if (DRV_DIS EQ 0)                     /*                                    */
#define DIS_DRV                        /*                                    */
#else                                  /*                                    */
#define DIS_DRV  (Sys_driver*)&dis_driver,  /*                               */
#endif                                 /*                                    */
                                       /*                                    */
#if (DRV_SMC EQ 0)                     /*                                    */
#define SMC_DRV                        /*                                    */
#else                                  /*                                    */
#define SMC_DRV  (Sys_driver*)&smc_driver,  /*                               */
#endif                                 /*                                    */
                                       /*                                    */
#if (DRV_FACTEST EQ 0)                 /*                                    */
#define FACTEST_DRV                    /*                                    */
#else                                  /*                                    */
#define FACTEST_DRV (Sys_driver*)&fct_driver, /*                             */
#endif                                 /*                                    */
                                       /*                                    */
#if (DRV_DHCPSRV EQ 0)                 /*                                    */
#define DHCP_DRV                       /*                                    */
#else                                  /*                                    */
#define DHCP_DRV (Sys_driver*)&dhcp_driver, /*                               */
#endif                                 /*                                    */
                                       /*                                    */
#if (DRV_USBD EQ 0)                    /*                                    */
#define USBD_DRV                       /*                                    */
#else                                  /*                                    */
#define USBD_DRV    (Sys_driver*)&usbd_driver, /*                            */
#endif                                 /*                                    */
                                       /*                                    */
#if (DRV_ENO EQ 0)                     /*                                    */
#define ENO_DRV                        /*                                    */
#else                                  /*                                    */
#define ENO_DRV    (Sys_driver*)&eno_driver, /*                              */
#endif                                 /*                                    */

const Sys_driver * const vmos_driver[]=/* Drivers table for sti71xx.         */
  BEGIN                                /*                                    */
    (Sys_driver*)&Sys_eep            , /* 0                                  */
    (Sys_driver*)&MDF_voldrv         , /* 1                                  */
    (Sys_driver*)&FDF_voldrv         , /* 2                                  */
    (Sys_driver*)&FAT_voldrv         , /* 3                                  */
    (Sys_driver*)&glue_voldrv        , /* 4                                  */
    (Sys_driver*)&kbditf_driver      , /* 5                                  */
    (Sys_driver*)&usbitf_driver      , /* 6                                  */
    (Sys_driver*)&den_driver         , /* 7                                  */
    (Sys_driver*)&led_driver         , /* 8                                  */
    (Sys_driver*)&swi_driver         , /* 9                                  */
    (Sys_driver*)&dmx_driver         , /* 10                                 */
    (Sys_driver*)&vid_driver         , /* 11                                 */
    (Sys_driver*)&aud_driver         , /* 12                                 */
    (Sys_driver*)&stl_driver         , /* 13                                 */
    (Sys_driver*)&play_driver        , /* 14                                 */
    (Sys_driver*)&http_service       , /* 15                                 */
    (Sys_driver*)&str_service        , /* 16                                 */
    (Sys_driver*)&eth_driver         , /* 17                                 */
    (Sys_driver*)&lo_driver          , /* 18                                 */
    (Sys_driver*)&ata_driver         , /* 19                                 */
    (Sys_driver*)&nand_driver        , /* 20                                 */
    (Sys_driver*)&ums_driver         , /* 21                                 */
    (Sys_driver*)&asy_driver         , /* 22                                 */
    (Sys_driver*)&ip_driver          , /* 23                                 */
    (Sys_driver*)&dns_service        , /* 24                                 */
    (Sys_driver*)&oad_service        , /* 25                                 */
    (Sys_driver*)&glue_service       , /* 26                                 */
    (Sys_driver*)&dsm_driver         , /* 27                                 */
    (Sys_driver*)&mp3_service        , /* 28                                 */
    (Sys_driver*)&hls_service        , /* 29                                 */
    (Sys_driver*)&pipe_driver        , /* 30                                 */
    FRE_DRV                            /* 31                                 */
    DIS_DRV                            /* 32                                 */
    POW_DRV                            /* 33                                 */
    PCM_DRV                            /* 34                                 */
    CI_DRV                             /* 35                                 */
    SEC_DRV                            /* 36                                 */
    PTH_DRV                            /* 37                                 */
    FACTEST_DRV                        /* 38                                 */
    USBD_DRV                           /* 39                                 */
    SMC_DRV                            /* 40                                 */
    ENO_DRV                            /* 41                                 */
    DHCP_DRV                           /* 42                                 */
    (Sys_driver*)&tls_driver         , /* 43                                 */
    HNULL                            , /* 44 Fin de la table                 */
  END                                ; /*                                    */
                                       /*                                    */
Hint_varenv * const hint_varenv      = /*                                    */
                         VARENV_INT  ; /* Package structure interface        */
                                       /*                                    */
IWORD (* const henv_start[])()       = /* Procedures d'initialisation        */
                 BEGIN                 /*                                    */
                   init_telecom      , /*                                    */
                   INIT_HEAP           /*                                    */
                   INIT_STREAM         /*                                    */
                   INIT_CLASS          /*                                    */
                   INIT_FILE           /*                                    */
                   INIT_ENV            /*                                    */
                   INIT_MESSAGE        /*                                    */
                   init_auttime      , /*                                    */
                   INIT_MODULE         /*                                    */
                   INIT_EXEC           /*                                    */
                   INIT_HLOAD          /*                                    */
                   init_autkbd       , /*                                    */
                   INIT_FILEREF        /*                                    */
                   INIT_NPANEL         /*                                    */
                   INIT_AC             /*                                    */
                   INIT_BRW            /*                                    */
                   INIT_ELFDL          /*                                    */
                   INIT_CLALIB         /*                                    */
                   INIT_POSIX          /*                                    */
                   INIT_PIPE           /*                                    */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
                                       /*                                    */
IWORD (* const henv_stop[])()        = /* Procedures de fin                  */
                 BEGIN                 /*                                    */
                   END_HLOAD           /*                                    */
                   END_FILEREF         /*                                    */
                /* scr_fin , */        /* _WORK_                             */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
#endif                                 /*                                    */


/* 5.xx Package ubuvmos - VMOS drivers - Linux Ubuntu simulators ------------*/

#ifdef PKG_ubuvmos                     /*                                    */
                                       /*                                    */
#ifdef PKG_vmos                             /* If VMOS included              */
IWORD init_vmos(CHAR*,CHAR*)              ; /*                               */
#define INIT_VMOS "VMOS", 1, 1, init_vmos , /*   VMOS Hyperpanel.            */
#else                                       /* Otherwise,                    */
#define INIT_VMOS                           /*   do not declare              */
#endif                                      /*                               */

#ifdef PKG_vmkuser                          /* If VMK app included,          */
IWORD VMK_USER_PROC(CHAR*,CHAR*)          ; /*                               */
#define INIT_VMK_USER \                     /*   start it.                   */\
        VMK_USER_NAME, 1, 1, VMK_USER_PROC, /*                               */
#else                                       /* Otherwise,                    */
#define INIT_VMK_USER                       /*   do not declare              */
#endif                                      /*                               */

#ifdef PKG_enigma                           /* If Enigma included,           */
IWORD init_enigma(CHAR*,CHAR*)            ; /*                               */
#define INIT_ENIGMA                         /*   Enigma access control.      */\
            "Enigma_CA", 2, 1, init_enigma, /*                               */
#else                                       /* Otherwise,                    */
#define INIT_ENIGMA                         /*   do not declare              */
#endif                                      /*                               */

const Task_grp task_grp[] =            /* Definition des groupes de taches   */
  BEGIN                                /* ---------------------------------- */
                                       /* Groupes de taches "temps reel" ... */
    INIT_VMOS                          /* VMOS   Hyperpanel.                 */
    INIT_VMK_USER                      /* VMK User App.                      */
                                       /* ---------------------------------- */
                                       /* Groupes de taches "standard" ..... */
    INIT_ENIGMA                        /* Controle d'acces Enigma.           */
                                       /* ---------------------------------- */
    ""             , 9 , 9 , HNULL   , /* Marque de fin de liste ........... */
  END                                ; /* ---------------------------------- */

const INT     szmemrun = AM_MEMSIZE  ; /* Taille de la memoire statique.     */
UCHAR         hp_ram    [AM_MEMSIZE] ; /* Allocation memoire.                */
                                       /*                                    */
const Sys_driver * const vmos_driver[]=/* Drivers table for ubuvmos.         */
  BEGIN                                /*                                    */
    (Sys_driver*)&Sys_eep            , /* 0                                  */
    (Sys_driver*)&HDF_voldrv         , /* 1                                  */
    (Sys_driver*)&MDF_voldrv         , /* 2                                  */
    (Sys_driver*)&FAT_voldrv         , /* 3                                  */
    (Sys_driver*)&glue_voldrv        , /* 4                                  */
    (Sys_driver*)&kbditf_driver      , /* 5                                  */
    (Sys_driver*)&fre_driver         , /* 6                                  */
    (Sys_driver*)&dmx_driver         , /* 7                                  */
    (Sys_driver*)&vid_driver         , /* 8                                  */
    (Sys_driver*)&aud_driver         , /* 9                                  */
    (Sys_driver*)&stl_driver         , /* 10                                 */
    (Sys_driver*)&den_driver         , /* 11                                 */
    (Sys_driver*)&swi_driver         , /* 12                                 */
    (Sys_driver*)&led_driver         , /* 13                                 */
    (Sys_driver*)&eth_driver         , /* 14                                 */
    (Sys_driver*)&lo_driver          , /* 15                                 */
    (Sys_driver*)&ata_driver         , /* 16                                 */
    (Sys_driver*)&play_driver        , /* 17                                 */
    (Sys_driver*)&http_service       , /* 18                                 */
    (Sys_driver*)&str_service        , /* 19                                 */
    (Sys_driver*)&asy_driver         , /* 20                                 */
    (Sys_driver*)&ip_driver          , /* 21                                 */
    (Sys_driver*)&dns_service        , /* 22                                 */
    (Sys_driver*)&oad_service        , /* 23                                 */
    (Sys_driver*)&glue_service       , /* 24                                 */
    (Sys_driver*)&dsm_driver         , /* 25                                 */
    (Sys_driver*)&mp3_service        , /* 26                                 */
    (Sys_driver*)&hls_service        , /* 27                                 */
    (Sys_driver*)&pipe_driver        , /* 28                                 */
    (Sys_driver*)&fct_driver         , /* 29                                 */
    (Sys_driver*)&tls_driver         , /* 30                                 */
    (Sys_driver*)0                   , /* 31 Fin de la table                 */
  END                                ; /*                                    */
                                       /*                                    */
Hint_varenv * const hint_varenv      = /*                                    */
                         VARENV_INT  ; /* Package structure interface        */
                                       /*                                    */
IWORD (* const henv_start[])()       = /* Procedures d'initialisation        */
                 BEGIN                 /*                                    */
                   init_telecom      , /*                                    */
                   INIT_HEAP           /*                                    */
                   INIT_STREAM         /*                                    */
                   INIT_CLASS          /*                                    */
                   INIT_FILE           /*                                    */
                   INIT_ENV            /*                                    */
                   INIT_MESSAGE        /*                                    */
                   init_auttime      , /*                                    */
                   INIT_MODULE         /*                                    */
                   INIT_EXEC           /*                                    */
                   INIT_HLOAD          /*                                    */
                   init_autkbd       , /*                                    */
                   INIT_FILEREF        /*                                    */
                   INIT_NPANEL         /*                                    */
                   INIT_AC             /*                                    */
                   INIT_BRW            /*                                    */
                   INIT_ELFDL          /*                                    */
                   INIT_CLALIB         /*                                    */
                   INIT_POSIX          /*                                    */
                   INIT_PIPE           /*                                    */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
                                       /*                                    */
IWORD (* const henv_stop[])()        = /* Procedures de fin                  */
                 BEGIN                 /*                                    */
                   END_HLOAD           /*                                    */
                   END_FILEREF         /*                                    */
                /* scr_fin , */        /* _WORK_                             */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
#endif                                 /*                                    */


/* 5.xx Package ubusyn - VMOS drivers - Linux Ubuntu simulators -------------*/

#ifdef PKG_ubusyn                      /*                                    */
                                       /*                                    */
const INT     szmemrun = AM_MEMSIZE  ; /* Taille de la memoire statique.     */
UCHAR         hp_ram    [AM_MEMSIZE] ; /* Allocation memoire.                */

IWORD init_vmos(CHAR*,CHAR*)         ; /*                                    */
                                       /*                                    */
const Task_grp task_grp[] =            /* Definition des groupes de taches   */
  BEGIN                                /* ---------------------------------- */
    "VMOS", 1 , 1 , init_vmos        , /* VMOS Hyperpanel.                   */
    ""    , 9 , 9 , HNULL            , /* Marque de fin de liste ........... */
  END                                ; /* ---------------------------------- */

const Sys_driver * const vmos_driver[]=/* Drivers table for ubuvmos.         */
  BEGIN                                /*                                    */
    (Sys_driver*)&HDF_voldrv         , /* 1                                  */
    (Sys_driver*)0                   , /* 2  Fin de la table                 */
  END                                ; /*                                    */
                                       /*                                    */
Hint_varenv * const hint_varenv      = /*                                    */
                         VARENV_INT  ; /* Package structure interface        */
                                       /*                                    */
IWORD (* const henv_start[])()       = /* Procedures d'initialisation        */
                 BEGIN                 /*                                    */
                   INIT_HEAP           /*                                    */
                   INIT_CLASS          /*                                    */
                   INIT_FILE           /*                                    */
                   INIT_ENV            /*                                    */
                   INIT_MESSAGE        /*                                    */
                   INIT_EXEC           /*                                    */
                   INIT_HLOAD          /*                                    */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
                                       /*                                    */
IWORD (* const henv_stop[])()        = /* Procedures de fin                  */
                 BEGIN                 /*                                    */
                   HNULL               /*                                    */
                 END                 ; /*                                    */
#endif                                 /*                                    */

const USHORT  vmos_nbdriver =          /* Size of vmos_driver table.         */
          sizeof(vmos_driver)/         /*                                    */
	  sizeof(Sys_driver *) -1    ; /*                                    */



/*
    6  Application langage dictionnaries Packages 
    _____________________________________________
*/


/* Package lg_* - Application language dictionaries ------------------------ */
/*                                                                           */
/* The following package are used to select required languages dictionnaries */
/* that can be used by the application. All language are dictionaries are    */
/* referenced in "hytv/uidata/lang.xls" file. This file include a generation */
/* tools for creation of "uidata/-.dic" files (Hyperpanel ascii dictionary   */
/* format. The utility "buildata" compile (PanTalk dictionary compiler) all  */
/* these "uidata/-.dic" files and produce "uidata/-.c" C source files.       */
/* These C source files contains byte code dictionary ready to used by the   */
/* application.                                                              */
/*                                                                           */
/* Several languages are availables. The list is :                           */
/*                                                                           */
/* NUMBER:     LANGUAGE:                                                     */
/*                                                                           */
/*   00        English                                                       */
/*   01        French                                                        */
/*   02        Deutch                                                        */
/*   03        Spanish                                                       */
/*   04        Italian                                                       */
/*   05        Polish                                                        */
/*   06        Russian                                                       */
/*   07        Turquish                                                      */
/*   08        Czech                                                         */
/*   09        Danish                                                        */
/*   10        Dutch                                                         */
/*   11        Swedish                                                       */
/*   12        Finnish                                                       */
/*   13        Greek                                                         */
/*   14        Arabic                                                        */
/*   15        Galician                                                      */
/*   16        Basque                                                        */
/*   17        Catalan                                                       */


/* 6.1  Packages lg00 - Application language (english) ----------------------*/

#ifdef PKG_lg00                        /* Language (language 00)             */
#define LG00_NBDICT  1                 /*                                    */
#define LG00_DICT    &lg00_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG00_NBDICT  0                 /*                                    */
#define LG00_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.2  Packages lg01 - Application language (french) -----------------------*/

#ifdef PKG_lg01                        /* Language (language 01)             */
#define LG01_NBDICT  1                 /*                                    */
#define LG01_DICT    &lg01_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG01_NBDICT  0                 /*                                    */
#define LG01_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.3  Packages lg02 - Application language (deutch) -----------------------*/

#ifdef PKG_lg02                        /* Language (language 02)             */
#define LG02_NBDICT  1                 /*                                    */
#define LG02_DICT    &lg02_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG02_NBDICT  0                 /*                                    */
#define LG02_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.4  Packages lg03 - Application language (spanish) ----------------------*/

#ifdef PKG_lg03                        /* Language (language 03)             */
#define LG03_NBDICT  1                 /*                                    */
#define LG03_DICT    &lg03_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG03_NBDICT  0                 /*                                    */
#define LG03_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.5  Packages lg04 - Application language (italian) ----------------------*/

#ifdef PKG_lg04                        /* Language (language 04)             */
#define LG04_NBDICT  1                 /*                                    */
#define LG04_DICT    &lg04_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG04_NBDICT  0                 /*                                    */
#define LG04_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.6  Packages lg05 - Application language (polish) -----------------------*/

#ifdef PKG_lg05                        /* Language (language 05)             */
#define LG05_NBDICT  1                 /*                                    */
#define LG05_DICT    &lg05_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG05_NBDICT  0                 /*                                    */
#define LG05_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.7  Packages lg06 - Application language (russian) ----------------------*/

#ifdef PKG_lg06                        /* Language (language 06)             */
#define LG06_NBDICT  1                 /*                                    */
#define LG06_DICT    &lg06_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG06_NBDICT  0                 /*                                    */
#define LG06_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.8  Packages lg07 - Application language (turquish) ---------------------*/

#ifdef PKG_lg07                        /* Language (language 07)             */
#define LG07_NBDICT  1                 /*                                    */
#define LG07_DICT    &lg07_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG07_NBDICT  0                 /*                                    */
#define LG07_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.9  Packages lg08 - Application language (czech) ------------------------*/

#ifdef PKG_lg08                        /* Language (language 08)             */
#define LG08_NBDICT  1                 /*                                    */
#define LG08_DICT    &lg08_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG08_NBDICT  0                 /*                                    */
#define LG08_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.10 Packages lg09 - Application language (danish) -----------------------*/

#ifdef PKG_lg09                        /* Language (language 09)             */
#define LG09_NBDICT  1                 /*                                    */
#define LG09_DICT    &lg09_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG09_NBDICT  0                 /*                                    */
#define LG09_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.11 Packages lg10 - Application language (dutch) ------------------------*/

#ifdef PKG_lg10                        /* Language (language 10)             */
#define LG10_NBDICT  1                 /*                                    */
#define LG10_DICT    &lg10_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG10_NBDICT  0                 /*                                    */
#define LG10_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.12 Packages lg11 - Application language (swedish) ----------------------*/

#ifdef PKG_lg11                        /* Language (language 11)             */
#define LG11_NBDICT  1                 /*                                    */
#define LG11_DICT    &lg11_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG11_NBDICT  0                 /*                                    */
#define LG11_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.13 Packages lg12 - Application language (finnish) ----------------------*/

#ifdef PKG_lg12                        /* Language (language 12)             */
#define LG12_NBDICT  1                 /*                                    */
#define LG12_DICT    &lg12_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG12_NBDICT  0                 /*                                    */
#define LG12_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.14 Packages lg13 - Application language (greek) ------------------------*/

#ifdef PKG_lg13                        /* Language (language 13)             */
#define LG13_NBDICT  1                 /*                                    */
#define LG13_DICT    &lg13_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG13_NBDICT  0                 /*                                    */
#define LG13_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.15 Packages lg14 - Application language (arabic) -----------------------*/

#ifdef PKG_lg14                        /* Language (language 14)             */
#define LG14_NBDICT  1                 /*                                    */
#define LG14_DICT    &lg14_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG14_NBDICT  0                 /*                                    */
#define LG14_DICT                      /*                                    */
#endif                                 /*                                    */


/* 6.16 Packages lg15 - Application language (galician) ---------------------*/

#ifdef PKG_lg15                        /* Language (language 15)             */
#define LG15_NBDICT  1                 /*                                    */
#define LG15_DICT    &lg15_dict     ,  /*                                    */
#else                                  /* Language not declared              */
#define LG15_NBDICT  0                 /*                                    */
#define LG15_DICT                      /*                                    */
#endif                                 /*                                    */



/*
    7  Messages packages
    ____________________
*/

/* 7.1  Packages msg_err - VMOS error messages ------------------------------*/

#ifdef PKG_msg_err                               /*                          */
#define MERR_DEF "error"  ,"ERR","ERROR"         /*                          */
#else                                            /*                          */
#define MERR_DEF  HNULL   ,HNULL,"NOT AVAILABLE" /*                          */
#define MERR_DISPLAY       0                     /*                          */
#endif                                           /*                          */


/* 7.2  Packages msg_war - VMOS warning messages ----------------------------*/

                                                 /*                          */
#ifdef PKG_msg_war                               /*                          */
#define MWAR_DEF "warning","WAR","WARNING"       /*                          */
#else                                            /*                          */
#define MWAR_DEF  HNULL   ,HNULL,"NOT AVAILABLE" /*                          */
#define MWAR_DISPLAY       0                     /*                          */
#endif                                             


/* 7.3  Packages msg_inf - VMOS info messages -------------------------------*/

#ifdef PKG_msg_inf                               /*                          */
#define MINF_DEF "info"    ,"INF","INFO"         /*                          */
#else                                            /*                          */
#define MINF_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MINF_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.4  Packages msg_fil - VMOS file system messages ------------------------*/

#ifdef PKG_msg_fil                               /*                          */
#define MFIL_DEF "file"    ,"FIL","FILE"         /*                          */
#else                                            /*                          */
#define MFIL_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MFIL_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.5  Packages msg_mem - VMOS memory manager messages ---------------------*/

#ifdef PKG_msg_mem                               /*                          */
#define MMEM_DEF "memory"  ,"MEM","MEMORY"       /*                          */
#else                                            /*                          */
#define MMEM_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MMEM_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.6  Packages msg_brw - VMOS browser messages ----------------------------*/

#ifdef PKG_msg_brw                               /*                          */
#define MBRW_DEF "brw" ,"BRW","BROWSER"          /*                          */
#else                                            /*                          */
#define MBRW_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MBRW_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.7  Packages msg_ptk - VMOS PanTalk script messages ---------------------*/

#ifdef PKG_msg_ptk                               /*                          */
#define MPTK_DEF "pantalk" ,"PTK","PANTALK"      /*                          */
#else                                            /*                          */
#define MPTK_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MPTK_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.8  Packages msg_mth - VMOS PanTalk method messages ---------------------*/

#ifdef PKG_msg_mth                               /*                          */
#define MMTH_DEF "method"  ,"MTH","METHOD"       /*                          */
#else                                            /*                          */
#define MMTH_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MMTH_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.9  Packages msg_tlc - VMOS telecom messages ----------------------------*/

#ifdef PKG_msg_tlc                               /*                          */
#define MTLC_DEF "telecom" ,"DRV","TELECOM"      /*                          */
#else                                            /*                          */
#define MTLC_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MTLC_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.10 Packages msg_pco - VMOS p-code messages -----------------------------*/

#ifdef PKG_msg_pco                               /*                          */
#define MPCO_DEF "pcode"  ,"PCO","PCODE"         /*                          */
#else                                            /*                          */
#define MPCO_DEF  HNULL   ,HNULL,"NOT AVAILABLE" /*                          */
#define MPCO_DISPLAY       0                     /*                          */
#endif                                           /*                          */


/* 7.11 Packages msg_cal - VMOS PanTalk procedurescall messages -------------*/

#ifdef PKG_msg_cal                               /*                          */
#define MCAL_DEF "call"   ,"CAL","CALL CPI"      /*                          */
#else                                            /*                          */
#define MCAL_DEF  HNULL   ,HNULL,"NOT AVAILABLE" /*                          */
#define MCAL_DISPLAY       0                     /*                          */
#endif                                           /*                          */


/* 7.12 Packages msg_mfi - VMOS file system more messages -------------------*/

#ifdef PKG_msg_mfi                               /*                          */
#define MMFI_DEF "morefil","MFI","MORE FILE"     /*                          */
#else                                            /*                          */
#define MMFI_DEF  HNULL   ,HNULL,"NOT AVAILABLE" /*                          */
#define MMFI_DISPLAY       0                     /*                          */
#endif                                           /*                          */


/* 7.13 Packages msg_aut - VMOS automaton messages --------------------------*/

#ifdef PKG_msg_aut                               /*                          */
#define MAUT_DEF "automat" ,"AUT","AUTOMATON"    /*                          */
#else                                            /*                          */
#define MAUT_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MAUT_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.14 Packages msg_mme - VMOS memory manager more messages ----------------*/

#ifdef PKG_msg_mme                               /*                          */
#define MMME_DEF "moremem" ,"MME","MORE MEMORY"  /*                          */
#else                                            /*                          */
#define MMME_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MMME_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.15 Packages msg_mhg - VMOS MHEG-5 messages -----------------------------*/

#ifdef PKG_msg_mhg                               /*                          */
#define MMHG_DEF "mheg" ,"MHG","MHEG"            /*                          */
#else                                            /*                          */
#define MMHG_DEF  HNULL ,HNULL,"NOT AVAILABLE"   /*                          */
#define MMHG_DISPLAY       0                     /*                          */
#endif                                           /*                          */


/* 7.16 Packages msg_thr - VMOS thread messages -----------------------------*/

#ifdef PKG_msg_thr                               /*                          */
#define MTHR_DEF "thr" ,"THR","THR THREAD"       /*                          */
#else                                            /*                          */
#define MTHR_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MTHR_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.17 Packages msg_tcp - VMOS TCP messages --------------------------------*/

#ifdef PKG_msg_tcp                               /*                          */
#define MTCP_DEF "tcp" ,"TCP","TCP PROTOCOL"     /*                          */
#else                                            /*                          */
#define MTCP_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MTCP_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.18 Packages msg_tsk - VMOS task manager messages -----------------------*/

#ifdef PKG_msg_tsk                               /*                          */
#define MTSK_DEF "task" ,"TSK","TASK CONTROL"    /*                          */
#else                                            /*                          */
#define MTSK_DEF  HNULL    ,HNULL,"NOT AVAILABLE"/*                          */
#define MTSK_DISPLAY        0                    /*                          */
#endif                                           /*                          */


/* 7.19 Packages msg_ca  - VMOS Access Control messages ---------------------*/

#ifdef PKG_msg_ca                                /*                          */
#define MCA_DEF "ca" ,"CA","CONDITIONAL ACCESS"  /*                          */
#else                                            /*                          */
#define MCA_DEF  HNULL    ,HNULL,"NOT AVAILABLE" /*                          */
#define MCA_DISPLAY        0                     /*                          */
#endif                                           /*                          */


/* 7.20 Packages msg_ci  - VMOS DCBC-I messages -----------------------------*/

#ifdef PKG_msg_ci                                /*                          */
                                                 /*                          */
#define MCI_DEF "ci" ,"CI","DVBCI"               /*                          */
#else                                            /*                          */
#define MCI_DEF  HNULL    ,HNULL,"NOT AVAILABLE" /*                          */
#define MCI_DISPLAY        0                     /*                          */
                                                 /*                          */
#endif                                           /*                          */



/*
    8  External exported variables
    ______________________________
*/


#ifndef _IOT_                          /* Unused for iot profiles.           */
                                       /*                                    */
const CHAR hhyp_exe [] = {HHYP_EXE } ; /*                                    */
const CHAR hhyp_am  [] = {HHYP_AM  } ; /*                                    */
const CHAR hhyp_sys [] = {HHYP_SYS } ; /*                                    */
const CHAR hhyp_vm  [] = {HHYP_VM  } ; /*                                    */
                                       /*                                    */
const CHAR  * const hmsg_names[32][3] =/* Nom des messages                   */
  BEGIN                                /*                                    */
                                       /*                                    */
    MERR_DEF , MWAR_DEF , MINF_DEF ,   /*                                    */
    MFIL_DEF , MMEM_DEF , MBRW_DEF ,   /*                                    */
    MPTK_DEF , MMTH_DEF , MTLC_DEF ,   /*                                    */
    MPCO_DEF , MCAL_DEF , MMFI_DEF ,   /*                                    */
    MAUT_DEF , MMME_DEF , MMHG_DEF ,   /*                                    */
    MTHR_DEF , MTCP_DEF , MTSK_DEF ,   /*                                    */
    MCA_DEF  , MCI_DEF                 /*                                    */
                                       /*                                    */
  END                                ; /*                                    */
                                       /*                                    */
 UINT hmsg_flag = MERR * MERR_DISPLAY+ /* Masque des warning()     (C      ) */
                  MWAR * MWAR_DISPLAY+ /*                                    */
                  MINF * MINF_DISPLAY+ /*                                    */
                  MFIL * MFIL_DISPLAY+ /*                                    */
                  MMEM * MMEM_DISPLAY+ /*                                    */
                  MBRW * MBRW_DISPLAY+ /*                                    */
                  MPTK * MPTK_DISPLAY+ /*                                    */
                  MMTH * MMTH_DISPLAY+ /*                                    */
                  MTLC * MTLC_DISPLAY+ /*                                    */
                  MPCO * MPCO_DISPLAY+ /*                                    */
                  MCAL * MCAL_DISPLAY+ /*                                    */
                  MMFI * MMFI_DISPLAY+ /*                                    */
                  MAUT * MAUT_DISPLAY+ /*                                    */
                  MMME * MMME_DISPLAY+ /*                                    */
                  MMHG * MMHG_DISPLAY+ /*                                    */
                  MTHR * MTHR_DISPLAY+ /*                                    */
                  MTCP * MTCP_DISPLAY+ /*                                    */
                  MTSK * MTSK_DISPLAY+ /*                                    */
                  MCA  *  MCA_DISPLAY+ /*                                    */
                  MCI  *  MCI_DISPLAY; /*                                    */


/*****************************************************************************
 * hmsg_exit = masque pour regler les valeurs par defaut des canaux de sortie*
 * des messages. Ce masque est un 32 bits utilise de la maniere suivante:    *
 *                                                                           *
 * bit 31                                                               bit 0*
 * x x x x x x x x    x x x x x x x x    x x x x x x x x    x x x x x x x x  *
 *                                                                           *
 * ^             ^    ^             ^    ^             ^    ^             ^  *
 * |             |    |             |    |             |    |             |  *
 * |-------------|    |-------------|    |-------------|    |-------------|  *
 *   |                  |                  |                  |              *
 *   write_alarm()      write_trace()      warning()          proc()         *
 *                                                                           *
 * Chacun des 4 champs de 8 bits est utilise de la maniere suivante:         *
 *                                                                           *
 *                                                                           *
 * bits    8 7 6 5 4 3 2 1                                                   *
 *         x x x x x x x x                                                   *
 *                                                                           *
 * avec:   bit 1 = VM output        write_console()                          *
 *         bit 2 = VM vt widget     VT widget            (unused)            *
 *         bit 3 = VM file          puf_df()             (unused)            *
 *         bit 4 = Toolkit console  diag_message()       (unused)            *
 *         bit 5 = VM printer       write_printer()      (unused)            *
 *         bit 6 = PanTalk method   send_evt()                               *
 *         bit 7 = unused                                (unused)            *
 *         bit 8 = unused                                (unused)            *
 *****************************************************************************/


    UINT hmsg_flaga  = 0x00000001    ; /* Masque des write_trace() (PanTalk) */
    UINT hmsg_flagal = 0xFFFFFFFF    ; /* Masque des write_alarm() (PanTalk) */
    UINT hmsg_exit   = 0x20010101    ; /* Voir "message.c"                   */

#else                                  /*                                    */
    UINT            hmsg_flag        ; /* Masque des messages de trace.      */
#endif                                 /* Unused for iot profiles.           */


/* Static dictionary declared in VMOS -------------------------------------- */

#ifndef _IOT_                          /* No dictionary in iot profiles.     */

extern const Dict message_dict       ; /* Dictionnaire des messages          */
                                       /*                                    */
extern const Dict lg00_dict          ; /* Language (language 00)             */
extern const Dict lg01_dict          ; /* Language (language 01)             */
extern const Dict lg02_dict          ; /* Language (language 02)             */
extern const Dict lg03_dict          ; /* Language (language 03)             */
extern const Dict lg04_dict          ; /* Language (language 04)             */
extern const Dict lg05_dict          ; /* Language (language 05)             */
extern const Dict lg06_dict          ; /* Language (language 06)             */
extern const Dict lg07_dict          ; /* Language (language 07)             */
extern const Dict lg08_dict          ; /* Language (language 08)             */
extern const Dict lg09_dict          ; /* Language (language 09)             */
extern const Dict lg10_dict          ; /* Language (language 10)             */
extern const Dict lg11_dict          ; /* Language (language 11)             */
extern const Dict lg12_dict          ; /* Language (language 12)             */
extern const Dict lg13_dict          ; /* Language (language 13)             */
extern const Dict lg14_dict          ; /* Language (language 14)             */
extern const Dict lg15_dict          ; /* Language (language 15)             */
extern const Dict lg16_dict          ; /* Language (language 16)             */
extern const Dict lg17_dict          ; /* Language (language 17)             */
                                       /*                                    */
const UCHAR romdict_nb    = 1        + /* Dictionnaire de messages .         */
              HPCHP_NBDICT           + /* Dict de procedureset mnemoniques.  */ 
              LG00_NBDICT            + /* Dict langue 00                     */
              LG01_NBDICT            + /* Dict langue 01                     */
              LG02_NBDICT            + /* Dict langue 02                     */
              LG03_NBDICT            + /* Dict langue 03                     */
              LG04_NBDICT            + /* Dict langue 04                     */
              LG05_NBDICT            + /* Dict langue 05                     */
              LG06_NBDICT            + /* Dict langue 06                     */
              LG07_NBDICT            + /* Dict langue 07                     */
              LG08_NBDICT            + /* Dict langue 08                     */
              LG09_NBDICT            + /* Dict langue 09                     */
              LG10_NBDICT            + /* Dict langue 10                     */
              LG11_NBDICT            + /* Dict langue 11                     */
              LG12_NBDICT            + /* Dict langue 12                     */
              LG13_NBDICT            + /* Dict langue 13                     */
              LG14_NBDICT            + /* Dict langue 14                     */
              LG15_NBDICT            ; /* Dict langue 15                     */

#define   RAMDICT_NB                   \
                 1                   + \
                 HPCHP_NBDICT        + \
                 LG00_NBDICT         + \
                 LG01_NBDICT         + \
                 LG02_NBDICT         + \
                 LG03_NBDICT         + \
                 LG04_NBDICT         + \
                 LG05_NBDICT         + \
                 LG06_NBDICT         + \
                 LG07_NBDICT         + \
                 LG08_NBDICT         + \
                 LG09_NBDICT         + \
                 LG10_NBDICT         + \
                 LG11_NBDICT         + \
                 LG12_NBDICT         + \
                 LG13_NBDICT         + \
                 LG14_NBDICT         + \
                 LG15_NBDICT         + \
                 2                     /* Pour un dico supplementaire .      */ 
                                       /*                                    */
Dictstat  ramdict[RAMDICT_NB]        ; /* Table de dictionnaires en RAM .    */
                                       /*                                    */
const Dict * const romdict[]   =       /* Table des dictionnaires en ROM.    */
               BEGIN                   /* Ancien format => type "Dict" .     */
                 &message_dict       , /* Messages Hyperpanel .              */
                 HPCHP_DICT            /* Dict de procedureset mnemoniques. */
                 LG00_DICT             /* Dict langue 00                     */
                 LG01_DICT             /* Dict langue 01                     */
                 LG02_DICT             /* Dict langue 02                     */
                 LG03_DICT             /* Dict langue 03                     */
                 LG04_DICT             /* Dict langue 04                     */
                 LG05_DICT             /* Dict langue 05                     */
                 LG06_DICT             /* Dict langue 06                     */
                 LG07_DICT             /* Dict langue 07                     */
                 LG08_DICT             /* Dict langue 08                     */
                 LG09_DICT             /* Dict langue 09                     */
                 LG10_DICT             /* Dict langue 10                     */
                 LG11_DICT             /* Dict langue 11                     */
                 LG12_DICT             /* Dict langue 12                     */
                 LG13_DICT             /* Dict langue 13                     */
                 LG14_DICT             /* Dict langue 14                     */
                 LG15_DICT             /* Dict langue 15                     */
               END                   ; /* Fin de la table.                   */
                                       /*                                    */
#ifndef SIZE_DICT                      /* Si le nombre max de dictionnaires  */
#define SIZE_DICT    RAMDICT_NB        /* n'est pas declare, prendre au      */
#endif                                 /* moins la taille de "ramdict" .     */
                                       /*                                    */
const UCHAR    dict_nb = SIZE_DICT   ; /* Nombre de dictionnaires            */
UCHAR         *dict_adr [SIZE_DICT]  ; /* Adresse   dictionnaires            */
UCHAR          dict_typ [SIZE_DICT]  ; /* Type      dictionnaires            */
                                       /*                                    */
#endif                                 /* No dictionary in iot profiles.     */
